/*
 * Copyright 2014 Mike Penz
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.mikepenz.iconics.typeface.library.community.material

import com.mikepenz.iconics.typeface.IIcon
import com.mikepenz.iconics.typeface.ITypeface
import com.mikepenz.iconics.typeface.library.community.R
import java.util.LinkedList

@Suppress("EnumEntryName")
object CommunityMaterial : ITypeface {

    override val fontRes: Int
        get() = R.font.community_material_font_v5_0_45_1

    override val characters: Map<String, Char> by lazy {
        mutableMapOf<String, Char>().apply {
            Icon.values().associateTo(this) { it.name to it.character }
            Icon2.values().associateTo(this) { it.name to it.character }
        }
    }

    override val mappingPrefix: String
        get() = "cmd"

    override val fontName: String
        get() = "Community Material Design"

    override val version: String
        get() = "5.0.45.1"

    override val iconCount: Int
        get() = characters.size

    override val icons: List<String>
        get() = characters.keys.toCollection(LinkedList())

    override val author: String
        get() = "Templarian / Community / Google"

    override val url: String
        get() = "http://materialdesignicons.com/"

    override val description: String
        get() = "Material Design Icons are the official open-source icons featured in the Google " +
                "Material Design specification."

    override val license: String
        get() = "Templates - Free, Community Icons - SIL Open Font License 1.1, Google Material " +
                "Design Icons: Attribution 4.0 International"

    override val licenseUrl: String
        get() = "https://raw.githubusercontent.com/Templarian/MaterialDesign/master/license.txt"

    override fun getIcon(key: String): IIcon {
        try {
            return Icon.valueOf(key)
        } catch (ex: Exception) {
            // ignore error, if not in 1st set, it has to be in the second
        }
        return Icon2.valueOf(key)
    }

    enum class Icon constructor(override val character: Char) : IIcon {
        cmd_ab_testing('\ueacc'),
        cmd_abjad_arabic('\ufc28'),
        cmd_abjad_hebrew('\ufc29'),
        cmd_abugida_devanagari('\ufc2a'),
        cmd_abugida_thai('\ufc2b'),
        cmd_access_point('\ue902'),
        cmd_access_point_network('\ue901'),
        cmd_access_point_network_off('\uf4e4'),
        cmd_account('\ue903'),
        cmd_account_alert('\ue904'),
        cmd_account_alert_outline('\uf453'),
        cmd_account_arrow_left('\uf454'),
        cmd_account_arrow_left_outline('\uf455'),
        cmd_account_arrow_right('\uf456'),
        cmd_account_arrow_right_outline('\uf457'),
        cmd_account_box('\ue905'),
        cmd_account_box_multiple('\uf233'),
        cmd_account_box_multiple_outline('\uf90d'),
        cmd_account_box_outline('\ue906'),
        cmd_account_cancel('\ufbdf'),
        cmd_account_cancel_outline('\ufbe0'),
        cmd_account_cash('\uf997'),
        cmd_account_cash_outline('\uf998'),
        cmd_account_check('\ue907'),
        cmd_account_check_outline('\uf4e5'),
        cmd_account_child('\uf388'),
        cmd_account_child_circle('\uf389'),
        cmd_account_child_outline('\uf9c8'),
        cmd_account_circle('\ue908'),
        cmd_account_circle_outline('\uf458'),
        cmd_account_clock('\uf459'),
        cmd_account_clock_outline('\uf45a'),
        cmd_account_cog('\ufc70'),
        cmd_account_cog_outline('\ufc71'),
        cmd_account_convert('\ue909'),
        cmd_account_convert_outline('\ufc01'),
        cmd_account_cowboy_hat('\uf79e'),
        cmd_account_details('\uef34'),
        cmd_account_details_outline('\ufc72'),
        cmd_account_edit('\uefbf'),
        cmd_account_edit_outline('\uf8fe'),
        cmd_account_group('\uf14a'),
        cmd_account_group_outline('\uf45b'),
        cmd_account_hard_hat('\ueeb9'),
        cmd_account_heart('\uf19a'),
        cmd_account_heart_outline('\uf4e6'),
        cmd_account_key('\ue90a'),
        cmd_account_key_outline('\uf4e7'),
        cmd_account_lock('\ufa5e'),
        cmd_account_lock_outline('\ufa5f'),
        cmd_account_minus('\ue90c'),
        cmd_account_minus_outline('\uf3eb'),
        cmd_account_multiple('\ue90d'),
        cmd_account_multiple_check('\uf1c5'),
        cmd_account_multiple_check_outline('\ufafe'),
        cmd_account_multiple_minus('\ueed7'),
        cmd_account_multiple_minus_outline('\uf4e8'),
        cmd_account_multiple_outline('\ue90e'),
        cmd_account_multiple_plus('\ue90f'),
        cmd_account_multiple_plus_outline('\uf101'),
        cmd_account_multiple_remove('\ufb0a'),
        cmd_account_multiple_remove_outline('\ufb0b'),
        cmd_account_music('\uf104'),
        cmd_account_music_outline('\uf5ec'),
        cmd_account_network('\ue910'),
        cmd_account_network_outline('\uf4e9'),
        cmd_account_off('\ue911'),
        cmd_account_off_outline('\uf4ea'),
        cmd_account_outline('\ue912'),
        cmd_account_plus('\ue913'),
        cmd_account_plus_outline('\uf102'),
        cmd_account_question('\uf45c'),
        cmd_account_question_outline('\uf45d'),
        cmd_account_remove('\ue914'),
        cmd_account_remove_outline('\uf3ec'),
        cmd_account_search('\ue915'),
        cmd_account_search_outline('\uf234'),
        cmd_account_settings('\uef33'),
        cmd_account_settings_outline('\uf9c9'),
        cmd_account_star('\ue916'),
        cmd_account_star_outline('\uf4eb'),
        cmd_account_supervisor('\uf38a'),
        cmd_account_supervisor_circle('\uf38b'),
        cmd_account_supervisor_outline('\ufa2d'),
        cmd_account_switch('\ue918'),
        cmd_account_switch_outline('\uedd0'),
        cmd_account_tie('\uf5e6'),
        cmd_account_tie_outline('\uf9ca'),
        cmd_account_tie_voice('\ufc08'),
        cmd_account_tie_voice_off('\ufc0a'),
        cmd_account_tie_voice_off_outline('\ufc0b'),
        cmd_account_tie_voice_outline('\ufc09'),
        cmd_account_voice('\ueecf'),
        cmd_adjust('\ue919'),
        cmd_adobe('\uf235'),
        cmd_adobe_acrobat('\uf8a0'),
        cmd_air_conditioner('\ue91a'),
        cmd_air_filter('\uf646'),
        cmd_air_horn('\uf6af'),
        cmd_air_humidifier('\uf999'),
        cmd_air_purifier('\uf647'),
        cmd_airbag('\uf4ec'),
        cmd_airballoon('\ue91b'),
        cmd_airballoon_outline('\uf90e'),
        cmd_airplane('\ue91c'),
        cmd_airplane_landing('\ueed8'),
        cmd_airplane_off('\ue91d'),
        cmd_airplane_takeoff('\ueed9'),
        cmd_airport('\uf14c'),
        cmd_alarm('\ue91f'),
        cmd_alarm_bell('\uf08f'),
        cmd_alarm_check('\ue920'),
        cmd_alarm_light('\uf090'),
        cmd_alarm_light_outline('\uf4ed'),
        cmd_alarm_multiple('\ue921'),
        cmd_alarm_note('\uf774'),
        cmd_alarm_note_off('\uf775'),
        cmd_alarm_off('\ue922'),
        cmd_alarm_plus('\ue923'),
        cmd_alarm_snooze('\uef91'),
        cmd_album('\ue924'),
        cmd_alert('\ue925'),
        cmd_alert_box('\ue926'),
        cmd_alert_box_outline('\uf5e7'),
        cmd_alert_circle('\ue927'),
        cmd_alert_circle_check('\ufaed'),
        cmd_alert_circle_check_outline('\ufaee'),
        cmd_alert_circle_outline('\ueeda'),
        cmd_alert_decagram('\uefc0'),
        cmd_alert_decagram_outline('\uf5e8'),
        cmd_alert_octagon('\ue928'),
        cmd_alert_octagon_outline('\uf5e9'),
        cmd_alert_octagram('\uf068'),
        cmd_alert_octagram_outline('\uf5ea'),
        cmd_alert_outline('\ue929'),
        cmd_alert_rhombus('\uface'),
        cmd_alert_rhombus_outline('\ufacf'),
        cmd_alien('\uf19b'),
        cmd_alien_outline('\uf9cb'),
        cmd_align_horizontal_center('\ufac3'),
        cmd_align_horizontal_left('\ufac2'),
        cmd_align_horizontal_right('\ufac4'),
        cmd_align_vertical_bottom('\ufac5'),
        cmd_align_vertical_center('\ufac6'),
        cmd_align_vertical_top('\ufac7'),
        cmd_all_inclusive('\uefc1'),
        cmd_allergy('\ufb58'),
        cmd_alpha('\ue92a'),
        cmd_alpha_a('\uf3ed'),
        cmd_alpha_a_box('\uf40c'),
        cmd_alpha_a_box_outline('\uf4ee'),
        cmd_alpha_a_circle('\uf4ef'),
        cmd_alpha_a_circle_outline('\uf4f0'),
        cmd_alpha_b('\uf3ee'),
        cmd_alpha_b_box('\uf40d'),
        cmd_alpha_b_box_outline('\uf4f1'),
        cmd_alpha_b_circle('\uf4f2'),
        cmd_alpha_b_circle_outline('\uf4f3'),
        cmd_alpha_c('\uf3ef'),
        cmd_alpha_c_box('\uf40e'),
        cmd_alpha_c_box_outline('\uf4f4'),
        cmd_alpha_c_circle('\uf4f5'),
        cmd_alpha_c_circle_outline('\uf4f6'),
        cmd_alpha_d('\uf3f0'),
        cmd_alpha_d_box('\uf40f'),
        cmd_alpha_d_box_outline('\uf4f7'),
        cmd_alpha_d_circle('\uf4f8'),
        cmd_alpha_d_circle_outline('\uf4f9'),
        cmd_alpha_e('\uf3f1'),
        cmd_alpha_e_box('\uf410'),
        cmd_alpha_e_box_outline('\uf4fa'),
        cmd_alpha_e_circle('\uf4fb'),
        cmd_alpha_e_circle_outline('\uf4fc'),
        cmd_alpha_f('\uf3f2'),
        cmd_alpha_f_box('\uf411'),
        cmd_alpha_f_box_outline('\uf4fd'),
        cmd_alpha_f_circle('\uf4fe'),
        cmd_alpha_f_circle_outline('\uf4ff'),
        cmd_alpha_g('\uf3f3'),
        cmd_alpha_g_box('\uf412'),
        cmd_alpha_g_box_outline('\uf500'),
        cmd_alpha_g_circle('\uf501'),
        cmd_alpha_g_circle_outline('\uf502'),
        cmd_alpha_h('\uf3f4'),
        cmd_alpha_h_box('\uf413'),
        cmd_alpha_h_box_outline('\uf503'),
        cmd_alpha_h_circle('\uf504'),
        cmd_alpha_h_circle_outline('\uf505'),
        cmd_alpha_i('\uf3f5'),
        cmd_alpha_i1('\uf3f6'),
        cmd_alpha_i_box('\uf414'),
        cmd_alpha_i_box_outline('\uf506'),
        cmd_alpha_i_circle('\uf507'),
        cmd_alpha_i_circle_outline('\uf508'),
        cmd_alpha_j('\uf3f7'),
        cmd_alpha_j_box('\uf415'),
        cmd_alpha_j_box_outline('\uf509'),
        cmd_alpha_j_circle('\uf50a'),
        cmd_alpha_j_circle_outline('\uf50b'),
        cmd_alpha_k('\uf3f8'),
        cmd_alpha_k_box('\uf416'),
        cmd_alpha_k_box_outline('\uf50c'),
        cmd_alpha_k_circle('\uf50d'),
        cmd_alpha_k_circle_outline('\uf50e'),
        cmd_alpha_l('\uf3f9'),
        cmd_alpha_l1('\uf3fa'),
        cmd_alpha_l_box('\uf417'),
        cmd_alpha_l_box_outline('\uf50f'),
        cmd_alpha_l_circle('\uf510'),
        cmd_alpha_l_circle_outline('\uf511'),
        cmd_alpha_m('\uf3fb'),
        cmd_alpha_m_box('\uf418'),
        cmd_alpha_m_box_outline('\uf512'),
        cmd_alpha_m_circle('\uf513'),
        cmd_alpha_m_circle_outline('\uf514'),
        cmd_alpha_n('\uf3fc'),
        cmd_alpha_n_box('\uf419'),
        cmd_alpha_n_box_outline('\uf515'),
        cmd_alpha_n_circle('\uf516'),
        cmd_alpha_n_circle_outline('\uf517'),
        cmd_alpha_o('\uf3fd'),
        cmd_alpha_o1('\uf3fe'),
        cmd_alpha_o_box('\uf41a'),
        cmd_alpha_o_box_outline('\uf518'),
        cmd_alpha_o_circle('\uf519'),
        cmd_alpha_o_circle1('\uf51a'),
        cmd_alpha_o_circle_outline('\uf51b'),
        cmd_alpha_o_circle_outline1('\uf51c'),
        cmd_alpha_p('\uf3ff'),
        cmd_alpha_p_box('\uf41b'),
        cmd_alpha_p_box_outline('\uf51d'),
        cmd_alpha_p_circle('\uf51e'),
        cmd_alpha_p_circle_outline('\uf51f'),
        cmd_alpha_q('\uf400'),
        cmd_alpha_q_box('\uf41c'),
        cmd_alpha_q_box_outline('\uf520'),
        cmd_alpha_q_circle('\uf521'),
        cmd_alpha_q_circle_outline('\uf522'),
        cmd_alpha_r('\uf401'),
        cmd_alpha_r_box('\uf41d'),
        cmd_alpha_r_box_outline('\uf523'),
        cmd_alpha_r_circle('\uf524'),
        cmd_alpha_r_circle_outline('\uf525'),
        cmd_alpha_s('\uf402'),
        cmd_alpha_s_box('\uf41e'),
        cmd_alpha_s_box_outline('\uf526'),
        cmd_alpha_s_circle('\uf527'),
        cmd_alpha_s_circle_outline('\uf528'),
        cmd_alpha_t('\uf403'),
        cmd_alpha_t_box('\uf41f'),
        cmd_alpha_t_box_outline('\uf529'),
        cmd_alpha_t_circle('\uf52a'),
        cmd_alpha_t_circle_outline('\uf52b'),
        cmd_alpha_u('\uf404'),
        cmd_alpha_u_box('\uf420'),
        cmd_alpha_u_box_outline('\uf52c'),
        cmd_alpha_u_circle('\uf52d'),
        cmd_alpha_u_circle_outline('\uf52e'),
        cmd_alpha_v('\uf405'),
        cmd_alpha_v1('\uf406'),
        cmd_alpha_v_box('\uf421'),
        cmd_alpha_v_box_outline('\uf52f'),
        cmd_alpha_v_circle('\uf530'),
        cmd_alpha_v_circle_outline('\uf531'),
        cmd_alpha_w('\uf407'),
        cmd_alpha_w_box('\uf422'),
        cmd_alpha_w_box_outline('\uf532'),
        cmd_alpha_w_circle('\uf533'),
        cmd_alpha_w_circle_outline('\uf534'),
        cmd_alpha_x('\uf408'),
        cmd_alpha_x1('\uf409'),
        cmd_alpha_x_box('\uf423'),
        cmd_alpha_x_box_outline('\uf535'),
        cmd_alpha_x_circle('\uf536'),
        cmd_alpha_x_circle_outline('\uf537'),
        cmd_alpha_y('\uf40a'),
        cmd_alpha_y_box('\uf424'),
        cmd_alpha_y_box_outline('\uf538'),
        cmd_alpha_y_circle('\uf539'),
        cmd_alpha_y_circle_outline('\uf53a'),
        cmd_alpha_z('\uf40b'),
        cmd_alpha_z_box('\uf425'),
        cmd_alpha_z_box_outline('\uf53b'),
        cmd_alpha_z_circle('\uf53c'),
        cmd_alpha_z_circle_outline('\uf53d'),
        cmd_alphabet_aurebesh('\ufc2c'),
        cmd_alphabet_cyrillic('\ufc2d'),
        cmd_alphabet_greek('\ufc2e'),
        cmd_alphabet_latin('\ufc2f'),
        cmd_alphabet_piqad('\ufc30'),
        cmd_alphabet_tengwar('\ufc37'),
        cmd_alphabetical('\ue92b'),
        cmd_alphabetical_off('\uf90f'),
        cmd_alphabetical_variant('\uf910'),
        cmd_alphabetical_variant_off('\uf911'),
        cmd_altimeter('\ueedb'),
        cmd_amazon('\ue92c'),
        cmd_amazon_alexa('\uf1c6'),
        cmd_ambulance('\ue92e'),
        cmd_ammunition('\uf5eb'),
        cmd_ampersand('\uf38c'),
        cmd_amplifier('\ue92f'),
        cmd_amplifier_off('\ufab5'),
        cmd_anchor('\ue930'),
        cmd_android('\ue931'),
        cmd_android_auto('\uf38d'),
        cmd_android_debug_bridge('\ue932'),
        cmd_android_messages('\uf648'),
        cmd_android_studio('\ue933'),
        cmd_angle_acute('\uf236'),
        cmd_angle_obtuse('\uf237'),
        cmd_angle_right('\uf238'),
        cmd_angular('\uefb5'),
        cmd_angularjs('\uefc2'),
        cmd_animation('\ueedc'),
        cmd_animation_outline('\uf38e'),
        cmd_animation_play('\uf239'),
        cmd_animation_play_outline('\uf38f'),
        cmd_ansible('\uf99a'),
        cmd_antenna('\ufa19'),
        cmd_anvil('\uf19c'),
        cmd_apache_kafka('\uf912'),
        cmd_api('\uf99b'),
        cmd_api_off('\ufb57'),
        cmd_apple('\ue934'),
        cmd_apple_airplay('\ue91e'),
        cmd_apple_finder('\ue935'),
        cmd_apple_icloud('\ue937'),
        cmd_apple_ios('\ue936'),
        cmd_apple_keyboard_caps('\uef35'),
        cmd_apple_keyboard_command('\uef36'),
        cmd_apple_keyboard_control('\uef37'),
        cmd_apple_keyboard_option('\uef38'),
        cmd_apple_keyboard_shift('\uef39'),
        cmd_apple_safari('\ue938'),
        cmd_application('\uef17'),
        cmd_application_export('\uf6b0'),
        cmd_application_import('\uf6b1'),
        cmd_approximately_equal('\uf8a1'),
        cmd_approximately_equal_box('\uf8a2'),
        cmd_apps('\ue93a'),
        cmd_apps_box('\uf649'),
        cmd_arch('\uf1c7'),
        cmd_archive('\ue93b'),
        cmd_archive_arrow_down('\ufb59'),
        cmd_archive_arrow_down_outline('\ufb5a'),
        cmd_archive_arrow_up('\ufb5b'),
        cmd_archive_arrow_up_outline('\ufb5c'),
        cmd_archive_outline('\ufb0e'),
        cmd_arm_flex('\uf8da'),
        cmd_arm_flex_outline('\uf8d9'),
        cmd_arrange_bring_forward('\ue93c'),
        cmd_arrange_bring_to_front('\ue93d'),
        cmd_arrange_send_backward('\ue93e'),
        cmd_arrange_send_to_back('\ue93f'),
        cmd_arrow_all('\ue940'),
        cmd_arrow_bottom_left('\ue941'),
        cmd_arrow_bottom_left_bold_outline('\uf2b6'),
        cmd_arrow_bottom_left_thick('\uf2b7'),
        cmd_arrow_bottom_right('\ue942'),
        cmd_arrow_bottom_right_bold_outline('\uf2b8'),
        cmd_arrow_bottom_right_thick('\uf2b9'),
        cmd_arrow_collapse('\uef18'),
        cmd_arrow_collapse_all('\ue943'),
        cmd_arrow_collapse_down('\uf093'),
        cmd_arrow_collapse_horizontal('\uf14d'),
        cmd_arrow_collapse_left('\uf094'),
        cmd_arrow_collapse_right('\uf095'),
        cmd_arrow_collapse_up('\uf096'),
        cmd_arrow_collapse_vertical('\uf14e'),
        cmd_arrow_decision('\uf2ba'),
        cmd_arrow_decision_auto('\uf2bb'),
        cmd_arrow_decision_auto_outline('\uf2bc'),
        cmd_arrow_decision_outline('\uf2bd'),
        cmd_arrow_down('\ue944'),
        cmd_arrow_down_bold('\uf031'),
        cmd_arrow_down_bold_box('\uf032'),
        cmd_arrow_down_bold_box_outline('\uf033'),
        cmd_arrow_down_bold_circle('\ue946'),
        cmd_arrow_down_bold_circle_outline('\ue947'),
        cmd_arrow_down_bold_hexagon_outline('\ue948'),
        cmd_arrow_down_bold_outline('\uf2be'),
        cmd_arrow_down_box('\uefc3'),
        cmd_arrow_down_circle('\uf5de'),
        cmd_arrow_down_circle_outline('\uf5df'),
        cmd_arrow_down_drop_circle('\ue949'),
        cmd_arrow_down_drop_circle_outline('\ue94a'),
        cmd_arrow_down_thick('\ue945'),
        cmd_arrow_expand('\uef19'),
        cmd_arrow_expand_all('\ue94b'),
        cmd_arrow_expand_down('\uf097'),
        cmd_arrow_expand_horizontal('\uf14f'),
        cmd_arrow_expand_left('\uf098'),
        cmd_arrow_expand_right('\uf099'),
        cmd_arrow_expand_up('\uf09a'),
        cmd_arrow_expand_vertical('\uf150'),
        cmd_arrow_horizontal_lock('\ufa5b'),
        cmd_arrow_left('\ue94c'),
        cmd_arrow_left_bold('\uf034'),
        cmd_arrow_left_bold_box('\uf035'),
        cmd_arrow_left_bold_box_outline('\uf036'),
        cmd_arrow_left_bold_circle('\ue94e'),
        cmd_arrow_left_bold_circle_outline('\ue94f'),
        cmd_arrow_left_bold_hexagon_outline('\ue950'),
        cmd_arrow_left_bold_outline('\uf2bf'),
        cmd_arrow_left_box('\uefc4'),
        cmd_arrow_left_circle('\uf5e0'),
        cmd_arrow_left_circle_outline('\uf5e1'),
        cmd_arrow_left_drop_circle('\ue951'),
        cmd_arrow_left_drop_circle_outline('\ue952'),
        cmd_arrow_left_right('\uf776'),
        cmd_arrow_left_right_bold('\uf777'),
        cmd_arrow_left_right_bold_outline('\uf2c0'),
        cmd_arrow_left_thick('\ue94d'),
        cmd_arrow_right('\ue953'),
        cmd_arrow_right_bold('\uf037'),
        cmd_arrow_right_bold_box('\uf038'),
        cmd_arrow_right_bold_box_outline('\uf039'),
        cmd_arrow_right_bold_circle('\ue955'),
        cmd_arrow_right_bold_circle_outline('\ue956'),
        cmd_arrow_right_bold_hexagon_outline('\ue957'),
        cmd_arrow_right_bold_outline('\uf2c1'),
        cmd_arrow_right_box('\uefc5'),
        cmd_arrow_right_circle('\uf5e2'),
        cmd_arrow_right_circle_outline('\uf5e3'),
        cmd_arrow_right_drop_circle('\ue958'),
        cmd_arrow_right_drop_circle_outline('\ue959'),
        cmd_arrow_right_thick('\ue954'),
        cmd_arrow_split_horizontal('\uf23a'),
        cmd_arrow_split_vertical('\uf23b'),
        cmd_arrow_top_left('\ue95a'),
        cmd_arrow_top_left_bold_outline('\uf2c2'),
        cmd_arrow_top_left_bottom_right('\uf778'),
        cmd_arrow_top_left_bottom_right_bold('\uf779'),
        cmd_arrow_top_left_thick('\uf2c3'),
        cmd_arrow_top_right('\ue95b'),
        cmd_arrow_top_right_bold_outline('\uf2c4'),
        cmd_arrow_top_right_bottom_left('\uf77a'),
        cmd_arrow_top_right_bottom_left_bold('\uf77b'),
        cmd_arrow_top_right_thick('\uf2c5'),
        cmd_arrow_up('\ue95c'),
        cmd_arrow_up_bold('\uf03a'),
        cmd_arrow_up_bold_box('\uf03b'),
        cmd_arrow_up_bold_box_outline('\uf03c'),
        cmd_arrow_up_bold_circle('\ue95e'),
        cmd_arrow_up_bold_circle_outline('\ue95f'),
        cmd_arrow_up_bold_hexagon_outline('\ue960'),
        cmd_arrow_up_bold_outline('\uf2c6'),
        cmd_arrow_up_box('\uefc6'),
        cmd_arrow_up_circle('\uf5e4'),
        cmd_arrow_up_circle_outline('\uf5e5'),
        cmd_arrow_up_down('\uf77c'),
        cmd_arrow_up_down_bold('\uf77d'),
        cmd_arrow_up_down_bold_outline('\uf2c7'),
        cmd_arrow_up_drop_circle('\ue961'),
        cmd_arrow_up_drop_circle_outline('\ue962'),
        cmd_arrow_up_thick('\ue95d'),
        cmd_arrow_vertical_lock('\ufa5c'),
        cmd_artstation('\uf45e'),
        cmd_aspect_ratio('\uf323'),
        cmd_assistant('\ue963'),
        cmd_asterisk('\uefc7'),
        cmd_at('\ue964'),
        cmd_atlassian('\uf105'),
        cmd_atm('\uf64a'),
        cmd_atom('\uf069'),
        cmd_atom_variant('\uf77e'),
        cmd_attachment('\ue965'),
        cmd_audio_video('\uf23c'),
        cmd_audio_video_off('\ufab6'),
        cmd_augmented_reality('\uf151'),
        cmd_auto_download('\ufc7e'),
        cmd_auto_fix('\ue967'),
        cmd_auto_upload('\ue968'),
        cmd_autorenew('\ue969'),
        cmd_av_timer('\ue96a'),
        cmd_aws('\uf712'),
        cmd_axe('\uf1c8'),
        cmd_axis('\uf64b'),
        cmd_axis_arrow('\uf64c'),
        cmd_axis_arrow_lock('\uf64d'),
        cmd_axis_lock('\uf64e'),
        cmd_axis_x_arrow('\uf64f'),
        cmd_axis_x_arrow_lock('\uf650'),
        cmd_axis_x_rotate_clockwise('\uf651'),
        cmd_axis_x_rotate_counterclockwise('\uf652'),
        cmd_axis_x_y_arrow_lock('\uf653'),
        cmd_axis_y_arrow('\uf654'),
        cmd_axis_y_arrow_lock('\uf655'),
        cmd_axis_y_rotate_clockwise('\uf656'),
        cmd_axis_y_rotate_counterclockwise('\uf657'),
        cmd_axis_z_arrow('\uf658'),
        cmd_axis_z_arrow_lock('\uf659'),
        cmd_axis_z_rotate_clockwise('\uf65a'),
        cmd_axis_z_rotate_counterclockwise('\uf65b'),
        cmd_babel('\uf324'),
        cmd_baby('\ue96b'),
        cmd_baby_bottle('\uf83c'),
        cmd_baby_bottle_outline('\uf83d'),
        cmd_baby_carriage('\uef92'),
        cmd_baby_carriage_off('\uf8a3'),
        cmd_baby_face('\uf77f'),
        cmd_baby_face_outline('\uf780'),
        cmd_backburger('\ue96c'),
        cmd_backspace('\ue96d'),
        cmd_backspace_outline('\uf45f'),
        cmd_backspace_reverse('\uf781'),
        cmd_backspace_reverse_outline('\uf782'),
        cmd_backup_restore('\ue96e'),
        cmd_bacteria('\uf7d8'),
        cmd_bacteria_outline('\uf7d9'),
        cmd_badge_account('\uf6aa'),
        cmd_badge_account_alert('\uf6ab'),
        cmd_badge_account_alert_outline('\uf6ac'),
        cmd_badge_account_horizontal('\uf710'),
        cmd_badge_account_horizontal_outline('\uf711'),
        cmd_badge_account_outline('\uf6ad'),
        cmd_badminton('\uf152'),
        cmd_bag_carry_on('\uf83e'),
        cmd_bag_carry_on_check('\uf668'),
        cmd_bag_carry_on_off('\uf83f'),
        cmd_bag_checked('\uf840'),
        cmd_bag_personal('\uf713'),
        cmd_bag_personal_off('\uf714'),
        cmd_bag_personal_off_outline('\uf715'),
        cmd_bag_personal_outline('\uf716'),
        cmd_baguette('\uf841'),
        cmd_balloon('\uf325'),
        cmd_ballot('\uf2c8'),
        cmd_ballot_outline('\uf2c9'),
        cmd_ballot_recount('\uf53e'),
        cmd_ballot_recount_outline('\uf53f'),
        cmd_bandage('\uf6b2'),
        cmd_bandcamp('\uef78'),
        cmd_bank('\ue96f'),
        cmd_bank_minus('\uf6b3'),
        cmd_bank_outline('\uf783'),
        cmd_bank_plus('\uf6b4'),
        cmd_bank_remove('\uf6b5'),
        cmd_bank_transfer('\uf326'),
        cmd_bank_transfer_in('\uf327'),
        cmd_bank_transfer_out('\uf328'),
        cmd_barcode('\ue970'),
        cmd_barcode_off('\ufb36'),
        cmd_barcode_scan('\ue971'),
        cmd_barley('\ue972'),
        cmd_barley_off('\uf460'),
        cmd_barn('\uf461'),
        cmd_barrel('\ue973'),
        cmd_baseball('\uf153'),
        cmd_baseball_bat('\uf154'),
        cmd_bash('\ufa83'),
        cmd_basket('\ue975'),
        cmd_basket_fill('\ue976'),
        cmd_basket_outline('\ufa81'),
        cmd_basket_unfill('\ue977'),
        cmd_basketball('\uf107'),
        cmd_basketball_hoop('\uf540'),
        cmd_basketball_hoop_outline('\uf541'),
        cmd_bat('\uf462'),
        cmd_battery('\ue978'),
        cmd_battery_10('\ue979'),
        cmd_battery_10_bluetooth('\uf23d'),
        cmd_battery_20('\ue97a'),
        cmd_battery_20_bluetooth('\uf23e'),
        cmd_battery_30('\ue97b'),
        cmd_battery_30_bluetooth('\uf23f'),
        cmd_battery_40('\ue97c'),
        cmd_battery_40_bluetooth('\uf240'),
        cmd_battery_50('\ue97d'),
        cmd_battery_50_bluetooth('\uf241'),
        cmd_battery_60('\ue97e'),
        cmd_battery_60_bluetooth('\uf242'),
        cmd_battery_70('\ue97f'),
        cmd_battery_70_bluetooth('\uf243'),
        cmd_battery_80('\ue980'),
        cmd_battery_80_bluetooth('\uf244'),
        cmd_battery_90('\ue981'),
        cmd_battery_90_bluetooth('\uf245'),
        cmd_battery_alert('\ue982'),
        cmd_battery_alert_bluetooth('\uf246'),
        cmd_battery_alert_variant('\uf9cc'),
        cmd_battery_alert_variant_outline('\uf9cd'),
        cmd_battery_bluetooth('\uf247'),
        cmd_battery_bluetooth_variant('\uf248'),
        cmd_battery_charging('\ue983'),
        cmd_battery_charging_10('\uf19d'),
        cmd_battery_charging_100('\ue984'),
        cmd_battery_charging_20('\ue985'),
        cmd_battery_charging_30('\ue986'),
        cmd_battery_charging_40('\ue987'),
        cmd_battery_charging_401('\ue988'),
        cmd_battery_charging_60('\ue989'),
        cmd_battery_charging_70('\uf19e'),
        cmd_battery_charging_80('\ue98a'),
        cmd_battery_charging_90('\ue98b'),
        cmd_battery_charging_high('\ufba6'),
        cmd_battery_charging_low('\ufba4'),
        cmd_battery_charging_medium('\ufba5'),
        cmd_battery_charging_outline('\uf19f'),
        cmd_battery_charging_wireless('\uf108'),
        cmd_battery_charging_wireless_10('\uf109'),
        cmd_battery_charging_wireless_20('\uf10a'),
        cmd_battery_charging_wireless_30('\uf10b'),
        cmd_battery_charging_wireless_40('\uf10c'),
        cmd_battery_charging_wireless_50('\uf10d'),
        cmd_battery_charging_wireless_60('\uf10e'),
        cmd_battery_charging_wireless_70('\uf10f'),
        cmd_battery_charging_wireless_80('\uf110'),
        cmd_battery_charging_wireless_90('\uf111'),
        cmd_battery_charging_wireless_alert('\uf112'),
        cmd_battery_charging_wireless_outline('\uf113'),
        cmd_battery_heart('\ufb0f'),
        cmd_battery_heart_outline('\ufb10'),
        cmd_battery_heart_variant('\ufb11'),
        cmd_battery_high('\ufba3'),
        cmd_battery_low('\ufba1'),
        cmd_battery_medium('\ufba2'),
        cmd_battery_minus('\ue98c'),
        cmd_battery_negative('\ue98d'),
        cmd_battery_off('\ufb5d'),
        cmd_battery_off_outline('\ufb5e'),
        cmd_battery_outline('\ue98e'),
        cmd_battery_plus('\ue98f'),
        cmd_battery_positive('\ue990'),
        cmd_battery_unknown('\ue991'),
        cmd_battery_unknown_bluetooth('\uf249'),
        cmd_battlenet('\uf463'),
        cmd_beach('\ue992'),
        cmd_beaker('\uf5ed'),
        cmd_beaker_alert('\ufb29'),
        cmd_beaker_alert_outline('\ufb2a'),
        cmd_beaker_check('\ufb2b'),
        cmd_beaker_check_outline('\ufb2c'),
        cmd_beaker_minus('\ufb2d'),
        cmd_beaker_minus_outline('\ufb2e'),
        cmd_beaker_outline('\uef93'),
        cmd_beaker_plus('\ufb2f'),
        cmd_beaker_plus_outline('\ufb30'),
        cmd_beaker_question('\ufb31'),
        cmd_beaker_question_outline('\ufb32'),
        cmd_beaker_remove('\ufb33'),
        cmd_beaker_remove_outline('\ufb34'),
        cmd_bed('\uebe8'),
        cmd_bed_double('\uf8d7'),
        cmd_bed_double_outline('\uf8d6'),
        cmd_bed_empty('\uf1a0'),
        cmd_bed_king('\uf8d5'),
        cmd_bed_king_outline('\uf8d4'),
        cmd_bed_outline('\ue999'),
        cmd_bed_queen('\uf8d3'),
        cmd_bed_queen_outline('\uf8de'),
        cmd_bed_single('\uf970'),
        cmd_bed_single_outline('\uf971'),
        cmd_bee('\uf8a4'),
        cmd_bee_flower('\uf8a5'),
        cmd_beehive_outline('\uf9ce'),
        cmd_beer('\ue998'),
        cmd_beer_outline('\ufc0c'),
        cmd_bell('\ue99a'),
        cmd_bell_alert('\uf65c'),
        cmd_bell_alert_outline('\uf784'),
        cmd_bell_check('\ufae5'),
        cmd_bell_check_outline('\ufae6'),
        cmd_bell_circle('\uf65d'),
        cmd_bell_circle_outline('\uf65e'),
        cmd_bell_off('\ue99b'),
        cmd_bell_off_outline('\uf390'),
        cmd_bell_outline('\ue99c'),
        cmd_bell_plus('\ue99d'),
        cmd_bell_plus_outline('\uf391'),
        cmd_bell_ring('\ue99e'),
        cmd_bell_ring_outline('\ue99f'),
        cmd_bell_sleep('\ue9a0'),
        cmd_bell_sleep_outline('\uf392'),
        cmd_beta('\ue9a1'),
        cmd_betamax('\uf2ca'),
        cmd_biathlon('\uf717'),
        cmd_bicycle('\uf99c'),
        cmd_bicycle_basket('\ufb35'),
        cmd_bike('\ue9a3'),
        cmd_bike_fast('\ufa1f'),
        cmd_billboard('\uf913'),
        cmd_billiards('\uf464'),
        cmd_billiards_rack('\uf465'),
        cmd_binoculars('\ue9a5'),
        cmd_bio('\ue9a6'),
        cmd_biohazard('\ue9a7'),
        cmd_bitbucket('\ue9a8'),
        cmd_bitcoin('\uf114'),
        cmd_black_mesa('\ue9a9'),
        cmd_blender('\uf5ee'),
        cmd_blender_software('\ue9ab'),
        cmd_blinds('\ue9ac'),
        cmd_blinds_open('\uf914'),
        cmd_block_helper('\ue9ad'),
        cmd_blogger('\ue9ae'),
        cmd_blood_bag('\uf5ef'),
        cmd_bluetooth('\ue9af'),
        cmd_bluetooth_audio('\ue9b0'),
        cmd_bluetooth_connect('\ue9b1'),
        cmd_bluetooth_off('\ue9b2'),
        cmd_bluetooth_settings('\ue9b3'),
        cmd_bluetooth_transfer('\ue9b4'),
        cmd_blur('\ue9b5'),
        cmd_blur_linear('\ue9b6'),
        cmd_blur_off('\ue9b7'),
        cmd_blur_radial('\ue9b8'),
        cmd_bolnisi_cross('\uf5f0'),
        cmd_bolt('\uf6b6'),
        cmd_bomb('\uef94'),
        cmd_bomb_off('\uefc8'),
        cmd_bone('\ue9b9'),
        cmd_book('\ue9ba'),
        cmd_book_account('\ufcac'),
        cmd_book_account_outline('\ufcad'),
        cmd_book_alphabet('\uef20'),
        cmd_book_cross('\ue9a2'),
        cmd_book_information_variant('\uf972'),
        cmd_book_lock('\uf09b'),
        cmd_book_lock_open('\uf09c'),
        cmd_book_minus('\ueedd'),
        cmd_book_minus_multiple('\uf393'),
        cmd_book_minus_multiple_outline('\uf20a'),
        cmd_book_multiple('\ue9bb'),
        cmd_book_multiple_outline('\ued3c'),
        cmd_book_music('\ue966'),
        cmd_book_open('\ue9bd'),
        cmd_book_open_outline('\uf466'),
        cmd_book_open_page_variant('\ueede'),
        cmd_book_open_variant('\ue9be'),
        cmd_book_outline('\uf467'),
        cmd_book_play('\uf785'),
        cmd_book_play_outline('\uf786'),
        cmd_book_plus('\ueedf'),
        cmd_book_plus_multiple('\uf394'),
        cmd_book_plus_multiple_outline('\uf3dd'),
        cmd_book_remove('\uf396'),
        cmd_book_remove_multiple('\uf395'),
        cmd_book_remove_multiple_outline('\uedcf'),
        cmd_book_search('\uf787'),
        cmd_book_search_outline('\uf788'),
        cmd_book_variant('\ue9bf'),
        cmd_book_variant_multiple('\ue9bc'),
        cmd_bookmark('\ue9c0'),
        cmd_bookmark_check('\ue9c1'),
        cmd_bookmark_check_outline('\ufc7b'),
        cmd_bookmark_minus('\uf2cb'),
        cmd_bookmark_minus_outline('\uf2cc'),
        cmd_bookmark_multiple('\uf718'),
        cmd_bookmark_multiple_outline('\uf719'),
        cmd_bookmark_music('\ue9c2'),
        cmd_bookmark_music_outline('\ufc79'),
        cmd_bookmark_off('\uf2cd'),
        cmd_bookmark_off_outline('\uf2ce'),
        cmd_bookmark_outline('\ue9c3'),
        cmd_bookmark_plus('\ue9c5'),
        cmd_bookmark_plus_outline('\ue9c4'),
        cmd_bookmark_remove('\ue9c6'),
        cmd_bookmark_remove_outline('\ufc7a'),
        cmd_bookshelf('\ufb5f'),
        cmd_boom_gate('\uf789'),
        cmd_boom_gate_alert('\uf78a'),
        cmd_boom_gate_alert_outline('\uf78b'),
        cmd_boom_gate_down('\uf78c'),
        cmd_boom_gate_down_outline('\uf78d'),
        cmd_boom_gate_outline('\uf78e'),
        cmd_boom_gate_up('\uf78f'),
        cmd_boom_gate_up_outline('\uf790'),
        cmd_boombox('\ueee0'),
        cmd_boomerang('\uf9cf'),
        cmd_bootstrap('\uefc9'),
        cmd_border_all('\ue9c7'),
        cmd_border_all_variant('\uf1a1'),
        cmd_border_bottom('\ue9c8'),
        cmd_border_bottom_variant('\uf1a2'),
        cmd_border_color('\ue9c9'),
        cmd_border_horizontal('\ue9ca'),
        cmd_border_inside('\ue9cb'),
        cmd_border_left('\ue9cc'),
        cmd_border_left_variant('\uf1a3'),
        cmd_border_none('\ue9cd'),
        cmd_border_none_variant('\uf1a4'),
        cmd_border_outside('\ue9ce'),
        cmd_border_right('\ue9cf'),
        cmd_border_right_variant('\uf1a5'),
        cmd_border_style('\ue9d0'),
        cmd_border_top('\ue9d1'),
        cmd_border_top_variant('\uf1a6'),
        cmd_border_vertical('\ue9d2'),
        cmd_bottle_soda('\uf973'),
        cmd_bottle_soda_classic('\uf974'),
        cmd_bottle_soda_classic_outline('\ufc63'),
        cmd_bottle_soda_outline('\uf975'),
        cmd_bottle_tonic('\ufa2e'),
        cmd_bottle_tonic_outline('\ufa2f'),
        cmd_bottle_tonic_plus('\ufa30'),
        cmd_bottle_tonic_plus_outline('\ufa31'),
        cmd_bottle_tonic_skull('\ufa32'),
        cmd_bottle_tonic_skull_outline('\ufa33'),
        cmd_bottle_wine('\uf155'),
        cmd_bottle_wine_outline('\ufc10'),
        cmd_bow_tie('\uef7b'),
        cmd_bowl('\ueb92'),
        cmd_bowl_mix('\uef1a'),
        cmd_bowl_mix_outline('\uebe9'),
        cmd_bowl_outline('\uebad'),
        cmd_bowling('\ue9d3'),
        cmd_box('\ue9d4'),
        cmd_box_cutter('\ue9d5'),
        cmd_box_cutter_off('\uf44d'),
        cmd_box_shadow('\uef3a'),
        cmd_boxing_glove('\uf468'),
        cmd_braille('\uf2cf'),
        cmd_brain('\uf2d0'),
        cmd_bread_slice('\uf5f1'),
        cmd_bread_slice_outline('\uf5f2'),
        cmd_bridge('\uef1b'),
        cmd_briefcase('\ue9d6'),
        cmd_briefcase_account('\uf5f3'),
        cmd_briefcase_account_outline('\uf5f4'),
        cmd_briefcase_check('\ue9d7'),
        cmd_briefcase_check_outline('\ufc1e'),
        cmd_briefcase_clock('\uf9d0'),
        cmd_briefcase_clock_outline('\uf9d1'),
        cmd_briefcase_download('\ue9d8'),
        cmd_briefcase_download_outline('\uf542'),
        cmd_briefcase_edit('\uf397'),
        cmd_briefcase_edit_outline('\uf543'),
        cmd_briefcase_minus('\uf329'),
        cmd_briefcase_minus_outline('\uf544'),
        cmd_briefcase_outline('\uf115'),
        cmd_briefcase_plus('\uf32a'),
        cmd_briefcase_plus_outline('\uf545'),
        cmd_briefcase_remove('\uf32b'),
        cmd_briefcase_remove_outline('\uf546'),
        cmd_briefcase_search('\uf32c'),
        cmd_briefcase_search_outline('\uf547'),
        cmd_briefcase_upload('\ue9d9'),
        cmd_briefcase_upload_outline('\uf548'),
        cmd_brightness_1('\ue9da'),
        cmd_brightness_2('\ue9db'),
        cmd_brightness_3('\ue9dc'),
        cmd_brightness_4('\ue9dd'),
        cmd_brightness_5('\ue9de'),
        cmd_brightness_6('\ue9df'),
        cmd_brightness_7('\ue9e0'),
        cmd_brightness_auto('\ue9e1'),
        cmd_brightness_percent('\uf5f5'),
        cmd_broom('\ue9e2'),
        cmd_brush('\ue9e3'),
        cmd_buddhism('\uf24a'),
        cmd_buffer('\uef1c'),
        cmd_buffet('\uee7c'),
        cmd_bug('\ue9e4'),
        cmd_bug_check('\uf32d'),
        cmd_bug_check_outline('\uf32e'),
        cmd_bug_outline('\uf32f'),
        cmd_bugle('\uf6b7'),
        cmd_bulldozer('\uf426'),
        cmd_bullet('\uf5f6'),
        cmd_bulletin_board('\ue9e5'),
        cmd_bullhorn('\ue9e6'),
        cmd_bullhorn_outline('\uf427'),
        cmd_bullseye('\ueee1'),
        cmd_bullseye_arrow('\uf1c9'),
        cmd_bulma('\ufbe7'),
        cmd_bunk_bed('\ufc02'),
        cmd_bunk_bed_outline('\ue997'),
        cmd_bus('\ue9e7'),
        cmd_bus_alert('\uf398'),
        cmd_bus_articulated_end('\uf09d'),
        cmd_bus_articulated_front('\uf09e'),
        cmd_bus_clock('\uf1ca'),
        cmd_bus_double_decker('\uf09f'),
        cmd_bus_marker('\ufb12'),
        cmd_bus_multiple('\uf842'),
        cmd_bus_school('\uf0a0'),
        cmd_bus_side('\uf0a1'),
        cmd_bus_stop('\uf915'),
        cmd_bus_stop_covered('\uf916'),
        cmd_bus_stop_uncovered('\uf917'),
        cmd_cable_data('\ufc94'),
        cmd_cached('\ue9e8'),
        cmd_cactus('\uf6b8'),
        cmd_cake('\ue9e9'),
        cmd_cake_layered('\ue9ea'),
        cmd_cake_variant('\ue9eb'),
        cmd_calculator('\ue9ec'),
        cmd_calculator_variant('\uf399'),
        cmd_calendar('\ue9ed'),
        cmd_calendar_account('\uf7da'),
        cmd_calendar_account_outline('\uf7db'),
        cmd_calendar_alert('\uf330'),
        cmd_calendar_arrow_left('\ufa34'),
        cmd_calendar_arrow_right('\ufa35'),
        cmd_calendar_blank('\ue9ee'),
        cmd_calendar_blank_multiple('\uf976'),
        cmd_calendar_blank_outline('\uf469'),
        cmd_calendar_check('\ue9ef'),
        cmd_calendar_check_outline('\uf549'),
        cmd_calendar_clock('\ue9f0'),
        cmd_calendar_edit('\uf1a7'),
        cmd_calendar_export('\uf428'),
        cmd_calendar_heart('\uf2d1'),
        cmd_calendar_import('\uf429'),
        cmd_calendar_minus('\uf65f'),
        cmd_calendar_month('\uf71a'),
        cmd_calendar_month_outline('\uf71b'),
        cmd_calendar_multiple('\ue9f1'),
        cmd_calendar_multiple_check('\ue9f2'),
        cmd_calendar_multiselect('\uf331'),
        cmd_calendar_outline('\uf46a'),
        cmd_calendar_plus('\ue9f3'),
        cmd_calendar_question('\uef95'),
        cmd_calendar_range('\uef7c'),
        cmd_calendar_range_outline('\uf46b'),
        cmd_calendar_refresh('\ueae4'),
        cmd_calendar_refresh_outline('\ueb06'),
        cmd_calendar_remove('\ue9f4'),
        cmd_calendar_remove_outline('\uf54a'),
        cmd_calendar_search('\uf24b'),
        cmd_calendar_star('\uf2d2'),
        cmd_calendar_sync('\uf791'),
        cmd_calendar_sync_outline('\uf792'),
        cmd_calendar_text('\ue9f5'),
        cmd_calendar_text_outline('\uf54b'),
        cmd_calendar_today('\ue9f6'),
        cmd_calendar_week('\uf332'),
        cmd_calendar_week_begin('\uf333'),
        cmd_calendar_weekend('\uf7dc'),
        cmd_calendar_weekend_outline('\uf7dd'),
        cmd_call_made('\ue9f7'),
        cmd_call_merge('\ue9f8'),
        cmd_call_missed('\ue9f9'),
        cmd_call_received('\ue9fa'),
        cmd_call_split('\ue9fb'),
        cmd_camcorder('\ue9fc'),
        cmd_camcorder_off('\ue9ff'),
        cmd_camera('\uea00'),
        cmd_camera_account('\uf1cb'),
        cmd_camera_burst('\uef96'),
        cmd_camera_control('\uf46c'),
        cmd_camera_enhance('\uea01'),
        cmd_camera_enhance_outline('\uf46d'),
        cmd_camera_front('\uea02'),
        cmd_camera_front_variant('\uea03'),
        cmd_camera_gopro('\uf0a2'),
        cmd_camera_image('\uf1cc'),
        cmd_camera_iris('\uea04'),
        cmd_camera_metering_center('\uf0a3'),
        cmd_camera_metering_matrix('\uf0a4'),
        cmd_camera_metering_partial('\uf0a5'),
        cmd_camera_metering_spot('\uf0a6'),
        cmd_camera_off('\ueee3'),
        cmd_camera_outline('\uf660'),
        cmd_camera_party_mode('\uea05'),
        cmd_camera_plus('\uf7de'),
        cmd_camera_plus_outline('\uf7df'),
        cmd_camera_rear('\uea06'),
        cmd_camera_rear_variant('\uea07'),
        cmd_camera_retake('\uf71c'),
        cmd_camera_retake_outline('\uf71d'),
        cmd_camera_switch('\uea08'),
        cmd_camera_switch_outline('\uf14b'),
        cmd_camera_timer('\uea09'),
        cmd_camera_wireless('\uf6b9'),
        cmd_camera_wireless_outline('\uf6ba'),
        cmd_campfire('\uf7e0'),
        cmd_cancel('\uf03d'),
        cmd_candle('\ueee6'),
        cmd_candycane('\uea0a'),
        cmd_cannabis('\uf0a7'),
        cmd_caps_lock('\uf39a'),
        cmd_car('\uea0b'),
        cmd_car_2_plus('\uf918'),
        cmd_car_3_plus('\uf919'),
        cmd_car_arrow_left('\ufcb1'),
        cmd_car_arrow_right('\ufcb2'),
        cmd_car_back('\uf71e'),
        cmd_car_battery('\uea0c'),
        cmd_car_brake_abs('\uf54c'),
        cmd_car_brake_alert('\uf54d'),
        cmd_car_brake_hold('\uf661'),
        cmd_car_brake_parking('\uf662'),
        cmd_car_brake_retarder('\uf91a'),
        cmd_car_child_seat('\uf8a6'),
        cmd_car_clutch('\uf91b'),
        cmd_car_connected('\uea0d'),
        cmd_car_convertible('\uf0a8'),
        cmd_car_coolant_level('\uf91c'),
        cmd_car_cruise_control('\uf663'),
        cmd_car_defrost_front('\uf664'),
        cmd_car_defrost_rear('\uf665'),
        cmd_car_door('\uf46e'),
        cmd_car_door_lock('\uf99d'),
        cmd_car_electric('\uf46f'),
        cmd_car_esp('\uf54e'),
        cmd_car_estate('\uf0a9'),
        cmd_car_hatchback('\uf0aa'),
        cmd_car_info('\ufabe'),
        cmd_car_key('\uf470'),
        cmd_car_light_dimmed('\uf54f'),
        cmd_car_light_fog('\uf550'),
        cmd_car_light_high('\uf551'),
        cmd_car_limousine('\uf1cd'),
        cmd_car_multiple('\uf471'),
        cmd_car_off('\uf71f'),
        cmd_car_parking_lights('\uf666'),
        cmd_car_pickup('\uf0ab'),
        cmd_car_seat('\uf8a7'),
        cmd_car_seat_cooler('\uf8a8'),
        cmd_car_seat_heater('\uf8a9'),
        cmd_car_shift_pattern('\uf843'),
        cmd_car_side('\uf0ac'),
        cmd_car_sports('\uf0ad'),
        cmd_car_tire_alert('\uf552'),
        cmd_car_traction_control('\uf667'),
        cmd_car_turbocharger('\uf91d'),
        cmd_car_wash('\uea0e'),
        cmd_car_windshield('\uf91e'),
        cmd_car_windshield_outline('\uf91f'),
        cmd_caravan('\uf0ae'),
        cmd_card('\uf472'),
        cmd_card_account_details('\ueed6'),
        cmd_card_account_details_outline('\uf6ae'),
        cmd_card_account_details_star('\ueba7'),
        cmd_card_account_details_star_outline('\uefde'),
        cmd_card_account_mail('\uea91'),
        cmd_card_account_mail_outline('\uf79b'),
        cmd_card_account_phone('\uf79c'),
        cmd_card_account_phone_outline('\uf79d'),
        cmd_card_bulleted('\uf473'),
        cmd_card_bulleted_off('\uf474'),
        cmd_card_bulleted_off_outline('\uf475'),
        cmd_card_bulleted_outline('\uf476'),
        cmd_card_bulleted_settings('\uf477'),
        cmd_card_bulleted_settings_outline('\uf478'),
        cmd_card_outline('\uf479'),
        cmd_card_plus('\ufaff'),
        cmd_card_plus_outline('\ufb00'),
        cmd_card_search('\uf977'),
        cmd_card_search_outline('\uf978'),
        cmd_card_text('\uf47a'),
        cmd_card_text_outline('\uf47b'),
        cmd_cards('\uef3b'),
        cmd_cards_club('\uf1ce'),
        cmd_cards_diamond('\uf1cf'),
        cmd_cards_diamond_outline('\uf920'),
        cmd_cards_outline('\uef3c'),
        cmd_cards_playing_outline('\uef3d'),
        cmd_cards_spade('\uf1d0'),
        cmd_cards_variant('\uefca'),
        cmd_carrot('\uea0f'),
        cmd_cart('\uea10'),
        cmd_cart_arrow_down('\uf669'),
        cmd_cart_arrow_right('\uf553'),
        cmd_cart_arrow_up('\uf66a'),
        cmd_cart_minus('\uf66b'),
        cmd_cart_off('\uef6e'),
        cmd_cart_outline('\uea11'),
        cmd_cart_plus('\uea12'),
        cmd_cart_remove('\uf66c'),
        cmd_case_sensitive_alt('\uea13'),
        cmd_cash('\uea14'),
        cmd_cash_100('\uea15'),
        cmd_cash_marker('\uf6bb'),
        cmd_cash_minus('\ufb60'),
        cmd_cash_multiple('\uea16'),
        cmd_cash_plus('\ufb61'),
        cmd_cash_refund('\uf39b'),
        cmd_cash_register('\uf5f7'),
        cmd_cash_remove('\ufb62'),
        cmd_cash_usd('\ufa76'),
        cmd_cash_usd_outline('\uea17'),
        cmd_cassette('\uf2d3'),
        cmd_cast('\uea18'),
        cmd_cast_audio('\uf921'),
        cmd_cast_connected('\uea19'),
        cmd_cast_education('\uf720'),
        cmd_cast_off('\uf08b'),
        cmd_castle('\uea1a'),
        cmd_cat('\uea1b'),
        cmd_cctv('\uf0af'),
        cmd_ceiling_light('\uf06a'),
        cmd_cellphone('\uea1c'),
        cmd_cellphone_android('\uea1d'),
        cmd_cellphone_arrow_down('\uf2d4'),
        cmd_cellphone_basic('\uea1e'),
        cmd_cellphone_charging('\ufc97'),
        cmd_cellphone_cog('\uf250'),
        cmd_cellphone_dock('\uea1f'),
        cmd_cellphone_erase('\uf24c'),
        cmd_cellphone_information('\uf844'),
        cmd_cellphone_iphone('\uea20'),
        cmd_cellphone_key('\uf24d'),
        cmd_cellphone_link('\uea21'),
        cmd_cellphone_link_off('\uea22'),
        cmd_cellphone_lock('\uf24e'),
        cmd_cellphone_message('\uf1d2'),
        cmd_cellphone_message_off('\uf9d2'),
        cmd_cellphone_nfc('\uf793'),
        cmd_cellphone_nfc_off('\ufbd8'),
        cmd_cellphone_off('\uf24f'),
        cmd_cellphone_play('\uf922'),
        cmd_cellphone_screenshot('\uf334'),
        cmd_cellphone_settings('\uea23'),
        cmd_cellphone_sound('\uf251'),
        cmd_cellphone_text('\uf1d1'),
        cmd_cellphone_wireless('\uf116'),
        cmd_celtic_cross('\uf5f8'),
        cmd_centos('\ufa1a'),
        cmd_certificate('\uea24'),
        cmd_certificate_outline('\ufa88'),
        cmd_chair_rolling('\uf84b'),
        cmd_chair_school('\uea25'),
        cmd_charity('\uf554'),
        cmd_chart_arc('\uea26'),
        cmd_chart_areaspline('\uea27'),
        cmd_chart_areaspline_variant('\uf794'),
        cmd_chart_bar('\uea28'),
        cmd_chart_bar_stacked('\uf06b'),
        cmd_chart_bell_curve('\uf555'),
        cmd_chart_bell_curve_cumulative('\uf8aa'),
        cmd_chart_bubble('\ueee7'),
        cmd_chart_donut('\uf0b0'),
        cmd_chart_donut_variant('\uf0b1'),
        cmd_chart_gantt('\uef6f'),
        cmd_chart_histogram('\uea29'),
        cmd_chart_line('\uea2a'),
        cmd_chart_line_stacked('\uf06c'),
        cmd_chart_line_variant('\uf0b2'),
        cmd_chart_multiline('\uf1d3'),
        cmd_chart_multiple('\ufb13'),
        cmd_chart_pie('\uea2b'),
        cmd_chart_ppf('\ufc80'),
        cmd_chart_sankey('\ufadf'),
        cmd_chart_sankey_variant('\ufae0'),
        cmd_chart_scatter_plot('\uf795'),
        cmd_chart_scatter_plot_hexbin('\uef70'),
        cmd_chart_timeline('\uef71'),
        cmd_chart_timeline_variant('\uf796'),
        cmd_chart_tree('\uf797'),
        cmd_chat('\uf47c'),
        cmd_chat_alert('\uf47d'),
        cmd_chat_alert_outline('\ufbc9'),
        cmd_chat_outline('\uf7e1'),
        cmd_chat_processing('\uf47e'),
        cmd_chat_processing_outline('\ufbca'),
        cmd_chat_sleep('\ufbd1'),
        cmd_chat_sleep_outline('\ufbd2'),
        cmd_check('\uea2c'),
        cmd_check_all('\uea2d'),
        cmd_check_bold('\uf721'),
        cmd_check_box_multiple_outline('\uf556'),
        cmd_check_box_outline('\uf557'),
        cmd_check_circle('\ueee4'),
        cmd_check_circle_outline('\ueee5'),
        cmd_check_decagram('\uf092'),
        cmd_check_network('\uf558'),
        cmd_check_network_outline('\uf559'),
        cmd_check_outline('\uf156'),
        cmd_check_underline('\uf722'),
        cmd_check_underline_circle('\uf723'),
        cmd_check_underline_circle_outline('\uf724'),
        cmd_checkbook('\uf39c'),
        cmd_checkbox_blank('\uea2e'),
        cmd_checkbox_blank_circle('\uea2f'),
        cmd_checkbox_blank_circle1('\uea30'),
        cmd_checkbox_blank_circle_outline('\uea31'),
        cmd_checkbox_blank_circle_outline1('\uea32'),
        cmd_checkbox_blank_circle_outline2('\uea33'),
        cmd_checkbox_blank_off('\ufbec'),
        cmd_checkbox_blank_off_outline('\ufbed'),
        cmd_checkbox_blank_outline('\uea34'),
        cmd_checkbox_intermediate('\uf157'),
        cmd_checkbox_marked('\uea35'),
        cmd_checkbox_marked_circle('\uea36'),
        cmd_checkbox_marked_circle_outline('\uea37'),
        cmd_checkbox_marked_outline('\uea38'),
        cmd_checkbox_multiple_blank('\uea39'),
        cmd_checkbox_multiple_blank_circle('\uef3e'),
        cmd_checkbox_multiple_blank_circle_outline('\uef3f'),
        cmd_checkbox_multiple_blank_outline('\uea3a'),
        cmd_checkbox_multiple_marked('\uea3b'),
        cmd_checkbox_multiple_marked_circle('\uef40'),
        cmd_checkbox_multiple_marked_circle_outline('\uef41'),
        cmd_checkbox_multiple_marked_outline('\uea3c'),
        cmd_checkerboard('\uea3d'),
        cmd_checkerboard_minus('\ufb02'),
        cmd_checkerboard_plus('\ufb01'),
        cmd_checkerboard_remove('\ufb03'),
        cmd_cheese('\ufbb9'),
        cmd_chef_hat('\uf47f'),
        cmd_chemical_weapon('\uea3e'),
        cmd_chess_bishop('\uf15d'),
        cmd_chess_king('\uf158'),
        cmd_chess_knight('\uf159'),
        cmd_chess_pawn('\uf15a'),
        cmd_chess_queen('\uf15b'),
        cmd_chess_rook('\uf15c'),
        cmd_chevron_double_down('\uea3f'),
        cmd_chevron_double_left('\uea40'),
        cmd_chevron_double_right('\uea41'),
        cmd_chevron_double_up('\uea42'),
        cmd_chevron_down('\uea43'),
        cmd_chevron_down_box('\uf2d5'),
        cmd_chevron_down_box_outline('\uf2d6'),
        cmd_chevron_down_circle('\uf42a'),
        cmd_chevron_down_circle_outline('\uf42b'),
        cmd_chevron_left('\uea44'),
        cmd_chevron_left_box('\uf2d7'),
        cmd_chevron_left_box_outline('\uf2d8'),
        cmd_chevron_left_circle('\uf42c'),
        cmd_chevron_left_circle_outline('\uf42d'),
        cmd_chevron_right('\uea45'),
        cmd_chevron_right_box('\uf2d9'),
        cmd_chevron_right_box_outline('\uf2da'),
        cmd_chevron_right_circle('\uf42e'),
        cmd_chevron_right_circle_outline('\uf42f'),
        cmd_chevron_triple_down('\uf6bc'),
        cmd_chevron_triple_left('\uf6bd'),
        cmd_chevron_triple_right('\uf6be'),
        cmd_chevron_triple_up('\uf6bf'),
        cmd_chevron_up('\uea46'),
        cmd_chevron_up_box('\uf2db'),
        cmd_chevron_up_box_outline('\uf2dc'),
        cmd_chevron_up_circle('\uf430'),
        cmd_chevron_up_circle_outline('\uf431'),
        cmd_chili_hot('\uf0b3'),
        cmd_chili_medium('\uf0b4'),
        cmd_chili_mild('\uf0b5'),
        cmd_chip('\uef1d'),
        cmd_christianity('\uf252'),
        cmd_christianity_outline('\uf5f9'),
        cmd_church('\uea47'),
        cmd_cigar('\ufa89'),
        cmd_circle_double('\uf798'),
        cmd_circle_edit_outline('\uf1d4'),
        cmd_circle_expand('\uf799'),
        cmd_circle_half('\ufc95'),
        cmd_circle_half_full('\ufc96'),
        cmd_circle_medium('\uf2dd'),
        cmd_circle_multiple('\uf43c'),
        cmd_circle_multiple_outline('\uef98'),
        cmd_circle_off_outline('\uf9d3'),
        cmd_circle_slice_1('\uf39d'),
        cmd_circle_slice_2('\uf39e'),
        cmd_circle_slice_3('\uf39f'),
        cmd_circle_slice_4('\uf3a0'),
        cmd_circle_slice_5('\uf3a1'),
        cmd_circle_slice_6('\uf3a2'),
        cmd_circle_slice_7('\uf3a3'),
        cmd_circle_slice_8('\uf3a4'),
        cmd_circle_small('\uf2de'),
        cmd_circular_saw('\uf725'),
        cmd_city('\uea49'),
        cmd_city_variant('\uf335'),
        cmd_city_variant_outline('\uf336'),
        cmd_clipboard('\uea4a'),
        cmd_clipboard_account('\uea4b'),
        cmd_clipboard_account_outline('\uf55a'),
        cmd_clipboard_alert('\uea4c'),
        cmd_clipboard_alert_outline('\uf5fa'),
        cmd_clipboard_arrow_down('\uea4d'),
        cmd_clipboard_arrow_down_outline('\uf55b'),
        cmd_clipboard_arrow_left('\uea4e'),
        cmd_clipboard_arrow_left_outline('\uf5fb'),
        cmd_clipboard_arrow_right('\uf5fc'),
        cmd_clipboard_arrow_right_outline('\uf5fd'),
        cmd_clipboard_arrow_up('\uf55c'),
        cmd_clipboard_arrow_up_outline('\uf55d'),
        cmd_clipboard_check('\uea51'),
        cmd_clipboard_check_multiple('\ufb63'),
        cmd_clipboard_check_multiple_outline('\ufb64'),
        cmd_clipboard_check_outline('\uf1a8'),
        cmd_clipboard_file('\ufb65'),
        cmd_clipboard_file_outline('\ufb66'),
        cmd_clipboard_flow('\uefcb'),
        cmd_clipboard_flow_outline('\ufa17'),
        cmd_clipboard_list('\uf9d4'),
        cmd_clipboard_list_outline('\uf9d5'),
        cmd_clipboard_multiple('\ufb67'),
        cmd_clipboard_multiple_outline('\ufb68'),
        cmd_clipboard_outline('\uea4f'),
        cmd_clipboard_play('\uf55e'),
        cmd_clipboard_play_multiple('\ufb69'),
        cmd_clipboard_play_multiple_outline('\ufb6a'),
        cmd_clipboard_play_outline('\uf55f'),
        cmd_clipboard_plus('\uf054'),
        cmd_clipboard_plus_outline('\ufc1f'),
        cmd_clipboard_pulse('\uf15e'),
        cmd_clipboard_pulse_outline('\uf15f'),
        cmd_clipboard_text('\uea50'),
        cmd_clipboard_text_multiple('\ufb6b'),
        cmd_clipboard_text_multiple_outline('\ufb6c'),
        cmd_clipboard_text_outline('\uf337'),
        cmd_clipboard_text_play('\uf560'),
        cmd_clipboard_text_play_outline('\uf561'),
        cmd_clippy('\uea52'),
        cmd_clock('\uf253'),
        cmd_clock_alert('\uf254'),
        cmd_clock_alert_outline('\ueed2'),
        cmd_clock_check('\uf8ab'),
        cmd_clock_check_outline('\uf8ac'),
        cmd_clock_digital('\uf79a'),
        cmd_clock_end('\uea54'),
        cmd_clock_fast('\uea55'),
        cmd_clock_in('\uea56'),
        cmd_clock_out('\uea57'),
        cmd_clock_outline('\uea53'),
        cmd_clock_start('\uea58'),
        cmd_close('\uea59'),
        cmd_close_box('\uea5a'),
        cmd_close_box_multiple('\uf562'),
        cmd_close_box_multiple_outline('\uf563'),
        cmd_close_box_outline('\uea5b'),
        cmd_close_circle('\uea5c'),
        cmd_close_circle_multiple('\uef2d'),
        cmd_close_circle_multiple_outline('\uf184'),
        cmd_close_circle_outline('\uea5d'),
        cmd_close_network('\uea5e'),
        cmd_close_network_outline('\uf564'),
        cmd_close_octagon('\uea5f'),
        cmd_close_octagon_outline('\uea60'),
        cmd_close_outline('\uefcc'),
        cmd_close_thick('\ufc98'),
        cmd_closed_caption('\uea61'),
        cmd_closed_caption_outline('\uf6c0'),
        cmd_cloud('\uea62'),
        cmd_cloud_alert('\uf2df'),
        cmd_cloud_braces('\uf0b6'),
        cmd_cloud_check('\uea63'),
        cmd_cloud_check_outline('\ufbcc'),
        cmd_cloud_circle('\uea64'),
        cmd_cloud_download('\uea65'),
        cmd_cloud_download_outline('\uf480'),
        cmd_cloud_lock('\ufaf1'),
        cmd_cloud_lock_outline('\ufaf2'),
        cmd_cloud_off_outline('\uea67'),
        cmd_cloud_outline('\uea66'),
        cmd_cloud_print('\uea68'),
        cmd_cloud_print_outline('\uea69'),
        cmd_cloud_question('\uf338'),
        cmd_cloud_refresh('\uee2e'),
        cmd_cloud_search('\uf255'),
        cmd_cloud_search_outline('\uf256'),
        cmd_cloud_sync('\uef42'),
        cmd_cloud_sync_outline('\ufbd6'),
        cmd_cloud_tags('\uf0b7'),
        cmd_cloud_upload('\uea6a'),
        cmd_cloud_upload_outline('\uf481'),
        cmd_clover('\uf117'),
        cmd_coach_lamp('\uf923'),
        cmd_coat_rack('\uf99e'),
        cmd_code_array('\uea6b'),
        cmd_code_braces('\uea6c'),
        cmd_code_braces_box('\uf9d6'),
        cmd_code_brackets('\uea6d'),
        cmd_code_equal('\uea6e'),
        cmd_code_greater_than('\uea6f'),
        cmd_code_greater_than_or_equal('\uea70'),
        cmd_code_json('\uef29'),
        cmd_code_less_than('\uea71'),
        cmd_code_less_than_or_equal('\uea72'),
        cmd_code_not_equal('\uea73'),
        cmd_code_not_equal_variant('\uea74'),
        cmd_code_parentheses('\uea75'),
        cmd_code_parentheses_box('\uf9d7'),
        cmd_code_string('\uea76'),
        cmd_code_tags('\uea77'),
        cmd_code_tags_check('\uef97'),
        cmd_codepen('\uea78'),
        cmd_coffee('\uea79'),
        cmd_coffee_maker('\uf99f'),
        cmd_coffee_off('\uf8ad'),
        cmd_coffee_off_outline('\uf8ae'),
        cmd_coffee_outline('\uefcd'),
        cmd_coffee_to_go('\uea7a'),
        cmd_coffee_to_go_outline('\ufc0e'),
        cmd_coffin('\uf482'),
        cmd_cog('\ued98'),
        cmd_cog_box('\ued99'),
        cmd_cog_clockwise('\ufadd'),
        cmd_cog_counterclockwise('\ufade'),
        cmd_cog_outline('\uf1bb'),
        cmd_cog_transfer('\uf95e'),
        cmd_cog_transfer_outline('\uf95f'),
        cmd_cogs('\uf1d5'),
        cmd_collage('\uef43'),
        cmd_collapse_all('\uf3a5'),
        cmd_collapse_all_outline('\uf3a6'),
        cmd_color_helper('\uea7c'),
        cmd_comma('\uf726'),
        cmd_comma_box('\uf72e'),
        cmd_comma_box_outline('\uf727'),
        cmd_comma_circle('\uf728'),
        cmd_comma_circle_outline('\uf729'),
        cmd_comment('\uea7d'),
        cmd_comment_account('\uea7e'),
        cmd_comment_account_outline('\uea7f'),
        cmd_comment_alert('\uea80'),
        cmd_comment_alert_outline('\uea81'),
        cmd_comment_arrow_left('\uf2e0'),
        cmd_comment_arrow_left_outline('\uf2e1'),
        cmd_comment_arrow_right('\uf2e2'),
        cmd_comment_arrow_right_outline('\uf2e3'),
        cmd_comment_check('\uea82'),
        cmd_comment_check_outline('\uea83'),
        cmd_comment_edit('\ufabf'),
        cmd_comment_edit_outline('\ufbc4'),
        cmd_comment_eye('\uf339'),
        cmd_comment_eye_outline('\uf33a'),
        cmd_comment_multiple('\uf160'),
        cmd_comment_multiple_outline('\uea84'),
        cmd_comment_outline('\uea85'),
        cmd_comment_plus('\uf2e4'),
        cmd_comment_plus_outline('\uea86'),
        cmd_comment_processing('\uea87'),
        cmd_comment_processing_outline('\uea88'),
        cmd_comment_question('\uf118'),
        cmd_comment_question_outline('\uea89'),
        cmd_comment_quote('\uf924'),
        cmd_comment_quote_outline('\uf925'),
        cmd_comment_remove('\ueee2'),
        cmd_comment_remove_outline('\uea8a'),
        cmd_comment_search('\uf33b'),
        cmd_comment_search_outline('\uf33c'),
        cmd_comment_text('\uea8b'),
        cmd_comment_text_multiple('\uf161'),
        cmd_comment_text_multiple_outline('\uf162'),
        cmd_comment_text_outline('\uea8c'),
        cmd_compare('\uea8d'),
        cmd_compass('\uea8e'),
        cmd_compass_off('\uf483'),
        cmd_compass_off_outline('\uf484'),
        cmd_compass_outline('\uea8f'),
        cmd_compass_rose('\ufc82'),
        cmd_concourse_ci('\uf9a0'),
        cmd_console('\uea90'),
        cmd_console_line('\uf0b8'),
        cmd_console_network('\uf1a9'),
        cmd_console_network_outline('\uf565'),
        cmd_consolidate('\uf9d8'),
        cmd_contactless_payment('\uf66d'),
        cmd_contactless_payment_circle('\uec27'),
        cmd_contactless_payment_circle_outline('\ued0e'),
        cmd_contacts('\uefce'),
        cmd_contacts_outline('\ueebc'),
        cmd_contain('\uf33d'),
        cmd_contain_end('\uf33e'),
        cmd_contain_start('\uf33f'),
        cmd_content_copy('\uea92'),
        cmd_content_cut('\uea93'),
        cmd_content_duplicate('\uea94'),
        cmd_content_paste('\uea95'),
        cmd_content_save('\uea96'),
        cmd_content_save_alert('\uf845'),
        cmd_content_save_alert_outline('\uf846'),
        cmd_content_save_all('\uea97'),
        cmd_content_save_all_outline('\uf847'),
        cmd_content_save_edit('\uf5fe'),
        cmd_content_save_edit_outline('\uf5ff'),
        cmd_content_save_move('\uf72a'),
        cmd_content_save_move_outline('\uf72b'),
        cmd_content_save_outline('\uf119'),
        cmd_content_save_settings('\uef1e'),
        cmd_content_save_settings_outline('\uf432'),
        cmd_contrast('\uea98'),
        cmd_contrast_box('\uea99'),
        cmd_contrast_circle('\uea9a'),
        cmd_controller_classic('\uf485'),
        cmd_controller_classic_outline('\uf486'),
        cmd_cookie('\uea9b'),
        cmd_coolant_temperature('\uecce'),
        cmd_copyright('\ueeea'),
        cmd_cordova('\uf257'),
        cmd_corn('\uf0b9'),
        cmd_counter('\uea9c'),
        cmd_cow('\uea9d'),
        cmd_cpu_32_bit('\uf7e2'),
        cmd_cpu_64_bit('\uf7e3'),
        cmd_crane('\uf163'),
        cmd_creation('\uef77'),
        cmd_creative_commons('\uf66e'),
        cmd_credit_card('\uf8f2'),
        cmd_credit_card_clock('\uf7e4'),
        cmd_credit_card_clock_outline('\uf7e5'),
        cmd_credit_card_marker('\uefab'),
        cmd_credit_card_marker_outline('\uf6c1'),
        cmd_credit_card_minus('\uf8af'),
        cmd_credit_card_minus_outline('\uf8b0'),
        cmd_credit_card_multiple('\uf8f3'),
        cmd_credit_card_multiple_outline('\uea9f'),
        cmd_credit_card_off('\uf8f4'),
        cmd_credit_card_off_outline('\ueee8'),
        cmd_credit_card_outline('\uea9e'),
        cmd_credit_card_plus('\uf8f5'),
        cmd_credit_card_plus_outline('\uef79'),
        cmd_credit_card_refund('\uf8f6'),
        cmd_credit_card_refund_outline('\uf3a7'),
        cmd_credit_card_remove('\uf8b1'),
        cmd_credit_card_remove_outline('\uf8b2'),
        cmd_credit_card_scan('\uf8f7'),
        cmd_credit_card_scan_outline('\ueaa0'),
        cmd_credit_card_settings('\uf8f8'),
        cmd_credit_card_settings_outline('\uf1d6'),
        cmd_credit_card_wireless('\uf103'),
        cmd_credit_card_wireless_off('\uee7e'),
        cmd_credit_card_wireless_off_outline('\uee7f'),
        cmd_credit_card_wireless_outline('\uf66f'),
        cmd_cricket('\uf670'),
        cmd_crop('\ueaa1'),
        cmd_crop_free('\ueaa2'),
        cmd_crop_landscape('\ueaa3'),
        cmd_crop_portrait('\ueaa4'),
        cmd_crop_rotate('\uef99'),
        cmd_crop_square('\ueaa5'),
        cmd_crosshairs('\ueaa6'),
        cmd_crosshairs_gps('\ueaa7'),
        cmd_crosshairs_off('\uf848'),
        cmd_crosshairs_question('\ufa36'),
        cmd_crown('\ueaa8'),
        cmd_crown_outline('\ufad0'),
        cmd_cryengine('\uf258'),
        cmd_crystal_ball('\uf433'),
        cmd_cube('\ueaa9'),
        cmd_cube_outline('\ueaaa'),
        cmd_cube_scan('\uf487'),
        cmd_cube_send('\ueaab'),
        cmd_cube_unfolded('\ueaac'),
        cmd_cup('\ueaad'),
        cmd_cup_off('\ueee9'),
        cmd_cup_off_outline('\ufc7d'),
        cmd_cup_outline('\ufc0f'),
        cmd_cup_water('\ueaae'),
        cmd_cupboard('\uf849'),
        cmd_cupboard_outline('\uf84a'),
        cmd_cupcake('\uf259'),
        cmd_curling('\uf164'),
        cmd_currency_bdt('\uf165'),
        cmd_currency_brl('\uf488'),
        cmd_currency_btc('\ueaaf'),
        cmd_currency_cny('\uf0bb'),
        cmd_currency_cny1('\uf0bc'),
        cmd_currency_eth('\uf0bd'),
        cmd_currency_eur('\ueab0'),
        cmd_currency_eur_off('\ufc15'),
        cmd_currency_gbp('\ueab1'),
        cmd_currency_ils('\uf566'),
        cmd_currency_inr('\ueab2'),
        cmd_currency_krw('\uf0be'),
        cmd_currency_kzt('\uf166'),
        cmd_currency_ngn('\ueab3'),
        cmd_currency_php('\uf2e5'),
        cmd_currency_rial('\uf79f'),
        cmd_currency_rub('\ueab4'),
        cmd_currency_sign('\uf0bf'),
        cmd_currency_try('\ueab5'),
        cmd_currency_twd('\uf0c0'),
        cmd_currency_usd('\ueac4'),
        cmd_currency_usd_circle('\ufa6b'),
        cmd_currency_usd_circle_outline('\uea7b'),
        cmd_currency_usd_off('\uef7d'),
        cmd_current_ac('\uf25a'),
        cmd_current_dc('\uf25b'),
        cmd_cursor_default('\ueac3'),
        cmd_cursor_default_click('\uf600'),
        cmd_cursor_default_click_outline('\uf601'),
        cmd_cursor_default_gesture('\ufa27'),
        cmd_cursor_default_gesture_outline('\ufa28'),
        cmd_cursor_default_outline('\ueac2'),
        cmd_cursor_move('\ueac1'),
        cmd_cursor_pointer('\ueac0'),
        cmd_cursor_text('\ueeeb'),
        cmd_database('\ueabf'),
        cmd_database_check('\uf3a8'),
        cmd_database_edit('\uf489'),
        cmd_database_export('\uf25d'),
        cmd_database_import('\uf25c'),
        cmd_database_lock('\uf3a9'),
        cmd_database_marker('\ufbf6'),
        cmd_database_minus('\ueabe'),
        cmd_database_plus('\ueabd'),
        cmd_database_refresh('\ueec6'),
        cmd_database_remove('\uf603'),
        cmd_database_search('\uf167'),
        cmd_database_settings('\uf604'),
        cmd_database_sync('\uf602'),
        cmd_death_star('\uf1d7'),
        cmd_death_star_variant('\uf1d8'),
        cmd_deathly_hallows('\uf48a'),
        cmd_debian('\uf1d9'),
        cmd_debug_step_into('\ueabc'),
        cmd_debug_step_out('\ueabb'),
        cmd_debug_step_over('\ueaba'),
        cmd_decagram('\uf06d'),
        cmd_decagram_outline('\uf06e'),
        cmd_decimal('\uf9a1'),
        cmd_decimal_comma('\uf9a2'),
        cmd_decimal_comma_decrease('\uf9a3'),
        cmd_decimal_comma_increase('\uf9a4'),
        cmd_decimal_decrease('\ueab9'),
        cmd_decimal_increase('\ueab8'),
        cmd_delete('\ueab7'),
        cmd_delete_alert('\uf9a5'),
        cmd_delete_alert_outline('\uf9a6'),
        cmd_delete_circle('\uef86'),
        cmd_delete_circle_outline('\uf48b'),
        cmd_delete_empty('\uefcf'),
        cmd_delete_empty_outline('\uf7a0'),
        cmd_delete_forever('\ueeec'),
        cmd_delete_forever_outline('\uf48c'),
        cmd_delete_off('\uf9a7'),
        cmd_delete_off_outline('\uf9a8'),
        cmd_delete_outline('\uf2e6'),
        cmd_delete_restore('\uf11a'),
        cmd_delete_sweep('\ueeed'),
        cmd_delete_sweep_outline('\uf567'),
        cmd_delete_variant('\ueab6'),
        cmd_delta('\ueac5'),
        cmd_desk('\ufb39'),
        cmd_desk_lamp('\uf25e'),
        cmd_deskphone('\ueac6'),
        cmd_desktop_classic('\uf0c1'),
        cmd_desktop_mac('\ueac7'),
        cmd_desktop_mac_dashboard('\uf2e7'),
        cmd_desktop_tower('\ueac8'),
        cmd_desktop_tower_monitor('\uf3aa'),
        cmd_details('\ueac9'),
        cmd_dev_to('\uf671'),
        cmd_developer_board('\uef9a'),
        cmd_deviantart('\ueaca'),
        cmd_devices('\uf8b3'),
        cmd_diabetes('\ufa26'),
        cmd_dialpad('\uef1f'),
        cmd_diameter('\uf568'),
        cmd_diameter_outline('\uf569'),
        cmd_diameter_variant('\uf56a'),
        cmd_diamond('\uf48d'),
        cmd_diamond_outline('\uf48e'),
        cmd_diamond_stone('\ueacb'),
        cmd_dice_1('\ueacd'),
        cmd_dice_1_outline('\ufa4a'),
        cmd_dice_2('\ueace'),
        cmd_dice_2_outline('\ufa4b'),
        cmd_dice_3('\ueacf'),
        cmd_dice_3_outline('\ufa4c'),
        cmd_dice_4('\uead0'),
        cmd_dice_4_outline('\ufa4d'),
        cmd_dice_5('\uead1'),
        cmd_dice_5_outline('\ufa4e'),
        cmd_dice_6('\uead2'),
        cmd_dice_6_outline('\ufa4f'),
        cmd_dice_d10('\ufa53'),
        cmd_dice_d10_outline('\uf070'),
        cmd_dice_d12('\ufa54'),
        cmd_dice_d12_outline('\uf168'),
        cmd_dice_d20('\ufa55'),
        cmd_dice_d20_outline('\ueeee'),
        cmd_dice_d4('\ufa50'),
        cmd_dice_d4_outline('\ueeef'),
        cmd_dice_d6('\ufa51'),
        cmd_dice_d6_outline('\ueef1'),
        cmd_dice_d8('\ufa52'),
        cmd_dice_d8_outline('\ueef0'),
        cmd_dice_multiple('\uf06f'),
        cmd_dice_multiple_outline('\ufa56'),
        cmd_digital_ocean('\ufb37'),
        cmd_dip_switch('\uf0c2'),
        cmd_directions('\uead3'),
        cmd_directions_fork('\uef44'),
        cmd_disc('\ueef2'),
        cmd_disc_alert('\uead4'),
        cmd_disc_player('\uf25f'),
        cmd_discord('\uef72'),
        cmd_dishwasher('\uf3ab'),
        cmd_dishwasher_alert('\ufab8'),
        cmd_dishwasher_off('\ufab9'),
        cmd_disqus('\uead5'),
        cmd_distribute_horizontal_center('\ufac9'),
        cmd_distribute_horizontal_left('\ufac8'),
        cmd_distribute_horizontal_right('\ufaca'),
        cmd_distribute_vertical_bottom('\ufacb'),
        cmd_distribute_vertical_center('\ufacc'),
        cmd_distribute_vertical_top('\ufacd'),
        cmd_diving_flippers('\uf6c2'),
        cmd_diving_helmet('\uf6c3'),
        cmd_diving_scuba('\uf6c4'),
        cmd_diving_scuba_flag('\uf6c5'),
        cmd_diving_scuba_tank('\uf6c6'),
        cmd_diving_scuba_tank_multiple('\uf6c7'),
        cmd_diving_snorkel('\uf6c8'),
        cmd_division('\uead7'),
        cmd_division_box('\uead8'),
        cmd_dlna('\uf340'),
        cmd_dna('\uef87'),
        cmd_dns('\uead9'),
        cmd_dns_outline('\uf48f'),
        cmd_do_not_disturb('\uef9b'),
        cmd_do_not_disturb_off('\uef9c'),
        cmd_dock_bottom('\uf9a9'),
        cmd_dock_left('\uf9aa'),
        cmd_dock_right('\uf9ab'),
        cmd_dock_window('\uf9ac'),
        cmd_docker('\uf169'),
        cmd_doctor('\uf341'),
        cmd_dog('\uf342'),
        cmd_dog_service('\uf3ac'),
        cmd_dog_side('\uf343'),
        cmd_dolby('\uefb6'),
        cmd_dolly('\uf7a1'),
        cmd_domain('\ueada'),
        cmd_domain_off('\uf672'),
        cmd_domain_plus('\uf9ad'),
        cmd_domain_remove('\uf9ae'),
        cmd_domino_mask('\uf926'),
        cmd_donkey('\uf0c3'),
        cmd_door('\uf11b'),
        cmd_door_closed('\uf11c'),
        cmd_door_closed_lock('\uf9af'),
        cmd_door_open('\uf11d'),
        cmd_doorbell('\ufbe6'),
        cmd_doorbell_video('\uf16a'),
        cmd_dot_net('\uf3ad'),
        cmd_dots_horizontal('\ueadb'),
        cmd_dots_horizontal_circle('\uf0c4'),
        cmd_dots_horizontal_circle_outline('\uf490'),
        cmd_dots_vertical('\ueadc'),
        cmd_dots_vertical_circle('\uf0c5'),
        cmd_dots_vertical_circle_outline('\uf491'),
        cmd_douban('\uef9d'),
        cmd_download('\ueadd'),
        cmd_download_lock('\ufc20'),
        cmd_download_lock_outline('\ufc21'),
        cmd_download_multiple('\uf2e8'),
        cmd_download_network('\ueff7'),
        cmd_download_network_outline('\uf56b'),
        cmd_download_off('\uf9b0'),
        cmd_download_off_outline('\uf9b1'),
        cmd_download_outline('\uf492'),
        cmd_drag('\ueade'),
        cmd_drag_horizontal('\ueadf'),
        cmd_drag_horizontal_variant('\ufbf0'),
        cmd_drag_variant('\uf493'),
        cmd_drag_vertical('\ueae0'),
        cmd_drag_vertical_variant('\ufbf1'),
        cmd_drama_masks('\uf605'),
        cmd_draw('\uf84c'),
        cmd_drawing('\ueae1'),
        cmd_drawing_box('\ueae2'),
        cmd_dresser('\uf84d'),
        cmd_dresser_outline('\uf84e'),
        cmd_drone('\ueae5'),
        cmd_dropbox('\ueae6'),
        cmd_drupal('\ueae7'),
        cmd_duck('\ueae8'),
        cmd_dumbbell('\ueae9'),
        cmd_dump_truck('\uf56c'),
        cmd_ear_hearing('\uf0c6'),
        cmd_ear_hearing_off('\uf344'),
        cmd_earth('\ueaea'),
        cmd_earth_arrow_right('\ufc11'),
        cmd_earth_box('\uefd0'),
        cmd_earth_box_off('\uefd1'),
        cmd_earth_off('\ueaeb'),
        cmd_egg('\uf3ae'),
        cmd_egg_easter('\uf3af'),
        cmd_eight_track('\uf2e9'),
        cmd_eject('\ueaed'),
        cmd_eject_outline('\uf494'),
        cmd_electric_switch('\uf7a2'),
        cmd_electric_switch_closed('\uf9d9'),
        cmd_electron_framework('\uf927'),
        cmd_elephant('\uf0c7'),
        cmd_elevation_decline('\ueaee'),
        cmd_elevation_rise('\ueaef'),
        cmd_elevator('\ueaf0'),
        cmd_elevator_down('\ufbc2'),
        cmd_elevator_passenger('\ufc81'),
        cmd_elevator_up('\ufbc1'),
        cmd_ellipse('\uf7a3'),
        cmd_ellipse_outline('\uf7a4'),
        cmd_email('\ueaf1'),
        cmd_email_alert('\uefd2'),
        cmd_email_alert_outline('\uf645'),
        cmd_email_box('\uf606'),
        cmd_email_check('\uf3b0'),
        cmd_email_check_outline('\uf3b1'),
        cmd_email_edit('\uf7e6'),
        cmd_email_edit_outline('\uf7e7'),
        cmd_email_lock('\ueaf4'),
        cmd_email_mark_as_unread('\uf495'),
        cmd_email_minus('\uf7e8'),
        cmd_email_minus_outline('\uf7e9'),
        cmd_email_multiple('\uf7ea'),
        cmd_email_multiple_outline('\uf7eb'),
        cmd_email_newsletter('\uf8b4'),
        cmd_email_open('\ueaf2'),
        cmd_email_open_multiple('\uf7ec'),
        cmd_email_open_multiple_outline('\uf7ed'),
        cmd_email_open_outline('\ueef3'),
        cmd_email_outline('\ueaf3'),
        cmd_email_plus('\uf2ea'),
        cmd_email_plus_outline('\uf2eb'),
        cmd_email_receive('\uf9da'),
        cmd_email_receive_outline('\uf9db'),
        cmd_email_search('\uf260'),
        cmd_email_search_outline('\uf261'),
        cmd_email_send('\uf9dc'),
        cmd_email_send_outline('\uf9dd'),
        cmd_email_sync('\ufbc7'),
        cmd_email_sync_outline('\ufbc8'),
        cmd_email_variant('\ueef4'),
        cmd_ember('\uf434'),
        cmd_emby('\uefb7'),
        cmd_emoticon('\uf56d'),
        cmd_emoticon_angry('\uf56e'),
        cmd_emoticon_angry_outline('\uf56f'),
        cmd_emoticon_confused('\uf9de'),
        cmd_emoticon_confused_outline('\uf9df'),
        cmd_emoticon_cool('\uf570'),
        cmd_emoticon_cool_outline('\ueaf6'),
        cmd_emoticon_cry('\uf571'),
        cmd_emoticon_cry_outline('\uf572'),
        cmd_emoticon_dead('\uf573'),
        cmd_emoticon_dead_outline('\uef9e'),
        cmd_emoticon_devil('\uf574'),
        cmd_emoticon_devil_outline('\ueaf7'),
        cmd_emoticon_excited('\uf575'),
        cmd_emoticon_excited_outline('\uef9f'),
        cmd_emoticon_frown('\uf84f'),
        cmd_emoticon_frown_outline('\uf850'),
        cmd_emoticon_happy('\uf576'),
        cmd_emoticon_happy_outline('\ueaf8'),
        cmd_emoticon_kiss('\uf577'),
        cmd_emoticon_kiss_outline('\uf578'),
        cmd_emoticon_lol('\ufb14'),
        cmd_emoticon_lol_outline('\ufb15'),
        cmd_emoticon_neutral('\uf579'),
        cmd_emoticon_neutral_outline('\ueaf9'),
        cmd_emoticon_outline('\ueaf5'),
        cmd_emoticon_poop('\ueafa'),
        cmd_emoticon_poop_outline('\uf57a'),
        cmd_emoticon_sad('\uf57b'),
        cmd_emoticon_sad_outline('\ueafb'),
        cmd_emoticon_tongue('\ueafc'),
        cmd_emoticon_tongue_outline('\uf57c'),
        cmd_emoticon_wink('\uf57d'),
        cmd_emoticon_wink_outline('\uf57e'),
        cmd_engine('\ueafd'),
        cmd_engine_off('\uf345'),
        cmd_engine_off_outline('\uf346'),
        cmd_engine_outline('\ueafe'),
        cmd_epsilon('\uf9e0'),
        cmd_equal('\ueaff'),
        cmd_equal_box('\ueb00'),
        cmd_equalizer('\uf7a5'),
        cmd_equalizer_outline('\uf7a6'),
        cmd_eraser('\ueb01'),
        cmd_eraser_variant('\uef45'),
        cmd_escalator('\ueb02'),
        cmd_escalator_box('\ufc99'),
        cmd_escalator_down('\ufbc0'),
        cmd_escalator_up('\ufbbf'),
        cmd_eslint('\uf57f'),
        cmd_et('\uf3b2'),
        cmd_ethereum('\uf16b'),
        cmd_ethernet('\ueb03'),
        cmd_ethernet_cable('\ueb04'),
        cmd_ethernet_cable_off('\ueb05'),
        cmd_ev_station('\ueef5'),
        cmd_evernote('\ueb07'),
        cmd_excavator('\uf928'),
        cmd_exclamation('\ueb08'),
        cmd_exclamation_thick('\ufb38'),
        cmd_exit_run('\uf347'),
        cmd_exit_to_app('\ueb09'),
        cmd_exit_to_app1('\ueb0a'),
        cmd_expand_all('\uf3b3'),
        cmd_expand_all_outline('\uf3b4'),
        cmd_expansion_card('\uf1ae'),
        cmd_expansion_card_variant('\uf8b5'),
        cmd_exponent('\uf262'),
        cmd_exponent_box('\uf263'),
        cmd_export('\ueb0b'),
        cmd_export_variant('\uf496'),
        cmd_eye('\ueb0c'),
        cmd_eye_check('\uf607'),
        cmd_eye_check_outline('\uf608'),
        cmd_eye_circle('\uf497'),
        cmd_eye_circle_outline('\uf498'),
        cmd_eye_minus('\uf929'),
        cmd_eye_minus_outline('\uf92a'),
        cmd_eye_off('\ueb0d'),
        cmd_eye_off_outline('\uefd4'),
        cmd_eye_outline('\uefd3'),
        cmd_eye_plus('\uf16c'),
        cmd_eye_plus_outline('\uf16d'),
        cmd_eye_settings('\uf16e'),
        cmd_eye_settings_outline('\uf16f'),
        cmd_eyedropper('\ueb0e'),
        cmd_eyedropper_variant('\ueb0f'),
        cmd_face('\uef46'),
        cmd_face_agent('\uf673'),
        cmd_face_outline('\uf499'),
        cmd_face_profile('\uef47'),
        cmd_face_profile_woman('\uf979'),
        cmd_face_recognition('\uf580'),
        cmd_face_woman('\uf97a'),
        cmd_face_woman_outline('\uf97b'),
        cmd_facebook('\ueb10'),
        cmd_facebook_messenger('\ueb12'),
        cmd_facebook_workplace('\uf435'),
        cmd_factory('\ueb13'),
        cmd_fan('\ueb14'),
        cmd_fan_off('\uf11e'),
        cmd_fast_forward('\ueb15'),
        cmd_fast_forward_10('\uf674'),
        cmd_fast_forward_30('\uf609'),
        cmd_fast_forward_5('\ufaf8'),
        cmd_fast_forward_outline('\uefd5'),
        cmd_fax('\ueb16'),
        cmd_feather('\uefd6'),
        cmd_feature_search('\uf348'),
        cmd_feature_search_outline('\uf349'),
        cmd_fedora('\uf1da'),
        cmd_ferris_wheel('\uf7a7'),
        cmd_ferry('\ueb17'),
        cmd_file('\ueb18'),
        cmd_file_account('\uf03e'),
        cmd_file_account_outline('\uf92b'),
        cmd_file_alert('\uf34a'),
        cmd_file_alert_outline('\uf34b'),
        cmd_file_cabinet('\uf3b5'),
        cmd_file_cad('\uf7ee'),
        cmd_file_cad_box('\uf7ef'),
        cmd_file_cancel('\uf6c9'),
        cmd_file_cancel_outline('\uf6ca'),
        cmd_file_certificate('\ufa86'),
        cmd_file_certificate_outline('\ufa87'),
        cmd_file_chart('\ueb19'),
        cmd_file_chart_outline('\uf92c'),
        cmd_file_check('\ueb1a'),
        cmd_file_check_outline('\uf72c'),
        cmd_file_clock('\ufbe1'),
        cmd_file_clock_outline('\ufbe2'),
        cmd_file_cloud('\ueb1b'),
        cmd_file_cloud_outline('\uf92d'),
        cmd_file_code('\ueb32'),
        cmd_file_code_outline('\uf92e'),
        cmd_file_cog('\uf97e'),
        cmd_file_cog_outline('\uf97f'),
        cmd_file_compare('\uf1aa'),
        cmd_file_delimited('\ueb1c'),
        cmd_file_delimited_outline('\uf7a8'),
        cmd_file_document('\ueb1d'),
        cmd_file_document_edit('\uf6cb'),
        cmd_file_document_edit_outline('\uf6cc'),
        cmd_file_document_outline('\uf2ed'),
        cmd_file_download('\uf264'),
        cmd_file_download_outline('\uf265'),
        cmd_file_edit('\ufae7'),
        cmd_file_edit_outline('\ufae8'),
        cmd_file_excel('\ueb1f'),
        cmd_file_excel_box('\ueb20'),
        cmd_file_excel_box_outline('\uf92f'),
        cmd_file_excel_outline('\uf930'),
        cmd_file_export('\ueb21'),
        cmd_file_export_outline('\uf931'),
        cmd_file_eye('\uf6cd'),
        cmd_file_eye_outline('\uf6ce'),
        cmd_file_find('\ueb22'),
        cmd_file_find_outline('\uf49a'),
        cmd_file_hidden('\uef16'),
        cmd_file_image('\ueb23'),
        cmd_file_image_outline('\uf7b3'),
        cmd_file_import('\ueb24'),
        cmd_file_import_outline('\uf932'),
        cmd_file_key('\ufa84'),
        cmd_file_key_outline('\ufa85'),
        cmd_file_link('\ufa77'),
        cmd_file_link_outline('\ufa78'),
        cmd_file_lock('\ueb25'),
        cmd_file_lock_outline('\uf933'),
        cmd_file_move('\uf3b8'),
        cmd_file_move_outline('\uf934'),
        cmd_file_multiple('\ueb26'),
        cmd_file_multiple_outline('\uf935'),
        cmd_file_music('\ueb27'),
        cmd_file_music_outline('\uf72d'),
        cmd_file_outline('\ueb28'),
        cmd_file_pdf('\ueb29'),
        cmd_file_pdf_box('\ueb2a'),
        cmd_file_pdf_box_outline('\uf8b6'),
        cmd_file_pdf_outline('\uf730'),
        cmd_file_percent('\uf11f'),
        cmd_file_percent_outline('\uf936'),
        cmd_file_phone('\ufa79'),
        cmd_file_phone_outline('\ufa7a'),
        cmd_file_plus('\uf055'),
        cmd_file_plus_outline('\uf7f0'),
        cmd_file_powerpoint('\ueb2b'),
        cmd_file_powerpoint_box('\ueb2c'),
        cmd_file_powerpoint_box_outline('\uf937'),
        cmd_file_powerpoint_outline('\uf938'),
        cmd_file_presentation_box('\ueb2d'),
        cmd_file_question('\uf170'),
        cmd_file_question_outline('\uf939'),
        cmd_file_refresh('\uf217'),
        cmd_file_refresh_outline('\uee45'),
        cmd_file_remove('\uf49b'),
        cmd_file_remove_outline('\uf93a'),
        cmd_file_replace('\uf436'),
        cmd_file_replace_outline('\uf437'),
        cmd_file_restore('\uef73'),
        cmd_file_restore_outline('\uf93b'),
        cmd_file_search('\uf581'),
        cmd_file_search_outline('\uf582'),
        cmd_file_send('\ueb2e'),
        cmd_file_send_outline('\uf93c'),
        cmd_file_settings('\uf97c'),
        cmd_file_settings_outline('\uf97d'),
        cmd_file_star('\uf93d'),
        cmd_file_star_outline('\uf93e'),
        cmd_file_swap('\uf8b7'),
        cmd_file_swap_outline('\uf8b8'),
        cmd_file_sync('\ufb16'),
        cmd_file_sync_outline('\ufb17'),
        cmd_file_table('\uf583'),
        cmd_file_table_box('\uf9e1'),
        cmd_file_table_box_multiple('\uf9e2'),
        cmd_file_table_box_multiple_outline('\uf9e3'),
        cmd_file_table_box_outline('\uf9e4'),
        cmd_file_table_outline('\uf584'),
        cmd_file_tree('\uef48'),
        cmd_file_undo('\uf1db'),
        cmd_file_undo_outline('\uf93f'),
        cmd_file_upload('\uf34c'),
        cmd_file_upload_outline('\uf34d'),
        cmd_file_video('\ueb2f'),
        cmd_file_video_outline('\uf72f'),
        cmd_file_word('\ueb30'),
        cmd_file_word_box('\ueb31'),
        cmd_file_word_box_outline('\uf940'),
        cmd_file_word_outline('\uf941'),
        cmd_film('\ueb33'),
        cmd_filmstrip('\ueb34'),
        cmd_filmstrip_box('\uec38'),
        cmd_filmstrip_box_multiple('\uf61b'),
        cmd_filmstrip_off('\ueb35'),
        cmd_filter('\ueb36'),
        cmd_filter_menu('\uf9e5'),
        cmd_filter_menu_outline('\uf9e6'),
        cmd_filter_minus('\uf7f1'),
        cmd_filter_minus_outline('\uf7f2'),
        cmd_filter_outline('\ueb37'),
        cmd_filter_plus('\uf7f3'),
        cmd_filter_plus_outline('\uf7f4'),
        cmd_filter_remove('\ueb38'),
        cmd_filter_remove_outline('\ueb39'),
        cmd_filter_variant('\ueb3a'),
        cmd_filter_variant_minus('\ufa12'),
        cmd_filter_variant_plus('\ufa13'),
        cmd_filter_variant_remove('\uf942'),
        cmd_finance('\uf120'),
        cmd_find_replace('\uefd7'),
        cmd_fingerprint('\ueb3b'),
        cmd_fingerprint_off('\uf7b4'),
        cmd_fire('\ueb3c'),
        cmd_fire_extinguisher('\uf7f5'),
        cmd_fire_hydrant('\ufa37'),
        cmd_fire_hydrant_alert('\ufa38'),
        cmd_fire_hydrant_off('\ufa39'),
        cmd_fire_truck('\uf1ab'),
        cmd_firebase('\uf266'),
        cmd_firefox('\ueb3d'),
        cmd_fireplace('\uf731'),
        cmd_fireplace_off('\uf732'),
        cmd_firework('\uf733'),
        cmd_fish('\ueb3e'),
        cmd_fishbowl('\uf7f6'),
        cmd_fishbowl_outline('\uf7f7'),
        cmd_fit_to_page('\uf7f8'),
        cmd_fit_to_page_outline('\uf7f9'),
        cmd_flag('\ueb3f'),
        cmd_flag_checkered('\ueb40'),
        cmd_flag_minus('\uf49c'),
        cmd_flag_minus_outline('\uf9b2'),
        cmd_flag_outline('\ueb41'),
        cmd_flag_plus('\uf49d'),
        cmd_flag_plus_outline('\uf9b3'),
        cmd_flag_remove('\uf49e'),
        cmd_flag_remove_outline('\uf9b4'),
        cmd_flag_triangle('\ueb43'),
        cmd_flag_variant('\ueb44'),
        cmd_flag_variant_outline('\ueb42'),
        cmd_flare('\uf675'),
        cmd_flash('\ueb45'),
        cmd_flash_alert('\uf7fa'),
        cmd_flash_alert_outline('\uf7fb'),
        cmd_flash_auto('\ueb46'),
        cmd_flash_circle('\uf121'),
        cmd_flash_off('\ueb47'),
        cmd_flash_outline('\uefd8'),
        cmd_flash_red_eye('\uef7e'),
        cmd_flashlight('\ueb48'),
        cmd_flashlight_off('\ueb49'),
        cmd_flask('\ue993'),
        cmd_flask_empty('\ue994'),
        cmd_flask_empty_minus('\ufb3a'),
        cmd_flask_empty_minus_outline('\ufb3b'),
        cmd_flask_empty_outline('\ue995'),
        cmd_flask_empty_plus('\ufb3c'),
        cmd_flask_empty_plus_outline('\ufb3d'),
        cmd_flask_empty_remove('\ufb3e'),
        cmd_flask_empty_remove_outline('\ufb3f'),
        cmd_flask_minus('\ufb40'),
        cmd_flask_minus_outline('\ufb41'),
        cmd_flask_outline('\ue996'),
        cmd_flask_plus('\ufb42'),
        cmd_flask_plus_outline('\ufb43'),
        cmd_flask_remove('\ufb44'),
        cmd_flask_remove_outline('\ufb45'),
        cmd_flask_round_bottom('\ufb4b'),
        cmd_flask_round_bottom_empty('\ufb4c'),
        cmd_flask_round_bottom_empty_outline('\ufb4d'),
        cmd_flask_round_bottom_outline('\ufb4e'),
        cmd_fleur_de_lis('\ufc03'),
        cmd_flip_horizontal('\uf9e7'),
        cmd_flip_to_back('\ueb4b'),
        cmd_flip_to_front('\ueb4c'),
        cmd_flip_vertical('\uf9e8'),
        cmd_floor_lamp('\uf1dc'),
        cmd_floor_lamp_dual('\uf943'),
        cmd_floor_lamp_variant('\uf944'),
        cmd_floor_plan('\uf122'),
        cmd_floppy('\ueb4d'),
        cmd_floppy_variant('\uf2ee'),
        cmd_flower('\ueb4e'),
        cmd_flower_outline('\uf2ef'),
        cmd_flower_poppy('\uf60b'),
        cmd_flower_tulip('\uf2f0'),
        cmd_flower_tulip_outline('\uf2f1'),
        cmd_focus_auto('\uf851'),
        cmd_focus_field('\uf852'),
        cmd_focus_field_horizontal('\uf853'),
        cmd_focus_field_vertical('\uf854'),
        cmd_folder('\ueb4f'),
        cmd_folder_account('\ueb50'),
        cmd_folder_account_outline('\uf49f'),
        cmd_folder_alert('\uf6cf'),
        cmd_folder_alert_outline('\uf6d0'),
        cmd_folder_clock('\uf3b9'),
        cmd_folder_clock_outline('\uf3ba'),
        cmd_folder_cog('\uf982'),
        cmd_folder_cog_outline('\uf983'),
        cmd_folder_download('\ueb51'),
        cmd_folder_download_outline('\uf9e9'),
        cmd_folder_edit('\uf1dd'),
        cmd_folder_edit_outline('\uf6d1'),
        cmd_folder_google_drive('\ueb52'),
        cmd_folder_heart('\uf9ea'),
        cmd_folder_heart_outline('\uf9eb'),
        cmd_folder_home('\uf9b5'),
        cmd_folder_home_outline('\uf9b6'),
        cmd_folder_image('\ueb53'),
        cmd_folder_information('\uf9b7'),
        cmd_folder_information_outline('\uf9b8'),
        cmd_folder_key('\uf1ac'),
        cmd_folder_key_network('\uf1ad'),
        cmd_folder_key_network_outline('\uf585'),
        cmd_folder_key_outline('\uf9ec'),
        cmd_folder_lock('\ueb54'),
        cmd_folder_lock_open('\ueb55'),
        cmd_folder_marker('\ufb6d'),
        cmd_folder_marker_outline('\ufb6e'),
        cmd_folder_move('\ueb56'),
        cmd_folder_move_outline('\ufb46'),
        cmd_folder_multiple('\ueb57'),
        cmd_folder_multiple_image('\ueb58'),
        cmd_folder_multiple_outline('\ueb59'),
        cmd_folder_music('\ufc59'),
        cmd_folder_music_outline('\ufc5a'),
        cmd_folder_network('\uf171'),
        cmd_folder_network_outline('\uf586'),
        cmd_folder_open('\uf071'),
        cmd_folder_open_outline('\uf6d2'),
        cmd_folder_outline('\ueb5a'),
        cmd_folder_plus('\ueb5b'),
        cmd_folder_plus_outline('\uf4a0'),
        cmd_folder_pound('\uf60c'),
        cmd_folder_pound_outline('\uf60d'),
        cmd_folder_refresh('\uf04c'),
        cmd_folder_refresh_outline('\uee46'),
        cmd_folder_remove('\ueb5c'),
        cmd_folder_remove_outline('\uf4a1'),
        cmd_folder_search('\uf267'),
        cmd_folder_search_outline('\uf268'),
        cmd_folder_settings('\uf980'),
        cmd_folder_settings_outline('\uf981'),
        cmd_folder_star('\uefa0'),
        cmd_folder_star_outline('\uf4a2'),
        cmd_folder_swap('\uf8b9'),
        cmd_folder_swap_outline('\uf8ba'),
        cmd_folder_sync('\uf60e'),
        cmd_folder_sync_outline('\uf60f'),
        cmd_folder_table('\ufbe3'),
        cmd_folder_table_outline('\ufbe4'),
        cmd_folder_text('\uf587'),
        cmd_folder_text_outline('\uf588'),
        cmd_folder_upload('\ueb5d'),
        cmd_folder_upload_outline('\uf9ed'),
        cmd_folder_zip('\uefee'),
        cmd_folder_zip_outline('\uf0ba'),
        cmd_font_awesome('\ue939'),
        cmd_food('\ueb5e'),
        cmd_food_apple('\ueb5f'),
        cmd_food_apple_outline('\uf589'),
        cmd_food_croissant('\uf0c9'),
        cmd_food_fork_drink('\ueef6'),
        cmd_food_off('\ueef7'),
        cmd_food_variant('\ueb60'),
        cmd_foot_print('\uf855'),
        cmd_football('\ueb61'),
        cmd_football_australian('\ueb62'),
        cmd_football_helmet('\ueb63'),
        cmd_forklift('\uf0ca'),
        cmd_format_align_bottom('\uf056'),
        cmd_format_align_center('\ueb64'),
        cmd_format_align_justify('\ueb65'),
        cmd_format_align_left('\ueb66'),
        cmd_format_align_middle('\uf057'),
        cmd_format_align_right('\ueb67'),
        cmd_format_align_top('\uf058'),
        cmd_format_annotation_minus('\uf3bb'),
        cmd_format_annotation_plus('\uef49'),
        cmd_format_bold('\ueb68'),
        cmd_format_clear('\ueb69'),
        cmd_format_color_fill('\ueb6a'),
        cmd_format_color_highlight('\uf734'),
        cmd_format_color_marker_cancel('\ufc13'),
        cmd_format_color_text('\uefa1'),
        cmd_format_columns('\uf1de'),
        cmd_format_float_center('\ueb6b'),
        cmd_format_float_left('\ueb6c'),
        cmd_format_float_none('\ueb6d'),
        cmd_format_float_right('\ueb6e'),
        cmd_format_font('\uefd9'),
        cmd_format_font_size_decrease('\uf2f2'),
        cmd_format_font_size_increase('\uf2f3'),
        cmd_format_header_1('\ueb6f'),
        cmd_format_header_2('\ueb70'),
        cmd_format_header_3('\ueb71'),
        cmd_format_header_4('\ueb72'),
        cmd_format_header_5('\ueb73'),
        cmd_format_header_6('\ueb74'),
        cmd_format_header_decrease('\ueb75'),
        cmd_format_header_equal('\ueb76'),
        cmd_format_header_increase('\ueb77'),
        cmd_format_header_pound('\ueb78'),
        cmd_format_horizontal_align_center('\uef21'),
        cmd_format_horizontal_align_left('\uef22'),
        cmd_format_horizontal_align_right('\uef23'),
        cmd_format_indent_decrease('\ueb79'),
        cmd_format_indent_increase('\ueb7a'),
        cmd_format_italic('\ueb7b'),
        cmd_format_letter_case('\uf438'),
        cmd_format_letter_case_lower('\uf439'),
        cmd_format_letter_case_upper('\uf43a'),
        cmd_format_letter_ends_with('\uf8bb'),
        cmd_format_letter_matches('\uf8bc'),
        cmd_format_letter_starts_with('\uf8bd'),
        cmd_format_line_spacing('\ueb7c'),
        cmd_format_line_style('\ueecc'),
        cmd_format_line_weight('\ueecd'),
        cmd_format_list_bulleted('\ueb7d'),
        cmd_format_list_bulleted_square('\uf6d3'),
        cmd_format_list_bulleted_triangle('\uf7b5'),
        cmd_format_list_bulleted_type('\ueb7e'),
        cmd_format_list_checkbox('\uf269'),
        cmd_format_list_checks('\uf059'),
        cmd_format_list_numbered('\ueb7f'),
        cmd_format_list_numbered_rtl('\uf610'),
        cmd_format_list_text('\ufb6f'),
        cmd_format_overline('\uf7b6'),
        cmd_format_page_break('\uefda'),
        cmd_format_paint('\ueb80'),
        cmd_format_paragraph('\ueb81'),
        cmd_format_pilcrow('\uefdb'),
        cmd_format_quote_close('\ueb82'),
        cmd_format_quote_close_outline('\ufaa8'),
        cmd_format_quote_open('\uf05a'),
        cmd_format_quote_open_outline('\ufaa7'),
        cmd_format_rotate_90('\uefad'),
        cmd_format_section('\uefa2'),
        cmd_format_size('\ueb83'),
        cmd_format_strikethrough('\ueb84'),
        cmd_format_strikethrough_variant('\ueb85'),
        cmd_format_subscript('\ueb86'),
        cmd_format_superscript('\ueb87'),
        cmd_format_text('\ueb88'),
        cmd_format_text_rotation_angle_down('\uf8be'),
        cmd_format_text_rotation_angle_up('\uf8bf'),
        cmd_format_text_rotation_down('\uf676'),
        cmd_format_text_rotation_down_vertical('\uf8c0'),
        cmd_format_text_rotation_none('\uf677'),
        cmd_format_text_rotation_up('\uf8c1'),
        cmd_format_text_rotation_vertical('\uf8c2'),
        cmd_format_text_variant('\uf735'),
        cmd_format_text_wrapping_clip('\uf611'),
        cmd_format_text_wrapping_overflow('\uf612'),
        cmd_format_text_wrapping_wrap('\uf613'),
        cmd_format_textbox('\uf614'),
        cmd_format_textdirection_l_to_r('\ueb89'),
        cmd_format_textdirection_r_to_l('\ueb8a'),
        cmd_format_title('\ueef8'),
        cmd_format_underline('\ueb8b'),
        cmd_format_vertical_align_bottom('\uef24'),
        cmd_format_vertical_align_center('\uef25'),
        cmd_format_vertical_align_top('\uef26'),
        cmd_format_wrap_inline('\ueb8c'),
        cmd_format_wrap_square('\ueb8d'),
        cmd_format_wrap_tight('\ueb8e'),
        cmd_format_wrap_top_bottom('\ueb8f'),
        cmd_forum('\ueb90'),
        cmd_forum_outline('\uf123'),
        cmd_forward('\ueb91'),
        cmd_forwardburger('\uf678'),
        cmd_fountain('\uf26a'),
        cmd_fountain_pen('\uf615'),
        cmd_fountain_pen_tip('\uf616'),
        cmd_freebsd('\uf1df'),
        cmd_frequently_asked_questions('\uf7b7'),
        cmd_fridge('\ueb94'),
        cmd_fridge_alert('\ufab1'),
        cmd_fridge_alert_outline('\ufab2'),
        cmd_fridge_bottom('\ueb96'),
        cmd_fridge_off('\ufaaf'),
        cmd_fridge_off_outline('\ufab0'),
        cmd_fridge_outline('\ueb93'),
        cmd_fridge_top('\ueb95'),
        cmd_fruit_cherries('\uf945'),
        cmd_fruit_citrus('\uf946'),
        cmd_fruit_grapes('\uf947'),
        cmd_fruit_grapes_outline('\uf948'),
        cmd_fruit_pineapple('\uf949'),
        cmd_fruit_watermelon('\uf94a'),
        cmd_fuel('\uf0cb'),
        cmd_fullscreen('\ueb97'),
        cmd_fullscreen_exit('\ueb98'),
        cmd_function('\ueb99'),
        cmd_function_variant('\uf172'),
        cmd_furigana_horizontal('\uf984'),
        cmd_furigana_vertical('\uf985'),
        cmd_fuse('\uf58a'),
        cmd_fuse_blade('\uf58b'),
        cmd_gamepad('\ueb9a'),
        cmd_gamepad_circle('\uf736'),
        cmd_gamepad_circle_down('\uf737'),
        cmd_gamepad_circle_left('\uf738'),
        cmd_gamepad_circle_outline('\uf739'),
        cmd_gamepad_circle_right('\uf73a'),
        cmd_gamepad_circle_up('\uf73b'),
        cmd_gamepad_down('\uf73c'),
        cmd_gamepad_left('\uf73d'),
        cmd_gamepad_right('\uf73e'),
        cmd_gamepad_round('\uf73f'),
        cmd_gamepad_round_down('\uf740'),
        cmd_gamepad_round_left('\uf741'),
        cmd_gamepad_round_outline('\uf742'),
        cmd_gamepad_round_right('\uf743'),
        cmd_gamepad_round_up('\uf744'),
        cmd_gamepad_square('\uf7b8'),
        cmd_gamepad_square_outline('\uf7b9'),
        cmd_gamepad_up('\uf745'),
        cmd_gamepad_variant('\ueb9b'),
        cmd_gamepad_variant_outline('\uf7ba'),
        cmd_gamma('\uf9ee'),
        cmd_gantry_crane('\uf6d4'),
        cmd_garage('\uefdc'),
        cmd_garage_alert('\uf173'),
        cmd_garage_alert_variant('\ufbd5'),
        cmd_garage_open('\uefdd'),
        cmd_garage_open_variant('\ufbd4'),
        cmd_garage_variant('\ufbd3'),
        cmd_gas_cylinder('\uef4a'),
        cmd_gas_station('\ueb9c'),
        cmd_gas_station_outline('\uf7bb'),
        cmd_gate('\ueb9d'),
        cmd_gate_and('\uf1e0'),
        cmd_gate_arrow_right('\ufa69'),
        cmd_gate_nand('\uf1e1'),
        cmd_gate_nor('\uf1e2'),
        cmd_gate_not('\uf1e3'),
        cmd_gate_open('\ufa6a'),
        cmd_gate_or('\uf1e4'),
        cmd_gate_xnor('\uf1e5'),
        cmd_gate_xor('\uf1e6'),
        cmd_gatsby('\uf746'),
        cmd_gauge('\ueb9e'),
        cmd_gauge_empty('\uf174'),
        cmd_gauge_full('\uf175'),
        cmd_gauge_low('\uf176'),
        cmd_gavel('\ueb9f'),
        cmd_gender_female('\ueba0'),
        cmd_gender_male('\ueba1'),
        cmd_gender_male_female('\ueba2'),
        cmd_gender_male_female_variant('\ufa3f'),
        cmd_gender_non_binary('\ufa40'),
        cmd_gender_transgender('\ueba3'),
        cmd_gentoo('\uf1e7'),
        cmd_gesture('\uf0cc'),
        cmd_gesture_double_tap('\uf03f'),
        cmd_gesture_pinch('\uf3bc'),
        cmd_gesture_spread('\uf3bd'),
        cmd_gesture_swipe('\uf679'),
        cmd_gesture_swipe_down('\uf040'),
        cmd_gesture_swipe_horizontal('\uf3be'),
        cmd_gesture_swipe_left('\uf041'),
        cmd_gesture_swipe_right('\uf042'),
        cmd_gesture_swipe_up('\uf043'),
        cmd_gesture_swipe_vertical('\uf3bf'),
        cmd_gesture_tap('\uf044'),
        cmd_gesture_tap_box('\ufba9'),
        cmd_gesture_tap_button('\ufba8'),
        cmd_gesture_tap_hold('\uf67a'),
        cmd_gesture_two_double_tap('\uf045'),
        cmd_gesture_two_tap('\uf046'),
        cmd_ghost('\ueba4'),
        cmd_ghost_off('\uf2f4'),
        cmd_gif('\uf67b'),
        cmd_gift('\uf747'),
        cmd_gift_outline('\ueba5'),
        cmd_git('\ueba6'),
        cmd_github('\ueba8'),
        cmd_gitlab('\uf4a3'),
        cmd_glass_cocktail('\uec5c'),
        cmd_glass_flute('\ueba9'),
        cmd_glass_mug('\uebaa'),
        cmd_glass_mug_variant('\ufa16'),
        cmd_glass_pint_outline('\ufc0d'),
        cmd_glass_stange('\uebab'),
        cmd_glass_tulip('\uebac'),
        cmd_glass_wine('\uf177'),
        cmd_glasses('\uebae'),
        cmd_globe_light('\ufbd7'),
        cmd_globe_model('\uf1e8'),
        cmd_gmail('\uebaf'),
        cmd_gnome('\uebb0'),
        cmd_go_kart('\uf67c'),
        cmd_go_kart_track('\uf67d'),
        cmd_gog('\uf4a4'),
        cmd_gold('\ufb4f'),
        cmd_golf('\uf124'),
        cmd_golf_cart('\ufaa4'),
        cmd_golf_tee('\uf986'),
        cmd_gondola('\uef89'),
        cmd_goodreads('\uf67e'),
        cmd_google('\uebb1'),
        cmd_google_ads('\uf58c'),
        cmd_google_analytics('\uf0cd'),
        cmd_google_assistant('\uf0ce'),
        cmd_google_cardboard('\uebb2'),
        cmd_google_chrome('\uebb3'),
        cmd_google_circles('\uebb4'),
        cmd_google_circles_communities('\uebb5'),
        cmd_google_circles_extended('\uebb6'),
        cmd_google_circles_group('\uebb7'),
        cmd_google_classroom('\uebc4'),
        cmd_google_cloud('\ufaf6'),
        cmd_google_controller('\uebb8'),
        cmd_google_controller_off('\uebb9'),
        cmd_google_downasaur('\ufc62'),
        cmd_google_drive('\uebba'),
        cmd_google_earth('\uebbb'),
        cmd_google_fit('\uf26b'),
        cmd_google_glass('\uebbc'),
        cmd_google_hangouts('\uebcd'),
        cmd_google_home('\uf125'),
        cmd_google_keep('\uefdf'),
        cmd_google_lens('\uf2f5'),
        cmd_google_maps('\ueef9'),
        cmd_google_my_business('\uf94b'),
        cmd_google_nearby('\uebbd'),
        cmd_google_photos('\uefe0'),
        cmd_google_play('\uebc0'),
        cmd_google_plus('\uebc1'),
        cmd_google_podcast('\uf7bc'),
        cmd_google_spreadsheet('\uf2f6'),
        cmd_google_street_view('\uf58d'),
        cmd_google_translate('\uebc3'),
        cmd_gradient('\uefa3'),
        cmd_grain('\uf67f'),
        cmd_graph('\uf94c'),
        cmd_graph_outline('\uf94d'),
        cmd_graphql('\uf178'),
        cmd_grave_stone('\uf4a5'),
        cmd_grease_pencil('\uef4b'),
        cmd_greater_than('\uf26c'),
        cmd_greater_than_or_equal('\uf26d'),
        cmd_grid('\uebc5'),
        cmd_grid_large('\uf05b'),
        cmd_grid_off('\uebc6'),
        cmd_grill('\uf748'),
        cmd_grill_outline('\ufa8a'),
        cmd_group('\uebc7'),
        cmd_guitar_acoustic('\uf072'),
        cmd_guitar_electric('\uebc8'),
        cmd_guitar_pick('\uebc9'),
        cmd_guitar_pick_outline('\uebca'),
        cmd_guy_fawkes_mask('\uf126');

        override val typeface: ITypeface by lazy { CommunityMaterial }
    }

    enum class Icon2 constructor(override val character: Char) : IIcon {

        cmd_hail('\uf3c0'),
        cmd_hair_dryer('\uf9ef'),
        cmd_hair_dryer_outline('\uf9f0'),
        cmd_halloween('\uf4a6'),
        cmd_hamburger('\uef88'),
        cmd_hammer('\uf1e9'),
        cmd_hammer_screwdriver('\ufc22'),
        cmd_hammer_wrench('\ufc23'),
        cmd_hand('\uf34e'),
        cmd_hand_heart('\uf9f1'),
        cmd_hand_left('\uf749'),
        cmd_hand_okay('\uf34f'),
        cmd_hand_peace('\uf350'),
        cmd_hand_peace_variant('\uf351'),
        cmd_hand_pointing_down('\uf352'),
        cmd_hand_pointing_left('\uf353'),
        cmd_hand_pointing_right('\uebcb'),
        cmd_hand_pointing_up('\uf354'),
        cmd_hand_right('\uf74a'),
        cmd_hand_saw('\uf74b'),
        cmd_hand_water('\ufc9f'),
        cmd_handball('\uf856'),
        cmd_handcuffs('\ufa3e'),
        cmd_handshake('\ufb18'),
        cmd_hanger('\uebcc'),
        cmd_hard_hat('\uf26e'),
        cmd_harddisk('\uebce'),
        cmd_harddisk_plus('\uf94e'),
        cmd_harddisk_remove('\uf94f'),
        cmd_hat_fedora('\uf4a7'),
        cmd_hazard_lights('\uf58e'),
        cmd_hdr('\uf680'),
        cmd_hdr_off('\uf681'),
        cmd_head('\ufc5e'),
        cmd_head_alert('\ufc38'),
        cmd_head_alert_outline('\ufc39'),
        cmd_head_check('\ufc3a'),
        cmd_head_check_outline('\ufc3b'),
        cmd_head_cog('\ufc3c'),
        cmd_head_cog_outline('\ufc3d'),
        cmd_head_dots_horizontal('\ufc3e'),
        cmd_head_dots_horizontal_outline('\ufc3f'),
        cmd_head_flash('\ufc40'),
        cmd_head_flash_outline('\ufc41'),
        cmd_head_heart('\ufc42'),
        cmd_head_heart_outline('\ufc43'),
        cmd_head_lightbulb('\ufc44'),
        cmd_head_lightbulb_outline('\ufc45'),
        cmd_head_minus('\ufc46'),
        cmd_head_minus_outline('\ufc47'),
        cmd_head_outline('\ufc5f'),
        cmd_head_plus('\ufc48'),
        cmd_head_plus_outline('\ufc49'),
        cmd_head_question('\ufc4a'),
        cmd_head_question_outline('\ufc4b'),
        cmd_head_remove('\ufc4c'),
        cmd_head_remove_outline('\ufc4d'),
        cmd_head_snowflake('\ufc4e'),
        cmd_head_snowflake_outline('\ufc4f'),
        cmd_head_sync('\ufc50'),
        cmd_head_sync_outline('\ufc51'),
        cmd_headphones('\uebcf'),
        cmd_headphones_bluetooth('\uf26f'),
        cmd_headphones_box('\uebd0'),
        cmd_headphones_off('\uf0cf'),
        cmd_headphones_settings('\uebd1'),
        cmd_headset('\uebd2'),
        cmd_headset_dock('\uebd3'),
        cmd_headset_off('\uebd4'),
        cmd_heart('\uebd5'),
        cmd_heart1('\uebd6'),
        cmd_heart_box('\uebd7'),
        cmd_heart_box_outline('\uebd8'),
        cmd_heart_broken('\uebd9'),
        cmd_heart_broken_outline('\uf617'),
        cmd_heart_circle('\uf270'),
        cmd_heart_circle_outline('\uf271'),
        cmd_heart_flash('\uf7fc'),
        cmd_heart_half('\uefe2'),
        cmd_heart_half_full('\uefe1'),
        cmd_heart_half_outline('\uefe3'),
        cmd_heart_multiple('\uf355'),
        cmd_heart_multiple_outline('\uf356'),
        cmd_heart_off('\uf05c'),
        cmd_heart_outline('\uebda'),
        cmd_heart_pulse('\ueefa'),
        cmd_helicopter('\uf3c1'),
        cmd_help('\uebdb'),
        cmd_help_box('\uf08c'),
        cmd_help_circle('\uebdc'),
        cmd_help_circle_outline('\uef28'),
        cmd_help_network('\ueff8'),
        cmd_help_network_outline('\uf58f'),
        cmd_help_rhombus('\uf4a8'),
        cmd_help_rhombus_outline('\uf4a9'),
        cmd_hexadecimal('\ufba7'),
        cmd_hexagon('\uebdd'),
        cmd_hexagon_multiple('\uefe4'),
        cmd_hexagon_multiple_outline('\uf9f2'),
        cmd_hexagon_outline('\uebde'),
        cmd_hexagon_slice_1('\uf3c2'),
        cmd_hexagon_slice_2('\uf3c3'),
        cmd_hexagon_slice_3('\uf3c4'),
        cmd_hexagon_slice_4('\uf3c5'),
        cmd_hexagon_slice_5('\uf3c6'),
        cmd_hexagon_slice_6('\uf3c7'),
        cmd_hexagram('\uf3c8'),
        cmd_hexagram_outline('\uf3c9'),
        cmd_high_definition('\uf0d0'),
        cmd_high_definition_box('\uf179'),
        cmd_highway('\ueefb'),
        cmd_hiking('\uf682'),
        cmd_hinduism('\uf272'),
        cmd_history('\uebdf'),
        cmd_hockey_puck('\uf17a'),
        cmd_hockey_sticks('\uf17b'),
        cmd_hololens('\uebe0'),
        cmd_home('\uebe1'),
        cmd_home_account('\uf127'),
        cmd_home_alert('\uf17c'),
        cmd_home_analytics('\uf7bd'),
        cmd_home_assistant('\uf0d1'),
        cmd_home_automation('\uf0d2'),
        cmd_home_circle('\uf0d3'),
        cmd_home_circle_outline('\uf950'),
        cmd_home_city('\uf618'),
        cmd_home_city_outline('\uf619'),
        cmd_home_currency_usd('\uf1af'),
        cmd_home_edit('\ufa59'),
        cmd_home_edit_outline('\ufa5a'),
        cmd_home_export_outline('\uf89e'),
        cmd_home_flood('\uf7fd'),
        cmd_home_floor_0('\uf6d5'),
        cmd_home_floor_1('\uf683'),
        cmd_home_floor_2('\uf684'),
        cmd_home_floor_3('\uf685'),
        cmd_home_floor_a('\uf686'),
        cmd_home_floor_b('\uf687'),
        cmd_home_floor_g('\uf688'),
        cmd_home_floor_l('\uf689'),
        cmd_home_floor_negative_1('\uf6d6'),
        cmd_home_group('\uf6d7'),
        cmd_home_heart('\uf128'),
        cmd_home_import_outline('\uf89f'),
        cmd_home_lightbulb('\ufb51'),
        cmd_home_lightbulb_outline('\ufb52'),
        cmd_home_lock('\uf1ea'),
        cmd_home_lock_open('\uf1eb'),
        cmd_home_map_marker('\ueefc'),
        cmd_home_minus('\uf273'),
        cmd_home_modern('\uebe2'),
        cmd_home_outline('\uefa4'),
        cmd_home_plus('\uf274'),
        cmd_home_remove('\ufb47'),
        cmd_home_roof('\ufa2b'),
        cmd_home_search('\ufcaf'),
        cmd_home_search_outline('\ufcb0'),
        cmd_home_thermometer('\uf857'),
        cmd_home_thermometer_outline('\uf858'),
        cmd_home_variant('\uebe3'),
        cmd_home_variant_outline('\uf4aa'),
        cmd_hook('\uefe5'),
        cmd_hook_off('\uefe6'),
        cmd_hops('\uebe4'),
        cmd_horizontal_rotate_clockwise('\uf9f3'),
        cmd_horizontal_rotate_counterclockwise('\uf9f4'),
        cmd_horseshoe('\uf357'),
        cmd_hospital('\uf8f9'),
        cmd_hospital_box('\uebe5'),
        cmd_hospital_box_outline('\uf8fa'),
        cmd_hospital_building('\uebe6'),
        cmd_hospital_marker('\uebe7'),
        cmd_hot_tub('\uf129'),
        cmd_hubspot('\uf61a'),
        cmd_hulu('\uf12a'),
        cmd_human('\uebeb'),
        cmd_human_baby_changing_table('\ufc8b'),
        cmd_human_child('\uebec'),
        cmd_human_female('\uef4c'),
        cmd_human_female_boy('\uf358'),
        cmd_human_female_female('\uf359'),
        cmd_human_female_girl('\uf35a'),
        cmd_human_greeting('\uef4d'),
        cmd_human_handsdown('\uef4e'),
        cmd_human_handsup('\uef4f'),
        cmd_human_male('\uef50'),
        cmd_human_male_boy('\uf35b'),
        cmd_human_male_child('\ufc8c'),
        cmd_human_male_female('\uebed'),
        cmd_human_male_girl('\uf35c'),
        cmd_human_male_height('\uf7fe'),
        cmd_human_male_height_variant('\uf7ff'),
        cmd_human_male_male('\uf35d'),
        cmd_human_pregnant('\ueed3'),
        cmd_human_wheelchair('\ufc8d'),
        cmd_humble_bundle('\uf047'),
        cmd_hvac('\ufc52'),
        cmd_hydraulic_oil_level('\ufc24'),
        cmd_hydraulic_oil_temperature('\ufc25'),
        cmd_hydro_power('\ufbe5'),
        cmd_ice_cream('\uf12b'),
        cmd_ice_cream_off('\uf755'),
        cmd_ice_pop('\uf800'),
        cmd_id_card('\uf8c3'),
        cmd_identifier('\uf801'),
        cmd_ideogram_cjk('\ufc31'),
        cmd_ideogram_cjk_variant('\ufc32'),
        cmd_iframe('\uf590'),
        cmd_iframe_array('\uf9f5'),
        cmd_iframe_array_outline('\uf9f6'),
        cmd_iframe_braces('\uf9f7'),
        cmd_iframe_braces_outline('\uf9f8'),
        cmd_iframe_outline('\uf591'),
        cmd_iframe_parentheses('\uf9f9'),
        cmd_iframe_parentheses_outline('\uf9fa'),
        cmd_iframe_variable('\uf9fb'),
        cmd_iframe_variable_outline('\uf9fc'),
        cmd_image('\uebee'),
        cmd_image_album('\uebef'),
        cmd_image_area('\uebf0'),
        cmd_image_area_close('\uebf1'),
        cmd_image_auto_adjust('\uf8c4'),
        cmd_image_broken('\uebf2'),
        cmd_image_broken_variant('\uebf3'),
        cmd_image_edit('\ufae3'),
        cmd_image_edit_outline('\ufae4'),
        cmd_image_filter_black_white('\uebf5'),
        cmd_image_filter_center_focus('\uebf6'),
        cmd_image_filter_center_focus_strong('\uf802'),
        cmd_image_filter_center_focus_strong_outline('\uf803'),
        cmd_image_filter_center_focus_weak('\uebf7'),
        cmd_image_filter_drama('\uebf8'),
        cmd_image_filter_frames('\uebf9'),
        cmd_image_filter_hdr('\uebfa'),
        cmd_image_filter_hdr1('\uebfb'),
        cmd_image_filter_none('\uebfc'),
        cmd_image_filter_tilt_shift('\uebfd'),
        cmd_image_filter_vintage('\uebfe'),
        cmd_image_frame('\uf74c'),
        cmd_image_move('\uf2f7'),
        cmd_image_multiple('\uebff'),
        cmd_image_multiple_outline('\uebf4'),
        cmd_image_off('\uf12c'),
        cmd_image_off_outline('\ufad1'),
        cmd_image_outline('\uf275'),
        cmd_image_plus('\uf17d'),
        cmd_image_search('\uf276'),
        cmd_image_search_outline('\uf277'),
        cmd_image_size_select_actual('\uf592'),
        cmd_image_size_select_large('\uf593'),
        cmd_image_size_select_small('\uf594'),
        cmd_import('\uec00'),
        cmd_inbox('\uef8a'),
        cmd_inbox_arrow_down('\uec01'),
        cmd_inbox_arrow_down_outline('\ufb70'),
        cmd_inbox_arrow_up('\uecd7'),
        cmd_inbox_arrow_up_outline('\ufb71'),
        cmd_inbox_full('\ufb72'),
        cmd_inbox_full_outline('\ufb73'),
        cmd_inbox_multiple('\uf1b0'),
        cmd_inbox_multiple_outline('\uf4ab'),
        cmd_inbox_outline('\ufb74'),
        cmd_incognito('\ueefd'),
        cmd_incognito_off('\ue974'),
        cmd_infinity('\uefe7'),
        cmd_information('\uec02'),
        cmd_information_outline('\uec03'),
        cmd_information_variant('\uef51'),
        cmd_instagram('\uec04'),
        cmd_instrument_triangle('\uf951'),
        cmd_invert_colors('\uec07'),
        cmd_invert_colors_off('\uf74d'),
        cmd_iobroker('\ufbe8'),
        cmd_ip('\uf35e'),
        cmd_ip_network('\uf35f'),
        cmd_ip_network_outline('\uf595'),
        cmd_ipod('\uf596'),
        cmd_islam('\uf278'),
        cmd_island('\uf952'),
        cmd_iv_bag('\uf9b9'),
        cmd_jabber('\uf6d8'),
        cmd_jeepney('\uec08'),
        cmd_jellyfish('\uf804'),
        cmd_jellyfish_outline('\uf805'),
        cmd_jira('\uec09'),
        cmd_jquery('\uf17e'),
        cmd_jsfiddle('\uec0a'),
        cmd_judaism('\uf279'),
        cmd_jump_rope('\ufbff'),
        cmd_kabaddi('\uf68a'),
        cmd_karate('\uf12d'),
        cmd_keg('\uec0b'),
        cmd_kettle('\ueefe'),
        cmd_kettle_alert('\ufc17'),
        cmd_kettle_alert_outline('\ufc18'),
        cmd_kettle_off('\ufc1b'),
        cmd_kettle_off_outline('\ufc1c'),
        cmd_kettle_outline('\uf859'),
        cmd_kettle_steam('\ufc19'),
        cmd_kettle_steam_outline('\ufc1a'),
        cmd_kettlebell('\ufc00'),
        cmd_key('\uec0c'),
        cmd_key_arrow_right('\ufc12'),
        cmd_key_change('\uec0d'),
        cmd_key_link('\ufa9f'),
        cmd_key_minus('\uec0e'),
        cmd_key_outline('\uf6d9'),
        cmd_key_plus('\uec0f'),
        cmd_key_remove('\uec10'),
        cmd_key_star('\ufa9e'),
        cmd_key_variant('\uec11'),
        cmd_key_wireless('\uf8c5'),
        cmd_keyboard('\uec12'),
        cmd_keyboard_backspace('\uec13'),
        cmd_keyboard_caps('\uec14'),
        cmd_keyboard_close('\uec15'),
        cmd_keyboard_esc('\ufbb7'),
        cmd_keyboard_f1('\ufbab'),
        cmd_keyboard_f10('\ufbb4'),
        cmd_keyboard_f11('\ufbb5'),
        cmd_keyboard_f12('\ufbb6'),
        cmd_keyboard_f2('\ufbac'),
        cmd_keyboard_f3('\ufbad'),
        cmd_keyboard_f4('\ufbae'),
        cmd_keyboard_f5('\ufbaf'),
        cmd_keyboard_f6('\ufbb0'),
        cmd_keyboard_f7('\ufbb1'),
        cmd_keyboard_f8('\ufbb2'),
        cmd_keyboard_f9('\ufbb3'),
        cmd_keyboard_off('\uec16'),
        cmd_keyboard_off_outline('\uf74e'),
        cmd_keyboard_outline('\uf27a'),
        cmd_keyboard_return('\uec17'),
        cmd_keyboard_settings('\uf2f8'),
        cmd_keyboard_settings_outline('\uf2f9'),
        cmd_keyboard_space('\uf953'),
        cmd_keyboard_tab('\uec18'),
        cmd_keyboard_variant('\uec19'),
        cmd_khanda('\uf9fd'),
        cmd_kickstarter('\uf048'),
        cmd_klingon('\ufc5b'),
        cmd_knife('\uf2fa'),
        cmd_knife_military('\uf2fb'),
        cmd_kodi('\uec1a'),
        cmd_kubernetes('\uf9fe'),
        cmd_label('\uec1b'),
        cmd_label_multiple('\ufc75'),
        cmd_label_multiple_outline('\ufc76'),
        cmd_label_off('\uf3ca'),
        cmd_label_off_outline('\uf3cb'),
        cmd_label_outline('\uec1c'),
        cmd_label_percent('\ufbea'),
        cmd_label_percent_outline('\ufbeb'),
        cmd_label_variant('\uf3cc'),
        cmd_label_variant_outline('\uf3cd'),
        cmd_ladybug('\uf12e'),
        cmd_lambda('\uef2a'),
        cmd_lamp('\uefb8'),
        cmd_lan('\uec1d'),
        cmd_lan_check('\ufbaa'),
        cmd_lan_connect('\uec1e'),
        cmd_lan_disconnect('\uec1f'),
        cmd_lan_pending('\uec20'),
        cmd_language_c('\uef74'),
        cmd_language_cpp('\uef75'),
        cmd_language_csharp('\uec21'),
        cmd_language_css3('\uec22'),
        cmd_language_fortran('\ufb1a'),
        cmd_language_go('\uf0d4'),
        cmd_language_haskell('\uf597'),
        cmd_language_html5('\uec23'),
        cmd_language_java('\uf43b'),
        cmd_language_javascript('\uec24'),
        cmd_language_kotlin('\ufb19'),
        cmd_language_lua('\uf1b1'),
        cmd_language_markdown('\uec5a'),
        cmd_language_markdown_outline('\uf85e'),
        cmd_language_php('\uec25'),
        cmd_language_python('\uec26'),
        cmd_language_r('\uf0d5'),
        cmd_language_ruby('\uf630'),
        cmd_language_ruby_on_rails('\uf3ce'),
        cmd_language_swift('\uefe8'),
        cmd_language_typescript('\uefe9'),
        cmd_language_xaml('\uef76'),
        cmd_laptop('\uec28'),
        cmd_laptop_chromebook('\uec29'),
        cmd_laptop_mac('\uec2a'),
        cmd_laptop_off('\uefea'),
        cmd_laptop_windows('\uec2b'),
        cmd_laravel('\uf3cf'),
        cmd_lasso('\uf806'),
        cmd_lastpass('\ued4b'),
        cmd_latitude('\uf85a'),
        cmd_launch('\uec2d'),
        cmd_lava_lamp('\uf0d6'),
        cmd_layers('\uec2e'),
        cmd_layers_minus('\uf74f'),
        cmd_layers_off('\uec2f'),
        cmd_layers_off_outline('\uf2fc'),
        cmd_layers_outline('\uf2fd'),
        cmd_layers_plus('\uf750'),
        cmd_layers_remove('\uf751'),
        cmd_layers_search('\ufb06'),
        cmd_layers_search_outline('\ufb07'),
        cmd_layers_triple('\uf85b'),
        cmd_layers_triple_outline('\uf85c'),
        cmd_lead_pencil('\uef52'),
        cmd_leaf('\uec30'),
        cmd_leaf_maple('\uf598'),
        cmd_leaf_maple_off('\ufbda'),
        cmd_leaf_off('\ufbd9'),
        cmd_leak('\uf6da'),
        cmd_leak_off('\uf6db'),
        cmd_led_off('\uec31'),
        cmd_led_on('\uec32'),
        cmd_led_outline('\uec33'),
        cmd_led_strip('\uf0d7'),
        cmd_led_strip_variant('\uf954'),
        cmd_led_variant_off('\uec34'),
        cmd_led_variant_on('\uec35'),
        cmd_led_variant_outline('\uec36'),
        cmd_leek('\ufa7d'),
        cmd_less_than('\uf27b'),
        cmd_less_than_or_equal('\uf27c'),
        cmd_library('\uec37'),
        cmd_library_shelves('\uf4ac'),
        cmd_license('\uf8c6'),
        cmd_lifebuoy('\uf17f'),
        cmd_light_switch('\uf27d'),
        cmd_lightbulb('\uec3b'),
        cmd_lightbulb_cfl('\ufb08'),
        cmd_lightbulb_cfl_off('\ufb09'),
        cmd_lightbulb_cfl_spiral('\ufb75'),
        cmd_lightbulb_cfl_spiral_off('\ufbc3'),
        cmd_lightbulb_group('\ufb53'),
        cmd_lightbulb_group_off('\ufbcd'),
        cmd_lightbulb_group_off_outline('\ufbce'),
        cmd_lightbulb_group_outline('\ufb54'),
        cmd_lightbulb_multiple('\ufb55'),
        cmd_lightbulb_multiple_off('\ufbcf'),
        cmd_lightbulb_multiple_off_outline('\ufbd0'),
        cmd_lightbulb_multiple_outline('\ufb56'),
        cmd_lightbulb_off('\uf752'),
        cmd_lightbulb_off_outline('\uf753'),
        cmd_lightbulb_on('\uefeb'),
        cmd_lightbulb_on_outline('\uefec'),
        cmd_lightbulb_outline('\uec3c'),
        cmd_lighthouse('\uf2fe'),
        cmd_lighthouse_on('\uf2ff'),
        cmd_link('\uec3d'),
        cmd_link_box('\uf61d'),
        cmd_link_box_outline('\uf61e'),
        cmd_link_box_variant('\uf61f'),
        cmd_link_box_variant_outline('\uf620'),
        cmd_link_lock('\uf9ba'),
        cmd_link_off('\uec3e'),
        cmd_link_plus('\uf599'),
        cmd_link_variant('\uec3f'),
        cmd_link_variant_minus('\uf9ff'),
        cmd_link_variant_off('\uec40'),
        cmd_link_variant_plus('\ufa00'),
        cmd_link_variant_remove('\ufa01'),
        cmd_linkedin('\uec41'),
        cmd_linux('\uec43'),
        cmd_linux_mint('\uf1ec'),
        cmd_lipstick('\ufcb4'),
        cmd_litecoin('\uf360'),
        cmd_loading('\uf073'),
        cmd_location_enter('\uf8c7'),
        cmd_location_exit('\uf8c8'),
        cmd_lock('\uec44'),
        cmd_lock_alert('\uf1ed'),
        cmd_lock_check('\ufc9a'),
        cmd_lock_clock('\uf27e'),
        cmd_lock_open('\uec45'),
        cmd_lock_open_alert('\ufc9b'),
        cmd_lock_open_check('\ufc9c'),
        cmd_lock_open_outline('\uec46'),
        cmd_lock_open_variant('\uf8c9'),
        cmd_lock_open_variant_outline('\uf8ca'),
        cmd_lock_outline('\uec47'),
        cmd_lock_pattern('\uefed'),
        cmd_lock_plus('\ueeff'),
        cmd_lock_question('\uf1ee'),
        cmd_lock_reset('\uf074'),
        cmd_lock_smart('\uf1b2'),
        cmd_locker('\uf0d8'),
        cmd_locker_multiple('\uf0d9'),
        cmd_login('\uec48'),
        cmd_logout('\uec49'),
        cmd_logout_variant('\uef00'),
        cmd_longitude('\uf85d'),
        cmd_looks('\uec4a'),
        cmd_loupe('\uec4b'),
        cmd_lumx('\uec4c'),
        cmd_lungs('\uf987'),
        cmd_magnet('\uec4d'),
        cmd_magnet_on('\uec4e'),
        cmd_magnify('\uec4f'),
        cmd_magnify_close('\uf27f'),
        cmd_magnify_minus('\uec50'),
        cmd_magnify_minus_cursor('\uf361'),
        cmd_magnify_minus_outline('\uefef'),
        cmd_magnify_plus('\uec51'),
        cmd_magnify_plus_cursor('\uf362'),
        cmd_magnify_plus_outline('\ueff0'),
        cmd_magnify_remove_cursor('\ufb0c'),
        cmd_magnify_remove_outline('\ufb0d'),
        cmd_magnify_scan('\ufb76'),
        cmd_mail('\uf7be'),
        cmd_mailbox('\ueff1'),
        cmd_mailbox_open('\uf68b'),
        cmd_mailbox_open_outline('\uf68c'),
        cmd_mailbox_open_up('\uf68d'),
        cmd_mailbox_open_up_outline('\uf68e'),
        cmd_mailbox_outline('\uf68f'),
        cmd_mailbox_up('\uf690'),
        cmd_mailbox_up_outline('\uf691'),
        cmd_map('\uec53'),
        cmd_map_check('\uf7bf'),
        cmd_map_check_outline('\uf7c0'),
        cmd_map_clock('\uf621'),
        cmd_map_clock_outline('\uf622'),
        cmd_map_legend('\uf300'),
        cmd_map_marker('\uec54'),
        cmd_map_marker_alert('\uf808'),
        cmd_map_marker_alert_outline('\uf809'),
        cmd_map_marker_check('\uf59a'),
        cmd_map_marker_check_outline('\ufbfb'),
        cmd_map_marker_circle('\uec55'),
        cmd_map_marker_distance('\uf1ef'),
        cmd_map_marker_down('\ufa02'),
        cmd_map_marker_left('\ufbdb'),
        cmd_map_marker_left_outline('\ufbdd'),
        cmd_map_marker_minus('\uef53'),
        cmd_map_marker_minus_outline('\ufbf9'),
        cmd_map_marker_multiple('\uec56'),
        cmd_map_marker_multiple_outline('\ufb77'),
        cmd_map_marker_off('\uec57'),
        cmd_map_marker_off_outline('\ufbfd'),
        cmd_map_marker_outline('\uf0da'),
        cmd_map_marker_path('\uf623'),
        cmd_map_marker_plus('\uef54'),
        cmd_map_marker_plus_outline('\ufbf8'),
        cmd_map_marker_question('\uf80a'),
        cmd_map_marker_question_outline('\uf80b'),
        cmd_map_marker_radius('\uec58'),
        cmd_map_marker_radius_outline('\ufbfc'),
        cmd_map_marker_remove('\uf80c'),
        cmd_map_marker_remove_outline('\ufbfa'),
        cmd_map_marker_remove_variant('\uf80d'),
        cmd_map_marker_right('\ufbdc'),
        cmd_map_marker_right_outline('\ufbde'),
        cmd_map_marker_up('\ufa03'),
        cmd_map_minus('\uf280'),
        cmd_map_outline('\uf281'),
        cmd_map_plus('\uf282'),
        cmd_map_search('\uf283'),
        cmd_map_search_outline('\uf284'),
        cmd_mapbox('\uf4ad'),
        cmd_margin('\uec59'),
        cmd_marker('\uef55'),
        cmd_marker_cancel('\uf6dc'),
        cmd_marker_check('\uec5b'),
        cmd_mastodon('\uf3d0'),
        cmd_material_design('\uf285'),
        cmd_material_ui('\uec5d'),
        cmd_math_compass('\uec5e'),
        cmd_math_cos('\uf59b'),
        cmd_math_integral('\uf8cb'),
        cmd_math_integral_box('\uf8cc'),
        cmd_math_log('\uf988'),
        cmd_math_norm('\uf8cd'),
        cmd_math_norm_box('\uf8ce'),
        cmd_math_sin('\uf59c'),
        cmd_math_tan('\uf59d'),
        cmd_matrix('\uef2b'),
        cmd_medal('\uf286'),
        cmd_medal_outline('\ufc26'),
        cmd_medical_bag('\ueff2'),
        cmd_meditation('\ufa7b'),
        cmd_memory('\uec61'),
        cmd_menu('\uec62'),
        cmd_menu_down('\uec63'),
        cmd_menu_down_outline('\uefb9'),
        cmd_menu_left('\uec64'),
        cmd_menu_left_outline('\uf301'),
        cmd_menu_open('\uf4ae'),
        cmd_menu_right('\uec65'),
        cmd_menu_right_outline('\uf302'),
        cmd_menu_swap('\uf363'),
        cmd_menu_swap_outline('\uf364'),
        cmd_menu_up('\uec66'),
        cmd_menu_up_outline('\uefba'),
        cmd_merge('\uf85f'),
        cmd_message('\uec67'),
        cmd_message_alert('\uec68'),
        cmd_message_alert_outline('\uf303'),
        cmd_message_arrow_left('\ufbf2'),
        cmd_message_arrow_left_outline('\ufbf3'),
        cmd_message_arrow_right('\ufbf4'),
        cmd_message_arrow_right_outline('\ufbf5'),
        cmd_message_bulleted('\uefa5'),
        cmd_message_bulleted_off('\uefa6'),
        cmd_message_cog('\ueff4'),
        cmd_message_cog_outline('\ufa72'),
        cmd_message_draw('\uec69'),
        cmd_message_image('\uec6a'),
        cmd_message_image_outline('\ufa6c'),
        cmd_message_lock('\uf8cf'),
        cmd_message_lock_outline('\ufa6d'),
        cmd_message_minus('\ufa6e'),
        cmd_message_minus_outline('\ufa6f'),
        cmd_message_outline('\uec6b'),
        cmd_message_plus('\uef56'),
        cmd_message_plus_outline('\uf9bb'),
        cmd_message_processing('\uec6c'),
        cmd_message_processing_outline('\ufa70'),
        cmd_message_reply('\uec6d'),
        cmd_message_reply_text('\uec6e'),
        cmd_message_settings('\ueff3'),
        cmd_message_settings_outline('\ufa71'),
        cmd_message_text('\uec6f'),
        cmd_message_text_clock('\ufa73'),
        cmd_message_text_clock_outline('\ufa74'),
        cmd_message_text_lock('\uf8d0'),
        cmd_message_text_lock_outline('\ufa75'),
        cmd_message_text_outline('\uec70'),
        cmd_message_video('\uec71'),
        cmd_meteor('\uef2c'),
        cmd_metronome('\uf0db'),
        cmd_metronome_tick('\uf0dc'),
        cmd_micro_sd('\uf0dd'),
        cmd_microphone('\uec72'),
        cmd_microphone_minus('\uf1b3'),
        cmd_microphone_off('\uec73'),
        cmd_microphone_outline('\uec74'),
        cmd_microphone_plus('\uf1b4'),
        cmd_microphone_settings('\uec75'),
        cmd_microphone_variant('\uec76'),
        cmd_microphone_variant_off('\uec77'),
        cmd_microscope('\uef57'),
        cmd_microsoft('\uec78'),
        cmd_microsoft_access('\ufc8e'),
        cmd_microsoft_azure('\uf106'),
        cmd_microsoft_azure_devops('\uf8d8'),
        cmd_microsoft_bing('\ue9a4'),
        cmd_microsoft_dynamics_365('\uf287'),
        cmd_microsoft_edge('\ueaec'),
        cmd_microsoft_edge_legacy('\ufb50'),
        cmd_microsoft_excel('\ufc8f'),
        cmd_microsoft_internet_explorer('\uec06'),
        cmd_microsoft_office('\ueccc'),
        cmd_microsoft_onedrive('\uecd0'),
        cmd_microsoft_onenote('\uf04a'),
        cmd_microsoft_outlook('\uf625'),
        cmd_microsoft_powerpoint('\ufc90'),
        cmd_microsoft_sharepoint('\ufc91'),
        cmd_microsoft_teams('\uebbf'),
        cmd_microsoft_visual_studio('\uef13'),
        cmd_microsoft_visual_studio_code('\uf31d'),
        cmd_microsoft_windows('\ueeb7'),
        cmd_microsoft_windows_classic('\uf320'),
        cmd_microsoft_word('\ufc92'),
        cmd_microsoft_xbox('\ueebd'),
        cmd_microsoft_xbox_controller('\ueebe'),
        cmd_microsoft_xbox_controller_battery_alert('\uf04e'),
        cmd_microsoft_xbox_controller_battery_charging('\uf321'),
        cmd_microsoft_xbox_controller_battery_empty('\uf04f'),
        cmd_microsoft_xbox_controller_battery_full('\uf050'),
        cmd_microsoft_xbox_controller_battery_low('\uf051'),
        cmd_microsoft_xbox_controller_battery_medium('\uf052'),
        cmd_microsoft_xbox_controller_battery_unknown('\uf053'),
        cmd_microsoft_xbox_controller_menu('\uf772'),
        cmd_microsoft_xbox_controller_off('\ueebf'),
        cmd_microsoft_xbox_controller_view('\uf773'),
        cmd_microsoft_yammer('\uf08a'),
        cmd_microwave('\uf59e'),
        cmd_middleware('\uf860'),
        cmd_middleware_outline('\uf861'),
        cmd_midi('\uf1f0'),
        cmd_midi_port('\uf1f1'),
        cmd_mine('\uf6dd'),
        cmd_minecraft('\uec79'),
        cmd_mini_sd('\uf304'),
        cmd_minidisc('\uf305'),
        cmd_minus('\uec7a'),
        cmd_minus_box('\uec7b'),
        cmd_minus_box_multiple('\ufa41'),
        cmd_minus_box_multiple_outline('\ufa42'),
        cmd_minus_box_outline('\ueff5'),
        cmd_minus_circle('\uec7c'),
        cmd_minus_circle_multiple('\uec60'),
        cmd_minus_circle_multiple_outline('\uf3d2'),
        cmd_minus_circle_outline('\uec7d'),
        cmd_minus_network('\uec7e'),
        cmd_minus_network_outline('\uf59f'),
        cmd_mirror('\ufafd'),
        cmd_mixed_martial_arts('\uf692'),
        cmd_mixed_reality('\uf180'),
        cmd_mixer('\uf0de'),
        cmd_molecule('\uf4af'),
        cmd_molecule_co('\ufbfe'),
        cmd_molecule_co2('\uf0e5'),
        cmd_monitor('\uec7f'),
        cmd_monitor_cellphone('\uf288'),
        cmd_monitor_cellphone_star('\uf289'),
        cmd_monitor_clean('\ufa04'),
        cmd_monitor_dashboard('\uf306'),
        cmd_monitor_edit('\ufbc6'),
        cmd_monitor_eye('\ufcb3'),
        cmd_monitor_lock('\uf6de'),
        cmd_monitor_multiple('\uec80'),
        cmd_monitor_off('\uf693'),
        cmd_monitor_screenshot('\uf754'),
        cmd_monitor_speaker('\uf862'),
        cmd_monitor_speaker_off('\uf863'),
        cmd_monitor_star('\uf6df'),
        cmd_moon_first_quarter('\uf864'),
        cmd_moon_full('\uf865'),
        cmd_moon_last_quarter('\uf866'),
        cmd_moon_new('\uf867'),
        cmd_moon_waning_crescent('\uf868'),
        cmd_moon_waning_gibbous('\uf869'),
        cmd_moon_waxing_crescent('\uf86a'),
        cmd_moon_waxing_gibbous('\uf86b'),
        cmd_moped('\uf989'),
        cmd_more('\uec81'),
        cmd_mother_heart('\ufc14'),
        cmd_mother_nurse('\uf624'),
        cmd_motion_sensor('\uf694'),
        cmd_motorbike('\uec82'),
        cmd_mouse('\uec83'),
        cmd_mouse_bluetooth('\uf28a'),
        cmd_mouse_off('\uec84'),
        cmd_mouse_variant('\uec85'),
        cmd_mouse_variant_off('\uec86'),
        cmd_move_resize('\uef58'),
        cmd_move_resize_variant('\uef59'),
        cmd_movie('\uec87'),
        cmd_movie_edit('\ufa22'),
        cmd_movie_edit_outline('\ufa23'),
        cmd_movie_filter('\ufa24'),
        cmd_movie_filter_outline('\ufa25'),
        cmd_movie_open('\uf8d1'),
        cmd_movie_open_outline('\uf8d2'),
        cmd_movie_outline('\uf6e0'),
        cmd_movie_roll('\uf0df'),
        cmd_movie_search('\ufad2'),
        cmd_movie_search_outline('\ufad3'),
        cmd_muffin('\uf28b'),
        cmd_multiplication('\uec88'),
        cmd_multiplication_box('\uec89'),
        cmd_mushroom('\uf0e0'),
        cmd_mushroom_outline('\uf0e1'),
        cmd_music('\uf05d'),
        cmd_music_accidental_double_flat('\uf86c'),
        cmd_music_accidental_double_sharp('\uf86d'),
        cmd_music_accidental_flat('\uf86e'),
        cmd_music_accidental_natural('\uf86f'),
        cmd_music_accidental_sharp('\uf870'),
        cmd_music_box('\uec8a'),
        cmd_music_box_multiple('\uec39'),
        cmd_music_box_multiple_outline('\uf807'),
        cmd_music_box_outline('\uec8b'),
        cmd_music_circle('\uec8c'),
        cmd_music_circle_outline('\uf3d3'),
        cmd_music_clef_alto('\uf871'),
        cmd_music_clef_bass('\uf872'),
        cmd_music_clef_treble('\uf873'),
        cmd_music_note('\uec8d'),
        cmd_music_note1('\uec8e'),
        cmd_music_note_bluetooth('\uef01'),
        cmd_music_note_bluetooth_off('\uef02'),
        cmd_music_note_eighth_dotted('\uf874'),
        cmd_music_note_half('\uec8f'),
        cmd_music_note_half_dotted('\uf875'),
        cmd_music_note_off('\uec90'),
        cmd_music_note_off_outline('\uf876'),
        cmd_music_note_outline('\uf877'),
        cmd_music_note_plus('\uf6e1'),
        cmd_music_note_quarter('\uec91'),
        cmd_music_note_quarter_dotted('\uf878'),
        cmd_music_note_sixteenth('\uec92'),
        cmd_music_note_sixteenth_dotted('\uf879'),
        cmd_music_note_whole('\uec93'),
        cmd_music_note_whole_dotted('\uf87a'),
        cmd_music_off('\uf05e'),
        cmd_music_rest_eighth('\uf87b'),
        cmd_music_rest_half('\uf87c'),
        cmd_music_rest_quarter('\uf87d'),
        cmd_music_rest_sixteenth('\uf87e'),
        cmd_music_rest_whole('\uf87f'),
        cmd_nail('\uf6e2'),
        cmd_nas('\uf1f2'),
        cmd_nativescript('\uf181'),
        cmd_nature('\uec94'),
        cmd_nature_people('\uec95'),
        cmd_navigation('\uec96'),
        cmd_near_me('\ueed1'),
        cmd_necklace('\uf80e'),
        cmd_needle('\uec97'),
        cmd_netflix('\uf049'),
        cmd_network('\ueff6'),
        cmd_network_off('\uf5a0'),
        cmd_network_off_outline('\uf5a1'),
        cmd_network_outline('\uf5a2'),
        cmd_network_strength_1('\uf1f3'),
        cmd_network_strength_1_alert('\uf1f4'),
        cmd_network_strength_2('\uf1f5'),
        cmd_network_strength_2_alert('\uf1f6'),
        cmd_network_strength_3('\uf1f7'),
        cmd_network_strength_3_alert('\uf1f8'),
        cmd_network_strength_4('\uf1f9'),
        cmd_network_strength_4_alert('\uf1fa'),
        cmd_network_strength_off('\uf1fb'),
        cmd_network_strength_off_outline('\uf1fc'),
        cmd_network_strength_outline('\uf1fd'),
        cmd_new_box('\uec9a'),
        cmd_newspaper('\uec9b'),
        cmd_newspaper_minus('\uf80f'),
        cmd_newspaper_plus('\uf810'),
        cmd_newspaper_variant('\uf904'),
        cmd_newspaper_variant_multiple('\uf905'),
        cmd_newspaper_variant_multiple_outline('\uf906'),
        cmd_newspaper_variant_outline('\uf907'),
        cmd_nfc('\uec9c'),
        cmd_nfc_search_variant('\uf756'),
        cmd_nfc_tap('\uec9d'),
        cmd_nfc_variant('\uec9e'),
        cmd_nfc_variant_off('\uf757'),
        cmd_ninja('\uf075'),
        cmd_nintendo_game_boy('\ufc93'),
        cmd_nintendo_switch('\uf0e2'),
        cmd_nintendo_wii('\ueeaf'),
        cmd_nintendo_wiiu('\uf030'),
        cmd_nix('\ufa05'),
        cmd_nodejs('\uec9f'),
        cmd_noodles('\ufa7e'),
        cmd_not_equal('\uf28c'),
        cmd_not_equal_variant('\uf28d'),
        cmd_note('\ueca0'),
        cmd_note_multiple('\uefbb'),
        cmd_note_multiple_outline('\uefbc'),
        cmd_note_outline('\ueca1'),
        cmd_note_plus('\ueca2'),
        cmd_note_plus_outline('\ueca3'),
        cmd_note_text('\ueca4'),
        cmd_note_text_outline('\ufad7'),
        cmd_notebook('\uf12f'),
        cmd_notebook_multiple('\uf758'),
        cmd_notebook_outline('\uf7c2'),
        cmd_notification_clear_all('\ueca5'),
        cmd_npm('\ueffa'),
        cmd_nuke('\uefa7'),
        cmd_null('\uf0e3'),
        cmd_numeric('\ueca6'),
        cmd_numeric_0_box('\ueca7'),
        cmd_numeric_0_box_multiple('\uf811'),
        cmd_numeric_0_box_multiple_outline('\ueca8'),
        cmd_numeric_0_box_outline('\ueca9'),
        cmd_numeric_1('\uf43d'),
        cmd_numeric_10('\uf8ec'),
        cmd_numeric_10_box('\uf880'),
        cmd_numeric_10_box_multiple('\uf8ed'),
        cmd_numeric_10_box_multiple_outline('\uf8ee'),
        cmd_numeric_10_box_outline('\uf881'),
        cmd_numeric_10_circle('\uf8ef'),
        cmd_numeric_10_circle_outline('\uf8f0'),
        cmd_numeric_1_box('\uecaa'),
        cmd_numeric_1_box_multiple('\uf812'),
        cmd_numeric_1_box_multiple_outline('\uecab'),
        cmd_numeric_1_box_outline('\uecac'),
        cmd_numeric_1_circle('\uf5a3'),
        cmd_numeric_1_circle_outline('\uf5a4'),
        cmd_numeric_2('\uf43e'),
        cmd_numeric_2_box('\uecad'),
        cmd_numeric_2_box_multiple('\uf813'),
        cmd_numeric_2_box_multiple_outline('\uecae'),
        cmd_numeric_2_box_outline('\uecaf'),
        cmd_numeric_2_circle('\uf5a5'),
        cmd_numeric_2_circle_outline('\uf5a6'),
        cmd_numeric_3('\uf43f'),
        cmd_numeric_3_box('\uecb0'),
        cmd_numeric_3_box_multiple('\uf814'),
        cmd_numeric_3_box_multiple_outline('\uecb1'),
        cmd_numeric_3_box_outline('\uecb2'),
        cmd_numeric_3_circle('\uf5a7'),
        cmd_numeric_3_circle_outline('\uf5a8'),
        cmd_numeric_4('\uf440'),
        cmd_numeric_4_box('\uecb3'),
        cmd_numeric_4_box_multiple('\uf815'),
        cmd_numeric_4_box_multiple_outline('\uecb8'),
        cmd_numeric_4_box_outline('\uecb4'),
        cmd_numeric_4_circle('\uf5a9'),
        cmd_numeric_4_circle_outline('\uf5aa'),
        cmd_numeric_5('\uf441'),
        cmd_numeric_5_box('\uecb7'),
        cmd_numeric_5_box_multiple('\uf816'),
        cmd_numeric_5_box_multiple_outline('\uecb5'),
        cmd_numeric_5_box_outline('\uecb6'),
        cmd_numeric_5_circle('\uf5ab'),
        cmd_numeric_5_circle_outline('\uf5ac'),
        cmd_numeric_6('\uf442'),
        cmd_numeric_6_box('\uecb9'),
        cmd_numeric_6_box_multiple('\uf817'),
        cmd_numeric_6_box_multiple_outline('\uecba'),
        cmd_numeric_6_box_outline('\uecbb'),
        cmd_numeric_6_circle('\uf5ad'),
        cmd_numeric_6_circle_outline('\uf5ae'),
        cmd_numeric_7('\uf443'),
        cmd_numeric_7_box('\uecbc'),
        cmd_numeric_7_box_multiple('\uf818'),
        cmd_numeric_7_box_multiple_outline('\uecbd'),
        cmd_numeric_7_box_outline('\uecbe'),
        cmd_numeric_7_circle('\uf5af'),
        cmd_numeric_7_circle_outline('\uf5b0'),
        cmd_numeric_8('\uf444'),
        cmd_numeric_8_box('\uecbf'),
        cmd_numeric_8_box_multiple('\uf819'),
        cmd_numeric_8_box_multiple_outline('\uecc0'),
        cmd_numeric_8_box_outline('\uecc1'),
        cmd_numeric_8_circle('\uf5b1'),
        cmd_numeric_8_circle_outline('\uf5b2'),
        cmd_numeric_9('\uf445'),
        cmd_numeric_9_box('\uecc2'),
        cmd_numeric_9_box_multiple('\uf81a'),
        cmd_numeric_9_box_multiple_outline('\uecc3'),
        cmd_numeric_9_box_outline('\uecc4'),
        cmd_numeric_9_circle('\uf5b3'),
        cmd_numeric_9_circle_outline('\uf5b4'),
        cmd_numeric_9_plus('\uf8f1'),
        cmd_numeric_9_plus_box('\uecc5'),
        cmd_numeric_9_plus_box_multiple('\uf81b'),
        cmd_numeric_9_plus_box_multiple_outline('\uecc6'),
        cmd_numeric_9_plus_box_outline('\uecc7'),
        cmd_numeric_9_plus_circle('\uf5b5'),
        cmd_numeric_9_plus_circle_outline('\uf5b6'),
        cmd_numeric_negative_1('\uf955'),
        cmd_nut('\ueffb'),
        cmd_nutrition('\uecc8'),
        cmd_nuxt('\ufa06'),
        cmd_oar('\uef7f'),
        cmd_ocarina('\uf6e3'),
        cmd_oci('\ufbe9'),
        cmd_ocr('\ufa3a'),
        cmd_octagon('\uecc9'),
        cmd_octagon_outline('\uecca'),
        cmd_octagram('\ueffc'),
        cmd_octagram_outline('\uf076'),
        cmd_odnoklassniki('\ueccb'),
        cmd_offer('\ufb1b'),
        cmd_office_building('\uf290'),
        cmd_oil('\ueccd'),
        cmd_oil_lamp('\uf81c'),
        cmd_oil_level('\uf956'),
        cmd_oil_temperature('\uf8fb'),
        cmd_omega('\ueccf'),
        cmd_one_up('\uf4b0'),
        cmd_onepassword('\uf182'),
        cmd_opacity('\ueed0'),
        cmd_open_in_app('\uecd1'),
        cmd_open_in_new('\uecd2'),
        cmd_open_source_initiative('\uf4b1'),
        cmd_openid('\uecd3'),
        cmd_opera('\uecd4'),
        cmd_orbit('\ue917'),
        cmd_order_alphabetical_ascending('\ueb11'),
        cmd_order_alphabetical_descending('\uf60a'),
        cmd_order_bool_ascending('\uebc2'),
        cmd_order_bool_ascending_variant('\uf28e'),
        cmd_order_bool_descending('\ufc84'),
        cmd_order_bool_descending_variant('\uf28f'),
        cmd_order_numeric_ascending('\uee49'),
        cmd_order_numeric_descending('\uee4a'),
        cmd_origin('\uf446'),
        cmd_ornament('\uecd5'),
        cmd_ornament_variant('\uecd6'),
        cmd_outdoor_lamp('\uf957'),
        cmd_overscan('\uf908'),
        cmd_owl('\uecd8'),
        cmd_pac_man('\uf4b2'),
        cmd_package('\uecd9'),
        cmd_package_down('\uecda'),
        cmd_package_up('\uecdb'),
        cmd_package_variant('\uecdc'),
        cmd_package_variant_closed('\uecdd'),
        cmd_page_first('\uef03'),
        cmd_page_last('\uef04'),
        cmd_page_layout_body('\ueffd'),
        cmd_page_layout_footer('\ueffe'),
        cmd_page_layout_header('\uefff'),
        cmd_page_layout_header_footer('\uf882'),
        cmd_page_layout_sidebar_left('\uf000'),
        cmd_page_layout_sidebar_right('\uf001'),
        cmd_page_next('\uf4b3'),
        cmd_page_next_outline('\uf4b4'),
        cmd_page_previous('\uf4b5'),
        cmd_page_previous_outline('\uf4b6'),
        cmd_palette('\uecde'),
        cmd_palette_advanced('\uecdf'),
        cmd_palette_outline('\uf70f'),
        cmd_palette_swatch('\uf1b5'),
        cmd_palette_swatch_outline('\ufc5c'),
        cmd_palm_tree('\uf958'),
        cmd_pan('\uf4b7'),
        cmd_pan_bottom_left('\uf4b8'),
        cmd_pan_bottom_right('\uf4b9'),
        cmd_pan_down('\uf4ba'),
        cmd_pan_horizontal('\uf4bb'),
        cmd_pan_left('\uf4bc'),
        cmd_pan_right('\uf4bd'),
        cmd_pan_top_left('\uf4be'),
        cmd_pan_top_right('\uf4bf'),
        cmd_pan_up('\uf4c0'),
        cmd_pan_vertical('\uf4c1'),
        cmd_panda('\uece0'),
        cmd_pandora('\uece1'),
        cmd_panorama('\uece2'),
        cmd_panorama_fisheye('\uece3'),
        cmd_panorama_horizontal('\uece4'),
        cmd_panorama_vertical('\uece5'),
        cmd_panorama_wide_angle('\uece6'),
        cmd_paper_cut_vertical('\uece7'),
        cmd_paper_roll('\ufa57'),
        cmd_paper_roll_outline('\ufa58'),
        cmd_paperclip('\uece8'),
        cmd_parachute('\uf5b7'),
        cmd_parachute_outline('\uf5b8'),
        cmd_parking('\uece9'),
        cmd_party_popper('\uf959'),
        cmd_passport('\uf0e4'),
        cmd_passport_biometric('\uf6e4'),
        cmd_pasta('\ufa60'),
        cmd_patio_heater('\uf883'),
        cmd_patreon('\uf183'),
        cmd_pause('\uecea'),
        cmd_pause_circle('\ueceb'),
        cmd_pause_circle_outline('\uecec'),
        cmd_pause_octagon('\ueced'),
        cmd_pause_octagon_outline('\uecee'),
        cmd_paw('\uecef'),
        cmd_paw_off('\uef5a'),
        cmd_pdf_box('\uf759'),
        cmd_peace('\uf185'),
        cmd_peanut('\uf8ff'),
        cmd_peanut_off('\uf900'),
        cmd_peanut_off_outline('\uf902'),
        cmd_peanut_outline('\uf901'),
        cmd_pen('\uecf0'),
        cmd_pen_lock('\uf6e5'),
        cmd_pen_minus('\uf6e6'),
        cmd_pen_off('\uf6e7'),
        cmd_pen_plus('\uf6e8'),
        cmd_pen_remove('\uf6e9'),
        cmd_pencil('\uecf1'),
        cmd_pencil_box('\uecf2'),
        cmd_pencil_box_multiple('\ufa44'),
        cmd_pencil_box_multiple_outline('\ufa45'),
        cmd_pencil_box_outline('\uecf3'),
        cmd_pencil_circle('\uf002'),
        cmd_pencil_circle_outline('\uf077'),
        cmd_pencil_lock('\uecf4'),
        cmd_pencil_lock_outline('\uf6ea'),
        cmd_pencil_minus('\uf6eb'),
        cmd_pencil_minus_outline('\uf6ec'),
        cmd_pencil_off('\uecf5'),
        cmd_pencil_off_outline('\uf6ed'),
        cmd_pencil_outline('\uf5b9'),
        cmd_pencil_plus('\uf6ee'),
        cmd_pencil_plus_outline('\uf6ef'),
        cmd_pencil_remove('\uf6f0'),
        cmd_pencil_remove_outline('\uf6f1'),
        cmd_pencil_ruler('\ufc53'),
        cmd_penguin('\uf7c3'),
        cmd_pentagon('\uf004'),
        cmd_pentagon_outline('\uf003'),
        cmd_percent('\uecf6'),
        cmd_percent_outline('\ufb78'),
        cmd_periodic_table('\uf1b6'),
        cmd_perspective_less('\uf626'),
        cmd_perspective_more('\uf627'),
        cmd_pharmacy('\uecf7'),
        cmd_phone('\uecf8'),
        cmd_phone_alert('\uf81d'),
        cmd_phone_alert_outline('\ufa8e'),
        cmd_phone_bluetooth('\uecf9'),
        cmd_phone_bluetooth_outline('\ufa8f'),
        cmd_phone_cancel('\uf9bc'),
        cmd_phone_cancel_outline('\ufa90'),
        cmd_phone_check('\ufaa9'),
        cmd_phone_check_outline('\ufaaa'),
        cmd_phone_classic('\uef05'),
        cmd_phone_classic_off('\ufb79'),
        cmd_phone_forward('\uecfa'),
        cmd_phone_forward_outline('\ufa91'),
        cmd_phone_hangup('\uecfb'),
        cmd_phone_hangup_outline('\ufa92'),
        cmd_phone_in_talk('\uecfc'),
        cmd_phone_in_talk_outline('\ufa82'),
        cmd_phone_incoming('\uecfd'),
        cmd_phone_incoming_outline('\ufa93'),
        cmd_phone_lock('\uecfe'),
        cmd_phone_lock_outline('\ufa94'),
        cmd_phone_log('\uecff'),
        cmd_phone_log_outline('\ufa95'),
        cmd_phone_message('\ufa96'),
        cmd_phone_message_outline('\ufa97'),
        cmd_phone_minus('\uef5b'),
        cmd_phone_minus_outline('\ufa98'),
        cmd_phone_missed('\ued00'),
        cmd_phone_missed_outline('\ufaa5'),
        cmd_phone_off('\uf6f2'),
        cmd_phone_off_outline('\ufaa6'),
        cmd_phone_outgoing('\ued01'),
        cmd_phone_outgoing_outline('\ufa99'),
        cmd_phone_outline('\uf6f3'),
        cmd_phone_paused('\ued02'),
        cmd_phone_paused_outline('\ufa9a'),
        cmd_phone_plus('\uef5c'),
        cmd_phone_plus_outline('\ufa9b'),
        cmd_phone_return('\uf130'),
        cmd_phone_return_outline('\ufa9c'),
        cmd_phone_ring('\ufaab'),
        cmd_phone_ring_outline('\ufaac'),
        cmd_phone_rotate_landscape('\uf186'),
        cmd_phone_rotate_portrait('\uf187'),
        cmd_phone_settings('\ued03'),
        cmd_phone_settings_outline('\ufa9d'),
        cmd_phone_voip('\ued04'),
        cmd_pi('\ued05'),
        cmd_pi_box('\ued06'),
        cmd_pi_hole('\uf6f4'),
        cmd_piano('\uef80'),
        cmd_pickaxe('\uf1b7'),
        cmd_picture_in_picture_bottom_right('\uf75a'),
        cmd_picture_in_picture_bottom_right_outline('\uf75b'),
        cmd_picture_in_picture_top_right('\uf75c'),
        cmd_picture_in_picture_top_right_outline('\uf75d'),
        cmd_pier('\uf188'),
        cmd_pier_crane('\uf189'),
        cmd_pig('\ued07'),
        cmd_pig_variant('\uf909'),
        cmd_piggy_bank('\uf90a'),
        cmd_pill('\ued08'),
        cmd_pillar('\uf005'),
        cmd_pin('\ued09'),
        cmd_pin_off('\ued0a'),
        cmd_pin_off_outline('\uf22f'),
        cmd_pin_outline('\uf230'),
        cmd_pine_tree('\ued0b'),
        cmd_pine_tree_box('\ued0c'),
        cmd_pinterest('\ued0d'),
        cmd_pinwheel('\uf3d4'),
        cmd_pinwheel_outline('\uf3d5'),
        cmd_pipe('\uf0e6'),
        cmd_pipe_disconnected('\uf0e7'),
        cmd_pipe_leak('\uf18a'),
        cmd_pipe_wrench('\ufc54'),
        cmd_pirate('\uf307'),
        cmd_pistol('\uf006'),
        cmd_piston('\uf18b'),
        cmd_pizza('\ued0f'),
        cmd_play('\ued10'),
        cmd_play_box('\ufb7a'),
        cmd_play_box_multiple('\uf61c'),
        cmd_play_box_outline('\ued11'),
        cmd_play_circle('\ued12'),
        cmd_play_circle_outline('\ued13'),
        cmd_play_network('\uf18c'),
        cmd_play_network_outline('\uf5ba'),
        cmd_play_outline('\uf81e'),
        cmd_play_pause('\ued14'),
        cmd_play_protected_content('\ued15'),
        cmd_play_speed('\uf1fe'),
        cmd_playlist_check('\ueecb'),
        cmd_playlist_edit('\uf1ff'),
        cmd_playlist_minus('\ued16'),
        cmd_playlist_music('\uf5bb'),
        cmd_playlist_music_outline('\uf5bc'),
        cmd_playlist_play('\ued17'),
        cmd_playlist_plus('\ued18'),
        cmd_playlist_remove('\ued19'),
        cmd_playlist_star('\uf6f5'),
        cmd_plex('\uefbd'),
        cmd_plus('\ued1b'),
        cmd_plus_box('\ued1c'),
        cmd_plus_box_multiple('\uec3a'),
        cmd_plus_box_multiple_outline('\ufa43'),
        cmd_plus_box_outline('\uf007'),
        cmd_plus_circle('\ued1d'),
        cmd_plus_circle_multiple('\uec52'),
        cmd_plus_circle_multiple_outline('\ued1e'),
        cmd_plus_circle_outline('\ued1f'),
        cmd_plus_minus('\uf291'),
        cmd_plus_minus_box('\uf292'),
        cmd_plus_network('\ued20'),
        cmd_plus_network_outline('\uf5bd'),
        cmd_plus_one('\ued21'),
        cmd_plus_outline('\uf008'),
        cmd_plus_thick('\ufaec'),
        cmd_podcast('\uf293'),
        cmd_podium('\uf628'),
        cmd_podium_bronze('\uf629'),
        cmd_podium_gold('\uf62a'),
        cmd_podium_silver('\uf62b'),
        cmd_point_of_sale('\uf695'),
        cmd_pokeball('\ued23'),
        cmd_pokemon_go('\uf308'),
        cmd_poker_chip('\uf131'),
        cmd_polaroid('\ued24'),
        cmd_police_badge('\ufa67'),
        cmd_police_badge_outline('\ufa68'),
        cmd_poll('\ued25'),
        cmd_poll_box('\ued26'),
        cmd_poll_box_outline('\ufb7b'),
        cmd_polymer('\ued27'),
        cmd_pool('\uef09'),
        cmd_popcorn('\ued28'),
        cmd_post('\uf90b'),
        cmd_post_outline('\uf90c'),
        cmd_postage_stamp('\uf5be'),
        cmd_pot('\uebea'),
        cmd_pot_mix('\uef5e'),
        cmd_pot_mix_outline('\uef7a'),
        cmd_pot_outline('\uec05'),
        cmd_pot_steam('\uef5d'),
        cmd_pot_steam_outline('\uec2c'),
        cmd_pound('\ued29'),
        cmd_pound_box('\ued2a'),
        cmd_pound_box_outline('\ufa7f'),
        cmd_power('\ued2b'),
        cmd_power_cycle('\uf200'),
        cmd_power_off('\uf201'),
        cmd_power_on('\uf202'),
        cmd_power_plug('\uefa8'),
        cmd_power_plug_off('\uefa9'),
        cmd_power_settings('\ued2c'),
        cmd_power_sleep('\uf203'),
        cmd_power_socket('\ued2d'),
        cmd_power_socket_au('\uf204'),
        cmd_power_socket_de('\ufa07'),
        cmd_power_socket_eu('\uf0e8'),
        cmd_power_socket_fr('\ufa08'),
        cmd_power_socket_jp('\ufa09'),
        cmd_power_socket_uk('\uf0e9'),
        cmd_power_socket_us('\uf0ea'),
        cmd_power_standby('\uf205'),
        cmd_powershell('\uf309'),
        cmd_prescription('\uf009'),
        cmd_presentation('\ued2e'),
        cmd_presentation_play('\ued2f'),
        cmd_printer('\ued30'),
        cmd_printer_3d('\ued31'),
        cmd_printer_3d_nozzle('\uf75e'),
        cmd_printer_3d_nozzle_alert('\ufac0'),
        cmd_printer_3d_nozzle_alert_outline('\ufac1'),
        cmd_printer_3d_nozzle_outline('\uf75f'),
        cmd_printer_alert('\ued32'),
        cmd_printer_check('\ufa46'),
        cmd_printer_off('\uf760'),
        cmd_printer_pos('\uf95a'),
        cmd_printer_settings('\uf00a'),
        cmd_printer_wireless('\uf30a'),
        cmd_priority_high('\uef06'),
        cmd_priority_low('\uef07'),
        cmd_professional_hexagon('\ued33'),
        cmd_progress_alert('\uf5bf'),
        cmd_progress_check('\uf294'),
        cmd_progress_clock('\uf295'),
        cmd_progress_close('\ufa0a'),
        cmd_progress_download('\uf296'),
        cmd_progress_upload('\uf297'),
        cmd_progress_wrench('\uf5c0'),
        cmd_projector('\ued34'),
        cmd_projector_screen('\ued35'),
        cmd_propane_tank('\ufc57'),
        cmd_propane_tank_outline('\ufc58'),
        cmd_protocol('\uf8db'),
        cmd_publish('\uefaa'),
        cmd_pulse('\ued36'),
        cmd_pumpkin('\uf4c2'),
        cmd_purse('\uf81f'),
        cmd_purse_outline('\uf820'),
        cmd_puzzle('\ued37'),
        cmd_puzzle_outline('\uf365'),
        cmd_qi('\uf298'),
        cmd_qqchat('\uef08'),
        cmd_qrcode('\ued38'),
        cmd_qrcode_edit('\uf1b8'),
        cmd_qrcode_minus('\ufa8c'),
        cmd_qrcode_plus('\ufa8b'),
        cmd_qrcode_remove('\ufa8d'),
        cmd_qrcode_scan('\ued39'),
        cmd_quadcopter('\ued3a'),
        cmd_quality_high('\ued3b'),
        cmd_quality_low('\uf30b'),
        cmd_quality_medium('\uf30c'),
        cmd_quora('\uf62c'),
        cmd_rabbit('\uf206'),
        cmd_racing_helmet('\uf696'),
        cmd_racquetball('\uf697'),
        cmd_radar('\ued3d'),
        cmd_radiator('\ued3e'),
        cmd_radiator_disabled('\uf3d6'),
        cmd_radiator_off('\uf3d7'),
        cmd_radio('\ued3f'),
        cmd_radio_am('\uf5c1'),
        cmd_radio_fm('\uf5c2'),
        cmd_radio_handheld('\ued40'),
        cmd_radio_off('\ufb1c'),
        cmd_radio_tower('\ued41'),
        cmd_radioactive('\ued42'),
        cmd_radioactive_off('\uf7c4'),
        cmd_radiobox_marked('\ued43'),
        cmd_radius('\uf5c3'),
        cmd_radius_outline('\uf5c4'),
        cmd_railroad_light('\uf821'),
        cmd_raspberry_pi('\ued44'),
        cmd_ray_end('\ued45'),
        cmd_ray_end_arrow('\ued46'),
        cmd_ray_start('\ued47'),
        cmd_ray_start_arrow('\ued48'),
        cmd_ray_start_end('\ued49'),
        cmd_ray_vertex('\ued4a'),
        cmd_react('\uf00b'),
        cmd_read('\ued4c'),
        cmd_receipt('\ued4e'),
        cmd_record('\ued4f'),
        cmd_record_circle('\uf7c5'),
        cmd_record_circle_outline('\uf7c6'),
        cmd_record_player('\uf299'),
        cmd_record_rec('\ued50'),
        cmd_rectangle('\uf761'),
        cmd_rectangle_outline('\uf762'),
        cmd_recycle('\ued51'),
        cmd_recycle_variant('\ufc9d'),
        cmd_reddit('\ued52'),
        cmd_redhat('\ufa1b'),
        cmd_redo('\ued53'),
        cmd_redo_variant('\ued54'),
        cmd_reflect_horizontal('\uf30d'),
        cmd_reflect_vertical('\uf30e'),
        cmd_refresh('\ued55'),
        cmd_refresh_circle('\ufc77'),
        cmd_regex('\ued56'),
        cmd_registered_trademark('\uf366'),
        cmd_relative_scale('\ued57'),
        cmd_reload('\ued58'),
        cmd_reload_alert('\ufa0b'),
        cmd_reminder('\uf18d'),
        cmd_remote('\ued59'),
        cmd_remote_desktop('\uf1b9'),
        cmd_remote_off('\uf7c7'),
        cmd_remote_tv('\uf7c8'),
        cmd_remote_tv_off('\uf7c9'),
        cmd_rename_box('\ued5a'),
        cmd_reorder_horizontal('\uef8b'),
        cmd_reorder_vertical('\uef8c'),
        cmd_repeat('\ued5b'),
        cmd_repeat_off('\ued5c'),
        cmd_repeat_once('\ued5d'),
        cmd_replay('\ued5e'),
        cmd_reply('\ued5f'),
        cmd_reply_all('\ued60'),
        cmd_reply_all_outline('\uf822'),
        cmd_reply_circle('\ufaae'),
        cmd_reply_outline('\uf823'),
        cmd_reproduction('\ued61'),
        cmd_resistor('\uf447'),
        cmd_resistor_nodes('\uf448'),
        cmd_resize('\uf367'),
        cmd_resize_bottom_right('\ued62'),
        cmd_responsive('\ued63'),
        cmd_restart('\uf00c'),
        cmd_restart_alert('\ufa0c'),
        cmd_restart_off('\uf698'),
        cmd_restore('\uf29a'),
        cmd_restore_alert('\ufa0d'),
        cmd_rewind('\ued64'),
        cmd_rewind_10('\uf62d'),
        cmd_rewind_30('\uf699'),
        cmd_rewind_5('\ufaf9'),
        cmd_rewind_outline('\uf00d'),
        cmd_rhombus('\uf00e'),
        cmd_rhombus_medium('\uf30f'),
        cmd_rhombus_outline('\uf00f'),
        cmd_rhombus_split('\uf310'),
        cmd_ribbon('\ued65'),
        cmd_rice('\uf0eb'),
        cmd_ring('\uf0ec'),
        cmd_rivet('\uf763'),
        cmd_road('\ued66'),
        cmd_road_variant('\ued67'),
        cmd_robber('\uf95b'),
        cmd_robot('\uefac'),
        cmd_robot_industrial('\uf449'),
        cmd_robot_mower('\ufaf7'),
        cmd_robot_mower_outline('\ufaf3'),
        cmd_robot_vacuum('\uf010'),
        cmd_robot_vacuum_variant('\uf207'),
        cmd_rocket('\ued68'),
        cmd_rocket_outline('\ufcae'),
        cmd_rodent('\ufc27'),
        cmd_roller_skate('\uf62e'),
        cmd_roller_skate_off('\uea48'),
        cmd_rollerblade('\uf62f'),
        cmd_rollerblade_off('\ue92d'),
        cmd_rollupjs('\uf4c3'),
        cmd_roman_numeral_2('\uf98b'),
        cmd_roman_numeral_3('\uf98c'),
        cmd_roman_numeral_4('\uf98d'),
        cmd_roman_numeral_6('\uf98e'),
        cmd_roman_numeral_7('\uf98f'),
        cmd_roman_numeral_8('\uf990'),
        cmd_roman_numeral_9('\uf991'),
        cmd_room_service('\uf18e'),
        cmd_room_service_outline('\uf69a'),
        cmd_rotate_3d('\uf7ca'),
        cmd_rotate_3d_variant('\ued69'),
        cmd_rotate_left('\ued6a'),
        cmd_rotate_left_variant('\ued6b'),
        cmd_rotate_orbit('\uf69b'),
        cmd_rotate_right('\ued6c'),
        cmd_rotate_right_variant('\ued6d'),
        cmd_rounded_corner('\uef0a'),
        cmd_router('\ufae2'),
        cmd_router_network('\uf98a'),
        cmd_router_wireless('\ued6e'),
        cmd_router_wireless_settings('\uf368'),
        cmd_routes('\ued6f'),
        cmd_routes_clock('\uf95c'),
        cmd_rowing('\uef0b'),
        cmd_rss('\ued70'),
        cmd_rss_box('\ued71'),
        cmd_rss_off('\uf824'),
        cmd_rugby('\uf69c'),
        cmd_ruler('\ued72'),
        cmd_ruler_square('\uf5c5'),
        cmd_ruler_square_compass('\uf7c1'),
        cmd_run('\uf011'),
        cmd_run_fast('\ued73'),
        cmd_rv_truck('\ufad4'),
        cmd_sack('\uf631'),
        cmd_sack_percent('\uf632'),
        cmd_safe('\uf369'),
        cmd_safe_square('\ufb7c'),
        cmd_safe_square_outline('\ufb7d'),
        cmd_safety_goggles('\uf633'),
        cmd_sail_boat('\uf7cb'),
        cmd_sale('\ued74'),
        cmd_salesforce('\uf18f'),
        cmd_sass('\uf0ed'),
        cmd_satellite('\ued75'),
        cmd_satellite_uplink('\uf208'),
        cmd_satellite_variant('\ued76'),
        cmd_sausage('\uf1ba'),
        cmd_saw_blade('\uf764'),
        cmd_saxophone('\uef0c'),
        cmd_scale('\ued77'),
        cmd_scale_balance('\ueed5'),
        cmd_scale_bathroom('\ued78'),
        cmd_scale_off('\uf95d'),
        cmd_scanner('\uefae'),
        cmd_scanner_off('\uf209'),
        cmd_scatter_plot('\uf7cc'),
        cmd_scatter_plot_outline('\uf7cd'),
        cmd_school('\ued79'),
        cmd_school_outline('\ufa80'),
        cmd_scissors_cutting('\uf36a'),
        cmd_scooter('\ufae9'),
        cmd_scoreboard('\ufb7e'),
        cmd_scoreboard_outline('\ufb7f'),
        cmd_screen_rotation('\ued7a'),
        cmd_screen_rotation_lock('\ued7d'),
        cmd_screw_flat_top('\uf6f6'),
        cmd_screw_lag('\uf6f7'),
        cmd_screw_machine_flat_top('\uf6f8'),
        cmd_screw_machine_round_top('\uf6f9'),
        cmd_screw_round_top('\uf6fa'),
        cmd_screwdriver('\ued7b'),
        cmd_script('\uf4c4'),
        cmd_script_outline('\ued7c'),
        cmd_script_text('\uf4c5'),
        cmd_script_text_outline('\uf4c6'),
        cmd_sd('\ued7e'),
        cmd_seal('\ued7f'),
        cmd_seal_variant('\uf8dc'),
        cmd_search_web('\uf012'),
        cmd_seat('\uf5c6'),
        cmd_seat_flat('\ued80'),
        cmd_seat_flat_angled('\ued81'),
        cmd_seat_individual_suite('\ued82'),
        cmd_seat_legroom_extra('\ued83'),
        cmd_seat_legroom_normal('\ued84'),
        cmd_seat_legroom_reduced('\ued85'),
        cmd_seat_outline('\uf5c7'),
        cmd_seat_passenger('\ufb49'),
        cmd_seat_recline_extra('\ued86'),
        cmd_seat_recline_normal('\ued87'),
        cmd_seatbelt('\uf5c8'),
        cmd_security('\ued88'),
        cmd_security_network('\ued89'),
        cmd_seed('\uf765'),
        cmd_seed_outline('\uf766'),
        cmd_segment('\uf7ce'),
        cmd_select('\ued8a'),
        cmd_select_all('\ued8b'),
        cmd_select_color('\uf634'),
        cmd_select_compare('\uf3d8'),
        cmd_select_drag('\uf36b'),
        cmd_select_group('\uf885'),
        cmd_select_inverse('\ued8c'),
        cmd_select_marker('\ufb80'),
        cmd_select_multiple('\ufb81'),
        cmd_select_multiple_marker('\ufb82'),
        cmd_select_off('\ued8d'),
        cmd_select_place('\uf8dd'),
        cmd_select_search('\ufb04'),
        cmd_selection('\ued8e'),
        cmd_selection_drag('\uf36c'),
        cmd_selection_ellipse('\uf635'),
        cmd_selection_ellipse_arrow_inside('\uf825'),
        cmd_selection_marker('\ufb83'),
        cmd_selection_multiple_marker('\ufb84'),
        cmd_selection_mutliple('\ufb85'),
        cmd_selection_off('\uf078'),
        cmd_selection_search('\ufb05'),
        cmd_semantic_web('\ufc16'),
        cmd_send('\ued8f'),
        cmd_send_check('\ufa61'),
        cmd_send_check_outline('\ufa62'),
        cmd_send_circle('\uf6fb'),
        cmd_send_circle_outline('\uf6fc'),
        cmd_send_clock('\ufa63'),
        cmd_send_clock_outline('\ufa64'),
        cmd_send_lock('\uf0ee'),
        cmd_send_lock_outline('\ufa66'),
        cmd_send_outline('\ufa65'),
        cmd_serial_port('\uef5f'),
        cmd_server('\ued90'),
        cmd_server_minus('\ued91'),
        cmd_server_network('\ued92'),
        cmd_server_network_off('\ued93'),
        cmd_server_off('\ued94'),
        cmd_server_plus('\ued95'),
        cmd_server_remove('\ued96'),
        cmd_server_security('\ued97'),
        cmd_set_all('\uf079'),
        cmd_set_center('\uf07a'),
        cmd_set_center_right('\uf07b'),
        cmd_set_left('\uf07c'),
        cmd_set_left_center('\uf07d'),
        cmd_set_left_right('\uf07e'),
        cmd_set_none('\uf07f'),
        cmd_set_right('\uf080'),
        cmd_set_top_box('\uf29e'),
        cmd_settings_helper('\uf36d'),
        cmd_shaker('\ufa0e'),
        cmd_shaker_outline('\ufa0f'),
        cmd_shape('\uf132'),
        cmd_shape_circle_plus('\uef60'),
        cmd_shape_outline('\uf133'),
        cmd_shape_oval_plus('\ufafa'),
        cmd_shape_plus('\ued9a'),
        cmd_shape_polygon_plus('\uef61'),
        cmd_shape_rectangle_plus('\uef62'),
        cmd_shape_square_plus('\uef63'),
        cmd_share('\ued9b'),
        cmd_share_all('\ufaf4'),
        cmd_share_all_outline('\ufaf5'),
        cmd_share_circle('\ufaad'),
        cmd_share_off('\uf826'),
        cmd_share_off_outline('\uf827'),
        cmd_share_outline('\uf231'),
        cmd_share_variant('\ued9c'),
        cmd_sheep('\uf5c9'),
        cmd_shield('\ued9d'),
        cmd_shield_account('\uf190'),
        cmd_shield_account_outline('\uf311'),
        cmd_shield_airplane('\uefbe'),
        cmd_shield_airplane_outline('\uf5ca'),
        cmd_shield_alert('\uf7cf'),
        cmd_shield_alert_outline('\uf7d0'),
        cmd_shield_car('\uf886'),
        cmd_shield_check('\uee69'),
        cmd_shield_check_outline('\uf5cb'),
        cmd_shield_cross('\uf5cc'),
        cmd_shield_cross_outline('\uf5cd'),
        cmd_shield_edit('\ufaa0'),
        cmd_shield_edit_outline('\ufaa1'),
        cmd_shield_half('\ufc60'),
        cmd_shield_half_full('\uf081'),
        cmd_shield_home('\uef8d'),
        cmd_shield_home_outline('\uf5ce'),
        cmd_shield_key('\uf4c7'),
        cmd_shield_key_outline('\uf4c8'),
        cmd_shield_link_variant('\uf636'),
        cmd_shield_link_variant_outline('\uf637'),
        cmd_shield_lock('\uf29c'),
        cmd_shield_lock_outline('\uf5cf'),
        cmd_shield_off('\uf29d'),
        cmd_shield_off_outline('\uf29b'),
        cmd_shield_outline('\ued9e'),
        cmd_shield_plus('\uf3d9'),
        cmd_shield_plus_outline('\uf3da'),
        cmd_shield_refresh('\ue9aa'),
        cmd_shield_refresh_outline('\ueae3'),
        cmd_shield_remove('\uf3db'),
        cmd_shield_remove_outline('\uf3dc'),
        cmd_shield_search('\uf69d'),
        cmd_shield_star('\ufa3b'),
        cmd_shield_star_outline('\ufa3c'),
        cmd_shield_sun('\uf960'),
        cmd_shield_sun_outline('\uf961'),
        cmd_shield_sync('\ufaa2'),
        cmd_shield_sync_outline('\ufaa3'),
        cmd_ship_wheel('\uf134'),
        cmd_shoe_formal('\uf44a'),
        cmd_shoe_heel('\uf44b'),
        cmd_shoe_print('\uf6fd'),
        cmd_shopping('\ued9f'),
        cmd_shopping_music('\ueda0'),
        cmd_shopping_outline('\ufad5'),
        cmd_shopping_search('\uf887'),
        cmd_shovel('\uf013'),
        cmd_shovel_off('\uf014'),
        cmd_shower('\uf29f'),
        cmd_shower_head('\uf2a0'),
        cmd_shredder('\ueda1'),
        cmd_shuffle('\ueda2'),
        cmd_shuffle_disabled('\ueda3'),
        cmd_shuffle_variant('\ueda4'),
        cmd_shuriken('\ufc7f'),
        cmd_sigma('\ueda5'),
        cmd_sigma_lower('\uef2e'),
        cmd_sign_caution('\ueda6'),
        cmd_sign_direction('\uf082'),
        cmd_sign_direction_minus('\uf903'),
        cmd_sign_direction_plus('\uf8df'),
        cmd_sign_direction_remove('\uf8e0'),
        cmd_sign_real_estate('\ufa18'),
        cmd_sign_text('\uf083'),
        cmd_signal('\ueda7'),
        cmd_signal_2g('\uf015'),
        cmd_signal_3g('\uf016'),
        cmd_signal_4g('\uf017'),
        cmd_signal_5g('\uf36e'),
        cmd_signal_cellular_1('\uf1bc'),
        cmd_signal_cellular_2('\uf1bd'),
        cmd_signal_cellular_3('\uf1be'),
        cmd_signal_cellular_outline('\uf1bf'),
        cmd_signal_distance_variant('\uf767'),
        cmd_signal_hspa('\uf018'),
        cmd_signal_hspa_plus('\uf019'),
        cmd_signal_off('\uf084'),
        cmd_signal_variant('\uef0d'),
        cmd_signature('\uf6fe'),
        cmd_signature_freehand('\uf6ff'),
        cmd_signature_image('\uf700'),
        cmd_signature_text('\uf701'),
        cmd_silo('\uf44c'),
        cmd_silverware('\ueda8'),
        cmd_silverware_clean('\uf8e1'),
        cmd_silverware_fork('\ueda9'),
        cmd_silverware_fork_knife('\uf36f'),
        cmd_silverware_spoon('\uedaa'),
        cmd_silverware_variant('\uedab'),
        cmd_sim('\uedac'),
        cmd_sim_alert('\uedad'),
        cmd_sim_off('\uedae'),
        cmd_simple_icons('\ufc1d'),
        cmd_sina_weibo('\uf3de'),
        cmd_sitemap('\uedaf'),
        cmd_size_m('\ufca5'),
        cmd_size_s('\ufca4'),
        cmd_size_xl('\ufca6'),
        cmd_size_xs('\ufca3'),
        cmd_size_xxl('\ufca7'),
        cmd_size_xxs('\ufca2'),
        cmd_size_xxxl('\ufca8'),
        cmd_skate('\uf638'),
        cmd_skew_less('\uf639'),
        cmd_skew_more('\uf63a'),
        cmd_ski('\ufc04'),
        cmd_ski_cross_country('\ufc05'),
        cmd_ski_water('\ufc06'),
        cmd_skip_backward('\uedb0'),
        cmd_skip_backward_outline('\uf828'),
        cmd_skip_forward('\uedb1'),
        cmd_skip_forward_outline('\uf829'),
        cmd_skip_next('\uedb2'),
        cmd_skip_next_circle('\uef64'),
        cmd_skip_next_circle_outline('\uef65'),
        cmd_skip_next_outline('\uf82a'),
        cmd_skip_previous('\uedb3'),
        cmd_skip_previous_circle('\uef66'),
        cmd_skip_previous_circle_outline('\uef67'),
        cmd_skip_previous_outline('\uf82b'),
        cmd_skull('\uef8f'),
        cmd_skull_crossbones('\uf4c9'),
        cmd_skull_crossbones_outline('\uf4ca'),
        cmd_skull_outline('\uf4cb'),
        cmd_skype('\uedb4'),
        cmd_skype_business('\uedb5'),
        cmd_slack('\uedb6'),
        cmd_slash_forward('\uf8e2'),
        cmd_slash_forward_box('\uf8e3'),
        cmd_sleep('\uedb7'),
        cmd_sleep_off('\uedb8'),
        cmd_slope_downhill('\uf702'),
        cmd_slope_uphill('\uf703'),
        cmd_slot_machine('\ufa14'),
        cmd_slot_machine_outline('\ufa15'),
        cmd_smart_card('\uf9bd'),
        cmd_smart_card_outline('\uf9be'),
        cmd_smart_card_reader('\uf9bf'),
        cmd_smart_card_reader_outline('\uf9c0'),
        cmd_smog('\uf370'),
        cmd_smoke_detector('\uec98'),
        cmd_smoking('\uedb9'),
        cmd_smoking_off('\uedba'),
        cmd_snapchat('\uedbb'),
        cmd_snowboard('\ufc07'),
        cmd_snowflake('\uf01a'),
        cmd_snowflake_alert('\uf82c'),
        cmd_snowflake_melt('\ufbcb'),
        cmd_snowflake_variant('\uf82d'),
        cmd_snowman('\uedbc'),
        cmd_soccer('\uedbd'),
        cmd_soccer_field('\uf135'),
        cmd_sofa('\uedbe'),
        cmd_solar_panel('\uf69e'),
        cmd_solar_panel_large('\uf69f'),
        cmd_solar_power('\uf371'),
        cmd_soldering_iron('\uf992'),
        cmd_solid('\uef90'),
        cmd_sony_playstation('\ued1a'),
        cmd_sort('\uedbf'),
        cmd_sort_alphabetical_ascending('\ueec1'),
        cmd_sort_alphabetical_ascending_variant('\ufa48'),
        cmd_sort_alphabetical_descending('\ueec3'),
        cmd_sort_alphabetical_descending_variant('\ufa49'),
        cmd_sort_alphabetical_variant('\uedc0'),
        cmd_sort_ascending('\uedc1'),
        cmd_sort_bool_ascending('\ufc85'),
        cmd_sort_bool_ascending_variant('\ufc86'),
        cmd_sort_bool_descending('\ufc87'),
        cmd_sort_bool_descending_variant('\ufc88'),
        cmd_sort_descending('\uedc2'),
        cmd_sort_numeric_ascending('\ufc89'),
        cmd_sort_numeric_ascending_variant('\uf20c'),
        cmd_sort_numeric_descending('\ufc8a'),
        cmd_sort_numeric_descending_variant('\uf3d1'),
        cmd_sort_numeric_variant('\uedc3'),
        cmd_sort_reverse_variant('\uec42'),
        cmd_sort_variant('\uedc4'),
        cmd_sort_variant_lock('\uf5d0'),
        cmd_sort_variant_lock_open('\uf5d1'),
        cmd_sort_variant_remove('\ufa47'),
        cmd_soundcloud('\uedc5'),
        cmd_source_branch('\uef2f'),
        cmd_source_commit('\uf01b'),
        cmd_source_commit_end('\uf01c'),
        cmd_source_commit_end_local('\uf01d'),
        cmd_source_commit_local('\uf01e'),
        cmd_source_commit_next_local('\uf01f'),
        cmd_source_commit_start('\uf020'),
        cmd_source_commit_start_next_local('\uf021'),
        cmd_source_fork('\uedc6'),
        cmd_source_merge('\uef30'),
        cmd_source_pull('\uedc7'),
        cmd_source_repository('\uf5d2'),
        cmd_source_repository_multiple('\uf5d3'),
        cmd_soy_sauce('\uf0ef'),
        cmd_spa('\uf5d4'),
        cmd_spa_outline('\uf5d5'),
        cmd_space_invaders('\uf4cc'),
        cmd_space_station('\ufc83'),
        cmd_spade('\uf768'),
        cmd_speaker('\uedc8'),
        cmd_speaker_bluetooth('\uf2a1'),
        cmd_speaker_multiple('\uf63b'),
        cmd_speaker_off('\uedc9'),
        cmd_speaker_wireless('\uf022'),
        cmd_speedometer('\uedca'),
        cmd_speedometer_medium('\uf888'),
        cmd_speedometer_slow('\uf889'),
        cmd_spellcheck('\uedcb'),
        cmd_spider('\ufaea'),
        cmd_spider_thread('\ufaeb'),
        cmd_spider_web('\uf4cd'),
        cmd_spotify('\uedcc'),
        cmd_spotlight('\uedcd'),
        cmd_spotlight_beam('\uedce'),
        cmd_spray('\uef68'),
        cmd_spray_bottle('\uf3df'),
        cmd_sprinkler('\uf962'),
        cmd_sprinkler_variant('\uf963'),
        cmd_sprout('\uf769'),
        cmd_sprout_outline('\uf76a'),
        cmd_square('\uf067'),
        cmd_square_edit_outline('\uf20b'),
        cmd_square_medium('\uf312'),
        cmd_square_medium_outline('\uf313'),
        cmd_square_off('\ufbee'),
        cmd_square_off_outline('\ufbef'),
        cmd_square_outline('\uf066'),
        cmd_square_root('\uf085'),
        cmd_square_root_box('\uf2a2'),
        cmd_square_small('\uf314'),
        cmd_squeegee('\uf3e0'),
        cmd_ssh('\uf1c0'),
        cmd_stack_exchange('\uef0e'),
        cmd_stack_overflow('\uedd1'),
        cmd_stackpath('\uec5f'),
        cmd_stadium('\uf8fc'),
        cmd_stadium_variant('\uf023'),
        cmd_stairs('\uedd2'),
        cmd_stairs_box('\ufc9e'),
        cmd_stairs_down('\ufbbe'),
        cmd_stairs_up('\ufbbd'),
        cmd_stamper('\uf63c'),
        cmd_standard_definition('\uf0f0'),
        cmd_star('\uedd3'),
        cmd_star_box('\uf372'),
        cmd_star_box_multiple('\ufb86'),
        cmd_star_box_multiple_outline('\ufb87'),
        cmd_star_box_outline('\uf373'),
        cmd_star_circle('\uedd4'),
        cmd_star_circle_outline('\uf2a3'),
        cmd_star_face('\uf2a4'),
        cmd_star_four_points('\uf3e1'),
        cmd_star_four_points_outline('\uf3e2'),
        cmd_star_half('\ueb4a'),
        cmd_star_half_full('\uedd5'),
        cmd_star_off('\uedd6'),
        cmd_star_outline('\uedd7'),
        cmd_star_three_points('\uf3e3'),
        cmd_star_three_points_outline('\uf3e4'),
        cmd_state_machine('\ufaef'),
        cmd_steam('\uedd8'),
        cmd_steering('\uedd9'),
        cmd_steering_off('\uf20d'),
        cmd_step_backward('\uedda'),
        cmd_step_backward_2('\ueddb'),
        cmd_step_forward('\ueddc'),
        cmd_step_forward_2('\ueddd'),
        cmd_stethoscope('\uedde'),
        cmd_sticker('\ufc64'),
        cmd_sticker_alert('\ufc65'),
        cmd_sticker_alert_outline('\ufc66'),
        cmd_sticker_check('\ufc67'),
        cmd_sticker_check_outline('\ufc68'),
        cmd_sticker_circle_outline('\ueed4'),
        cmd_sticker_emoji('\uf086'),
        cmd_sticker_minus('\ufc69'),
        cmd_sticker_minus_outline('\ufc6a'),
        cmd_sticker_outline('\ufc6b'),
        cmd_sticker_plus('\ufc6c'),
        cmd_sticker_plus_outline('\ufc6d'),
        cmd_sticker_remove('\ufc6e'),
        cmd_sticker_remove_outline('\ufc6f'),
        cmd_stocking('\ueddf'),
        cmd_stomach('\uf993'),
        cmd_stop('\uede0'),
        cmd_stop_circle('\uef69'),
        cmd_stop_circle_outline('\uef6a'),
        cmd_store('\uede1'),
        cmd_store_24_hour('\uede2'),
        cmd_store_outline('\ufc61'),
        cmd_storefront('\uf0c8'),
        cmd_storefront_outline('\uf9c1'),
        cmd_stove('\uede3'),
        cmd_strategy('\ufad6'),
        cmd_stretch_to_page('\uf82e'),
        cmd_stretch_to_page_outline('\uf82f'),
        cmd_string_lights('\ufbba'),
        cmd_string_lights_off('\ufbbb'),
        cmd_subdirectory_arrow_left('\uef0f'),
        cmd_subdirectory_arrow_right('\uef10'),
        cmd_subtitles('\uf315'),
        cmd_subtitles_outline('\uf316'),
        cmd_subway('\uefaf'),
        cmd_subway_alert_variant('\uf6a0'),
        cmd_subway_variant('\uede4'),
        cmd_summit('\uf087'),
        cmd_sunglasses('\uede5'),
        cmd_surround_sound('\ueec9'),
        cmd_surround_sound_2_0('\uf0f1'),
        cmd_surround_sound_3_1('\uf0f2'),
        cmd_surround_sound_5_1('\uf0f3'),
        cmd_surround_sound_7_1('\uf0f4'),
        cmd_svg('\uf024'),
        cmd_swap_horizontal('\uede6'),
        cmd_swap_horizontal_bold('\uf4d0'),
        cmd_swap_horizontal_circle('\uf8e4'),
        cmd_swap_horizontal_circle_outline('\uf8e5'),
        cmd_swap_horizontal_variant('\uf1c1'),
        cmd_swap_vertical('\uede7'),
        cmd_swap_vertical_bold('\uf4d1'),
        cmd_swap_vertical_circle('\uf8e6'),
        cmd_swap_vertical_circle_outline('\uf8e7'),
        cmd_swap_vertical_variant('\uf1c2'),
        cmd_swim('\uede8'),
        cmd_switch('\uede9'),
        cmd_sword('\uedea'),
        cmd_sword_cross('\uf088'),
        cmd_syllabary_hangul('\ufc33'),
        cmd_syllabary_hiragana('\ufc34'),
        cmd_syllabary_katakana('\ufc35'),
        cmd_syllabary_katakana_half_width('\ufc36'),
        cmd_symfony('\uf3e5'),
        cmd_sync('\uedeb'),
        cmd_sync_alert('\uedec'),
        cmd_sync_circle('\ufc78'),
        cmd_sync_off('\ueded'),
        cmd_tab('\uedee'),
        cmd_tab_minus('\uf44e'),
        cmd_tab_plus('\uf05f'),
        cmd_tab_remove('\uf44f'),
        cmd_tab_unselected('\uedef'),
        cmd_table('\uedf0'),
        cmd_table_border('\uf317'),
        cmd_table_chair('\uf964'),
        cmd_table_column('\uf136'),
        cmd_table_column_plus_after('\uedf1'),
        cmd_table_column_plus_before('\uedf2'),
        cmd_table_column_remove('\uedf3'),
        cmd_table_column_width('\uedf4'),
        cmd_table_edit('\uedf5'),
        cmd_table_eye('\uf994'),
        cmd_table_furniture('\ueec0'),
        cmd_table_headers_eye('\ufb1d'),
        cmd_table_headers_eye_off('\ufb1e'),
        cmd_table_large('\uedf6'),
        cmd_table_large_plus('\uf88a'),
        cmd_table_large_remove('\uf88b'),
        cmd_table_merge_cells('\uf2a5'),
        cmd_table_of_contents('\uf137'),
        cmd_table_plus('\uf374'),
        cmd_table_refresh('\ufca0'),
        cmd_table_remove('\uf375'),
        cmd_table_row('\uf138'),
        cmd_table_row_height('\uedf7'),
        cmd_table_row_plus_after('\uedf8'),
        cmd_table_row_plus_before('\uedf9'),
        cmd_table_row_remove('\uedfa'),
        cmd_table_search('\uf20e'),
        cmd_table_settings('\uf139'),
        cmd_table_sync('\ufca1'),
        cmd_table_tennis('\uf76b'),
        cmd_tablet('\uedfb'),
        cmd_tablet_android('\uedfc'),
        cmd_tablet_cellphone('\uf2a6'),
        cmd_tablet_dashboard('\uf7d1'),
        cmd_tablet_ipad('\uedfd'),
        cmd_taco('\uf065'),
        cmd_tag('\uedfe'),
        cmd_tag_faces('\uedff'),
        cmd_tag_heart('\uef8e'),
        cmd_tag_heart_outline('\uf4d2'),
        cmd_tag_minus('\uf20f'),
        cmd_tag_minus_outline('\ufb1f'),
        cmd_tag_multiple('\uee00'),
        cmd_tag_multiple_outline('\ufbf7'),
        cmd_tag_off('\ufb20'),
        cmd_tag_off_outline('\ufb21'),
        cmd_tag_outline('\uee01'),
        cmd_tag_plus('\uf025'),
        cmd_tag_plus_outline('\ufb22'),
        cmd_tag_remove('\uf026'),
        cmd_tag_remove_outline('\ufb23'),
        cmd_tag_text('\ufb24'),
        cmd_tag_text_outline('\uee02'),
        cmd_tank('\uf63d'),
        cmd_tanker_truck('\uf8e8'),
        cmd_tape_measure('\uf450'),
        cmd_target('\uee03'),
        cmd_target_account('\uf4d3'),
        cmd_target_variant('\uf376'),
        cmd_taxi('\uee04'),
        cmd_tea('\uf6a1'),
        cmd_tea_outline('\uf6a2'),
        cmd_teach('\uf191'),
        cmd_teamviewer('\uee05'),
        cmd_telegram('\uee06'),
        cmd_telescope('\uf451'),
        cmd_television('\uee07'),
        cmd_television_ambient_light('\ufc56'),
        cmd_television_box('\uf13a'),
        cmd_television_classic('\uf0f5'),
        cmd_television_classic_off('\uf13b'),
        cmd_television_clean('\ufa10'),
        cmd_television_guide('\uee08'),
        cmd_television_off('\uf13c'),
        cmd_television_pause('\uf88c'),
        cmd_television_play('\uf7d2'),
        cmd_television_stop('\uf88d'),
        cmd_temperature_celsius('\uee09'),
        cmd_temperature_fahrenheit('\uee0a'),
        cmd_temperature_kelvin('\uee0b'),
        cmd_tennis('\uf6a3'),
        cmd_tennis_ball('\uee0c'),
        cmd_tent('\uee0d'),
        cmd_terraform('\uf965'),
        cmd_test_tube('\uef6b'),
        cmd_test_tube_empty('\uf210'),
        cmd_test_tube_off('\uf211'),
        cmd_text('\uf2a7'),
        cmd_text_box('\ueb1e'),
        cmd_text_box_check('\uf7a9'),
        cmd_text_box_check_outline('\uf7aa'),
        cmd_text_box_minus('\uf7ab'),
        cmd_text_box_minus_outline('\uf7ac'),
        cmd_text_box_multiple('\uf3b6'),
        cmd_text_box_multiple_outline('\uf3b7'),
        cmd_text_box_outline('\uf2ec'),
        cmd_text_box_plus('\uf7ad'),
        cmd_text_box_plus_outline('\uf7ae'),
        cmd_text_box_remove('\uf7af'),
        cmd_text_box_remove_outline('\uf7b0'),
        cmd_text_box_search('\uf7b1'),
        cmd_text_box_search_outline('\uf7b2'),
        cmd_text_recognition('\ufa3d'),
        cmd_text_shadow('\uef6c'),
        cmd_text_short('\uf2a8'),
        cmd_text_subject('\uf2a9'),
        cmd_text_to_speech('\uee0e'),
        cmd_text_to_speech_off('\uee0f'),
        cmd_textarea('\uf995'),
        cmd_textbox('\uef11'),
        cmd_textbox_lock('\ufc5d'),
        cmd_textbox_password('\uf0f6'),
        cmd_texture('\uee10'),
        cmd_texture_box('\uf8e9'),
        cmd_theater('\uee11'),
        cmd_theme_light_dark('\uee12'),
        cmd_thermometer('\uee13'),
        cmd_thermometer_alert('\uf704'),
        cmd_thermometer_chevron_down('\uf705'),
        cmd_thermometer_chevron_up('\uf706'),
        cmd_thermometer_high('\uf9c2'),
        cmd_thermometer_lines('\uee14'),
        cmd_thermometer_low('\uf9c3'),
        cmd_thermometer_minus('\uf707'),
        cmd_thermometer_plus('\uf708'),
        cmd_thermostat('\uec99'),
        cmd_thermostat_box('\uf192'),
        cmd_thought_bubble('\uf0f7'),
        cmd_thought_bubble_outline('\uf0f8'),
        cmd_thumb_down('\uee15'),
        cmd_thumb_down_outline('\uee16'),
        cmd_thumb_up('\uee17'),
        cmd_thumb_up_outline('\uee18'),
        cmd_thumbs_up_down('\uee19'),
        cmd_ticket('\uee1a'),
        cmd_ticket_account('\uee1b'),
        cmd_ticket_confirmation('\uee1c'),
        cmd_ticket_confirmation_outline('\ufca9'),
        cmd_ticket_outline('\uf212'),
        cmd_ticket_percent('\uf027'),
        cmd_tie('\uee1d'),
        cmd_tilde('\uf028'),
        cmd_timelapse('\uee1e'),
        cmd_timeline('\uf4d4'),
        cmd_timeline_alert('\uf898'),
        cmd_timeline_alert_outline('\uf89b'),
        cmd_timeline_clock('\ufafb'),
        cmd_timeline_clock_outline('\ufafc'),
        cmd_timeline_help('\uf89c'),
        cmd_timeline_help_outline('\uf89d'),
        cmd_timeline_outline('\uf4d5'),
        cmd_timeline_plus('\uf899'),
        cmd_timeline_plus_outline('\uf89a'),
        cmd_timeline_text('\uf4d6'),
        cmd_timeline_text_outline('\uf4d7'),
        cmd_timer('\ufcaa'),
        cmd_timer_10('\uee20'),
        cmd_timer_3('\uee21'),
        cmd_timer_off('\ufcab'),
        cmd_timer_off_outline('\uee22'),
        cmd_timer_outline('\uee1f'),
        cmd_timer_sand('\uee23'),
        cmd_timer_sand_empty('\uefb0'),
        cmd_timer_sand_full('\uf08d'),
        cmd_timetable('\uee24'),
        cmd_toaster('\uf966'),
        cmd_toaster_off('\ufab7'),
        cmd_toaster_oven('\uf5d6'),
        cmd_toggle_switch('\uee25'),
        cmd_toggle_switch_off('\uee26'),
        cmd_toggle_switch_off_outline('\uf318'),
        cmd_toggle_switch_outline('\uf319'),
        cmd_toilet('\uf2aa'),
        cmd_toolbox('\uf2ab'),
        cmd_toolbox_outline('\uf2ac'),
        cmd_tools('\uf967'),
        cmd_tooltip('\uee27'),
        cmd_tooltip_account('\ue90b'),
        cmd_tooltip_edit('\uee28'),
        cmd_tooltip_edit_outline('\ufbc5'),
        cmd_tooltip_image('\uee29'),
        cmd_tooltip_image_outline('\uf4d8'),
        cmd_tooltip_outline('\uee2a'),
        cmd_tooltip_plus('\uf4d9'),
        cmd_tooltip_plus_outline('\uee2b'),
        cmd_tooltip_text('\uee2c'),
        cmd_tooltip_text_outline('\uf4da'),
        cmd_tooth('\uf1c3'),
        cmd_tooth_outline('\uee2d'),
        cmd_toothbrush('\ufa29'),
        cmd_toothbrush_electric('\ufa2c'),
        cmd_toothbrush_paste('\ufa2a'),
        cmd_tortoise('\uf63e'),
        cmd_toslink('\ufbb8'),
        cmd_tournament('\uf2ad'),
        cmd_tow_truck('\uf13d'),
        cmd_tower_beach('\uef84'),
        cmd_tower_fire('\uef85'),
        cmd_toy_brick('\ufb88'),
        cmd_toy_brick_marker('\ufb89'),
        cmd_toy_brick_marker_outline('\ufb8a'),
        cmd_toy_brick_minus('\ufb8b'),
        cmd_toy_brick_minus_outline('\ufb8c'),
        cmd_toy_brick_outline('\ufb8d'),
        cmd_toy_brick_plus('\ufb8e'),
        cmd_toy_brick_plus_outline('\ufb8f'),
        cmd_toy_brick_plus_outline1('\ufb90'),
        cmd_toy_brick_remove('\ufb91'),
        cmd_toy_brick_search('\ufb92'),
        cmd_toy_brick_search_outline('\ufb93'),
        cmd_track_light('\uf213'),
        cmd_trackpad('\uf0f9'),
        cmd_trackpad_lock('\uf232'),
        cmd_tractor('\uf193'),
        cmd_trademark('\uf377'),
        cmd_traffic_cone('\ufc7c'),
        cmd_traffic_light('\uee2f'),
        cmd_train('\uee30'),
        cmd_train_car('\uf4db'),
        cmd_train_variant('\uf1c4'),
        cmd_tram('\uee31'),
        cmd_tram_side('\uf8ea'),
        cmd_transcribe('\uee32'),
        cmd_transcribe_close('\uee33'),
        cmd_transfer('\uf968'),
        cmd_transfer_down('\uf6a4'),
        cmd_transfer_left('\uf6a5'),
        cmd_transfer_right('\uee34'),
        cmd_transfer_up('\uf6a6'),
        cmd_transit_connection('\uf63f'),
        cmd_transit_connection_variant('\uf640'),
        cmd_transit_detour('\uf88e'),
        cmd_transit_transfer('\uefb1'),
        cmd_transition('\uf214'),
        cmd_transition_masked('\uf215'),
        cmd_translate('\ueece'),
        cmd_translate_off('\uf709'),
        cmd_transmission_tower('\uf641'),
        cmd_trash_can('\uf378'),
        cmd_trash_can_outline('\uf379'),
        cmd_tray('\ufb94'),
        cmd_tray_alert('\ufb95'),
        cmd_tray_full('\ufb96'),
        cmd_tray_minus('\ufb97'),
        cmd_tray_plus('\ufb98'),
        cmd_tray_remove('\ufb99'),
        cmd_treasure_chest('\uf029'),
        cmd_tree('\uee35'),
        cmd_tree_outline('\uf76c'),
        cmd_trello('\uee36'),
        cmd_trending_down('\uee37'),
        cmd_trending_neutral('\uee38'),
        cmd_trending_up('\uee39'),
        cmd_triangle('\uee3a'),
        cmd_triangle_outline('\uee3b'),
        cmd_triforce('\uf4dc'),
        cmd_trophy('\uee3c'),
        cmd_trophy_award('\uee3d'),
        cmd_trophy_broken('\uf6a7'),
        cmd_trophy_outline('\uee3e'),
        cmd_trophy_variant('\uee3f'),
        cmd_trophy_variant_outline('\uee40'),
        cmd_truck('\uee41'),
        cmd_truck_check('\uf5d7'),
        cmd_truck_check_outline('\ufb9a'),
        cmd_truck_delivery('\uee42'),
        cmd_truck_delivery_outline('\ufb9b'),
        cmd_truck_fast('\uf089'),
        cmd_truck_fast_outline('\ufb9c'),
        cmd_truck_outline('\ufb9d'),
        cmd_truck_trailer('\uf02a'),
        cmd_trumpet('\uf996'),
        cmd_tshirt_crew('\uf37a'),
        cmd_tshirt_crew_outline('\uee43'),
        cmd_tshirt_v('\uf37b'),
        cmd_tshirt_v_outline('\uee44'),
        cmd_tumble_dryer('\uf216'),
        cmd_tumble_dryer_alert('\ufaba'),
        cmd_tumble_dryer_off('\ufabb'),
        cmd_tune('\uef31'),
        cmd_tune_vertical('\uef6d'),
        cmd_turnstile('\uf5d8'),
        cmd_turnstile_outline('\uf5d9'),
        cmd_turtle('\uf5da'),
        cmd_twitch('\uee47'),
        cmd_twitter('\uee48'),
        cmd_twitter_retweet('\uee4b'),
        cmd_two_factor_authentication('\uf2ae'),
        cmd_typewriter('\uf830'),
        cmd_ubisoft('\uf4dd'),
        cmd_ubuntu('\uee4c'),
        cmd_ufo('\uf9c4'),
        cmd_ufo_outline('\uf9c5'),
        cmd_ultra_high_definition('\uf0fa'),
        cmd_umbraco('\uee4d'),
        cmd_umbrella('\uee4e'),
        cmd_umbrella_closed('\uf2af'),
        cmd_umbrella_outline('\uee4f'),
        cmd_undo('\uee50'),
        cmd_undo_variant('\uee51'),
        cmd_unfold_less_horizontal('\uee52'),
        cmd_unfold_less_vertical('\uf063'),
        cmd_unfold_more_horizontal('\uee53'),
        cmd_unfold_more_vertical('\uf064'),
        cmd_ungroup('\uee54'),
        cmd_unicode('\uf7d3'),
        cmd_unity('\uefb2'),
        cmd_unreal('\uf2b0'),
        cmd_untappd('\uee55'),
        cmd_update('\uefb3'),
        cmd_upload('\uee56'),
        cmd_upload_lock('\ufc73'),
        cmd_upload_lock_outline('\ufc74'),
        cmd_upload_multiple('\uf13e'),
        cmd_upload_network('\ueff9'),
        cmd_upload_network_outline('\uf5db'),
        cmd_upload_off('\uf9c6'),
        cmd_upload_off_outline('\uf9c7'),
        cmd_upload_outline('\uf70a'),
        cmd_usb('\uee57'),
        cmd_usb_flash_drive('\ufb9e'),
        cmd_usb_flash_drive_outline('\ufb9f'),
        cmd_usb_port('\ufaf0'),
        cmd_valve('\uf969'),
        cmd_valve_closed('\uf96a'),
        cmd_valve_open('\uf96b'),
        cmd_van_passenger('\uf0fb'),
        cmd_van_utility('\uf0fc'),
        cmd_vanish('\uf0fd'),
        cmd_vanity_light('\ufae1'),
        cmd_variable('\uf3e6'),
        cmd_variable_box('\ufa11'),
        cmd_vector_arrange_above('\uee58'),
        cmd_vector_arrange_below('\uee59'),
        cmd_vector_bezier('\uf3e7'),
        cmd_vector_circle('\uee5a'),
        cmd_vector_circle_variant('\uee5b'),
        cmd_vector_combine('\uee5c'),
        cmd_vector_curve('\uee5d'),
        cmd_vector_difference('\uee5e'),
        cmd_vector_difference_ab('\uee5f'),
        cmd_vector_difference_ba('\uee60'),
        cmd_vector_ellipse('\uf194'),
        cmd_vector_intersection('\uee61'),
        cmd_vector_line('\uee62'),
        cmd_vector_link('\uf8eb'),
        cmd_vector_point('\uee63'),
        cmd_vector_polygon('\uee64'),
        cmd_vector_polyline('\uee65'),
        cmd_vector_polyline_edit('\ufb25'),
        cmd_vector_polyline_minus('\ufb26'),
        cmd_vector_polyline_plus('\ufb27'),
        cmd_vector_polyline_remove('\ufb28'),
        cmd_vector_radius('\uf04d'),
        cmd_vector_rectangle('\ueeca'),
        cmd_vector_selection('\uee66'),
        cmd_vector_square('\ue900'),
        cmd_vector_triangle('\uee67'),
        cmd_vector_union('\uee68'),
        cmd_vhs('\uf31a'),
        cmd_vibrate('\uee6a'),
        cmd_vibrate_off('\uf5dc'),
        cmd_video('\uee6b'),
        cmd_video_3d('\uf0fe'),
        cmd_video_3d_variant('\uf7d4'),
        cmd_video_4k_box('\uf13f'),
        cmd_video_account('\uf218'),
        cmd_video_box('\ue9fd'),
        cmd_video_box_off('\ue9fe'),
        cmd_video_check('\uf96c'),
        cmd_video_check_outline('\uf96d'),
        cmd_video_image('\uf219'),
        cmd_video_input_antenna('\uf140'),
        cmd_video_input_component('\uf141'),
        cmd_video_input_hdmi('\uf142'),
        cmd_video_input_scart('\uf88f'),
        cmd_video_input_svideo('\uf143'),
        cmd_video_minus('\uf2b1'),
        cmd_video_minus_outline('\uebbe'),
        cmd_video_off('\uee6c'),
        cmd_video_off_outline('\uf4de'),
        cmd_video_outline('\uf4df'),
        cmd_video_plus('\uf2b2'),
        cmd_video_plus_outline('\uead6'),
        cmd_video_stabilization('\uf21a'),
        cmd_video_switch('\uee6d'),
        cmd_video_switch_outline('\uf091'),
        cmd_video_vintage('\uf31b'),
        cmd_video_wireless('\uf7d5'),
        cmd_video_wireless_outline('\uf7d6'),
        cmd_view_agenda('\uee6e'),
        cmd_view_agenda_outline('\ufad8'),
        cmd_view_array('\uee6f'),
        cmd_view_carousel('\uee70'),
        cmd_view_column('\uee71'),
        cmd_view_comfy('\uf76d'),
        cmd_view_compact('\uf76e'),
        cmd_view_compact_outline('\uf76f'),
        cmd_view_dashboard('\uee72'),
        cmd_view_dashboard_outline('\uf31c'),
        cmd_view_dashboard_variant('\uf144'),
        cmd_view_day('\uee73'),
        cmd_view_grid('\uee74'),
        cmd_view_grid_outline('\ufad9'),
        cmd_view_grid_plus('\uf890'),
        cmd_view_grid_plus_outline('\ufada'),
        cmd_view_headline('\uee75'),
        cmd_view_list('\uee76'),
        cmd_view_module('\uee77'),
        cmd_view_parallel('\uf02b'),
        cmd_view_quilt('\uee78'),
        cmd_view_sequential('\uf02c'),
        cmd_view_split_horizontal('\uf4ce'),
        cmd_view_split_vertical('\uf4cf'),
        cmd_view_stream('\uee79'),
        cmd_view_week('\uee7a'),
        cmd_vimeo('\uee7b'),
        cmd_violin('\uef12'),
        cmd_virtual_reality('\uf195'),
        cmd_vk('\uee7d'),
        cmd_vlc('\uee80'),
        cmd_voice_off('\uf7d7'),
        cmd_voicemail('\uee81'),
        cmd_volleyball('\uf2b3'),
        cmd_volume_high('\uee82'),
        cmd_volume_low('\uee83'),
        cmd_volume_medium('\uee84'),
        cmd_volume_minus('\uf061'),
        cmd_volume_mute('\uf062'),
        cmd_volume_off('\uee85'),
        cmd_volume_plus('\uf060'),
        cmd_volume_source('\ufa20'),
        cmd_volume_variant_off('\uf70b'),
        cmd_volume_vibrate('\ufa21'),
        cmd_vote('\uf31e'),
        cmd_vote_outline('\uf31f'),
        cmd_vpn('\uee86'),
        cmd_vuejs('\uf145'),
        cmd_vuetify('\uf770'),
        cmd_walk('\uee87'),
        cmd_wall('\uf0ff'),
        cmd_wall_sconce('\uf21b'),
        cmd_wall_sconce_flat('\uf21c'),
        cmd_wall_sconce_flat_variant('\ued22'),
        cmd_wall_sconce_round('\uf04b'),
        cmd_wall_sconce_round_variant('\uf21d'),
        cmd_wallet('\uee88'),
        cmd_wallet_giftcard('\uee89'),
        cmd_wallet_membership('\uee8a'),
        cmd_wallet_outline('\uf4e0'),
        cmd_wallet_plus('\uf891'),
        cmd_wallet_plus_outline('\uf892'),
        cmd_wallet_travel('\uee8b'),
        cmd_wallpaper('\uf70c'),
        cmd_wan('\uee8c'),
        cmd_wardrobe('\uf893'),
        cmd_wardrobe_outline('\uf894'),
        cmd_warehouse('\uf884'),
        cmd_washing_machine('\uf02d'),
        cmd_washing_machine_alert('\ufabc'),
        cmd_washing_machine_off('\ufabd'),
        cmd_watch('\uee8d'),
        cmd_watch_export('\uee8e'),
        cmd_watch_export_variant('\uf196'),
        cmd_watch_import('\uee8f'),
        cmd_watch_import_variant('\uf197'),
        cmd_watch_variant('\uf198'),
        cmd_watch_vibrate('\uefb4'),
        cmd_watch_vibrate_off('\uf5dd'),
        cmd_water('\uee90'),
        cmd_water_boiler('\uf895'),
        cmd_water_boiler_alert('\ufab3'),
        cmd_water_boiler_off('\ufab4'),
        cmd_water_off('\uee91'),
        cmd_water_outline('\uf70d'),
        cmd_water_percent('\uee92'),
        cmd_water_polo('\ufba0'),
        cmd_water_pump('\uee93'),
        cmd_water_pump_off('\uf896'),
        cmd_water_well('\uf96e'),
        cmd_water_well_outline('\uf96f'),
        cmd_watermark('\uef15'),
        cmd_wave('\uf831'),
        cmd_waves('\uf08e'),
        cmd_waze('\uf4e1'),
        cmd_weather_cloudy('\uee94'),
        cmd_weather_cloudy_alert('\uf832'),
        cmd_weather_cloudy_arrow_right('\uf771'),
        cmd_weather_fog('\uee95'),
        cmd_weather_hail('\uee96'),
        cmd_weather_hazy('\uf833'),
        cmd_weather_hurricane('\uf199'),
        cmd_weather_lightning('\uee97'),
        cmd_weather_lightning_rainy('\uef81'),
        cmd_weather_night('\uee98'),
        cmd_weather_night_partly_cloudy('\uf834'),
        cmd_weather_partly_cloudy('\uee99'),
        cmd_weather_partly_lightning('\uf835'),
        cmd_weather_partly_rainy('\uf836'),
        cmd_weather_partly_snowy('\uf837'),
        cmd_weather_partly_snowy_rainy('\uf838'),
        cmd_weather_pouring('\uee9a'),
        cmd_weather_rainy('\uee9b'),
        cmd_weather_snowy('\uee9c'),
        cmd_weather_snowy_heavy('\uf839'),
        cmd_weather_snowy_rainy('\uef82'),
        cmd_weather_sunny('\uee9d'),
        cmd_weather_sunny_alert('\uf83a'),
        cmd_weather_sunset('\uee9e'),
        cmd_weather_sunset_down('\uee9f'),
        cmd_weather_sunset_up('\ueea0'),
        cmd_weather_tornado('\uf83b'),
        cmd_weather_windy('\ueea1'),
        cmd_weather_windy_variant('\ueea2'),
        cmd_web('\ueea3'),
        cmd_web_box('\uf897'),
        cmd_web_clock('\ufb4a'),
        cmd_webcam('\ueea4'),
        cmd_webhook('\uef32'),
        cmd_webpack('\uf02e'),
        cmd_webrtc('\ufb48'),
        cmd_wechat('\uef14'),
        cmd_weight('\ueea5'),
        cmd_weight_gram('\uf642'),
        cmd_weight_kilogram('\ueea6'),
        cmd_weight_lifter('\ufa5d'),
        cmd_weight_pound('\uf2b4'),
        cmd_whatsapp('\ueea7'),
        cmd_wheelchair_accessibility('\ueea8'),
        cmd_whistle('\uf2b5'),
        cmd_whistle_outline('\ufbbc'),
        cmd_white_balance_auto('\ueea9'),
        cmd_white_balance_incandescent('\ueeaa'),
        cmd_white_balance_iridescent('\ueeab'),
        cmd_white_balance_sunny('\ueeac'),
        cmd_widgets('\uf02f'),
        cmd_widgets_outline('\ufc55'),
        cmd_wifi('\ueead'),
        cmd_wifi_off('\ueeae'),
        cmd_wifi_star('\uf70e'),
        cmd_wifi_strength_1('\uf21e'),
        cmd_wifi_strength_1_alert('\uf21f'),
        cmd_wifi_strength_1_lock('\uf220'),
        cmd_wifi_strength_2('\uf221'),
        cmd_wifi_strength_2_alert('\uf222'),
        cmd_wifi_strength_2_lock('\uf223'),
        cmd_wifi_strength_3('\uf224'),
        cmd_wifi_strength_3_alert('\uf225'),
        cmd_wifi_strength_3_lock('\uf226'),
        cmd_wifi_strength_4('\uf227'),
        cmd_wifi_strength_4_alert('\uf228'),
        cmd_wifi_strength_4_lock('\uf229'),
        cmd_wifi_strength_alert_outline('\uf22a'),
        cmd_wifi_strength_lock_outline('\uf22b'),
        cmd_wifi_strength_off('\uf22c'),
        cmd_wifi_strength_off_outline('\uf22d'),
        cmd_wifi_strength_outline('\uf22e'),
        cmd_wikipedia('\ueeb0'),
        cmd_wind_turbine('\uf6a8'),
        cmd_window_close('\ueeb1'),
        cmd_window_closed('\ueeb2'),
        cmd_window_closed_variant('\ufadb'),
        cmd_window_maximize('\ueeb3'),
        cmd_window_minimize('\ueeb4'),
        cmd_window_open('\ueeb5'),
        cmd_window_open_variant('\ufadc'),
        cmd_window_restore('\ueeb6'),
        cmd_window_shutter('\ufa1c'),
        cmd_window_shutter_alert('\ufa1d'),
        cmd_window_shutter_open('\ufa1e'),
        cmd_wiper('\uf3e8'),
        cmd_wiper_wash('\uf6a9'),
        cmd_wordpress('\ueeb8'),
        cmd_wrap('\ueeba'),
        cmd_wrap_disabled('\uf4e2'),
        cmd_wrench('\ueebb'),
        cmd_wrench_outline('\uf4e3'),
        cmd_xamarin('\uf146'),
        cmd_xamarin_outline('\uf147'),
        cmd_xing('\ueec2'),
        cmd_xml('\ueec4'),
        cmd_xmpp('\uf100'),
        cmd_y_combinator('\uef27'),
        cmd_yahoo('\uf452'),
        cmd_yeast('\ueec5'),
        cmd_yin_yang('\uef83'),
        cmd_yoga('\ufa7c'),
        cmd_youtube('\ueec7'),
        cmd_youtube_gaming('\uf149'),
        cmd_youtube_studio('\uf148'),
        cmd_youtube_subscription('\uf643'),
        cmd_youtube_tv('\ued4d'),
        cmd_z_wave('\uf3e9'),
        cmd_zend('\uf3ea'),
        cmd_zigbee('\uf644'),
        cmd_zip_box('\ueec8'),
        cmd_zip_box_outline('\uf8fd'),
        cmd_zip_disk('\uf322'),
        cmd_zodiac_aquarius('\uf37c'),
        cmd_zodiac_aries('\uf37d'),
        cmd_zodiac_cancer('\uf37e'),
        cmd_zodiac_capricorn('\uf37f'),
        cmd_zodiac_gemini('\uf380'),
        cmd_zodiac_leo('\uf381'),
        cmd_zodiac_libra('\uf382'),
        cmd_zodiac_pisces('\uf383'),
        cmd_zodiac_sagittarius('\uf384'),
        cmd_zodiac_scorpio('\uf385'),
        cmd_zodiac_taurus('\uf386'),
        cmd_zodiac_virgo('\uf387');

        override val typeface: ITypeface by lazy { CommunityMaterial }
    }
}
